(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    531133,      13462]
NotebookOptionsPosition[    505891,      13121]
NotebookOutlinePosition[    506283,      13137]
CellTagsIndexPosition[    506240,      13134]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Evolution of plasticity in production and transgenerational inheritance of \
small RNAs under dynamic environmental conditions.\
\>", "Title",
 CellChangeTimes->{{3.8152889092272177`*^9, 3.8152889304008408`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"d8e03421-3017-45a7-90fe-b27ce3fbc027"],

Cell["Willian T.A.F. Silva, Sarah P. Otto, Simone Immler", "Chapter",
 CellChangeTimes->{{3.8152889494328547`*^9, 
  3.8152889615168133`*^9}},ExpressionUUID->"e37f05dc-2e5a-4625-b1f0-\
72d2a7b06448"],

Cell["OBS.: This script calculates fitness throughout development.", "Chapter",
 CellChangeTimes->{
  3.815288977930084*^9},ExpressionUUID->"03223c65-756b-40cf-9f00-\
b49764c3d47b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basics", "Title",
 CellChangeTimes->{{3.8152889913660927`*^9, 
  3.815288994875596*^9}},ExpressionUUID->"16c6eee6-4d95-4506-b421-\
193679f16308"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.81528901934866*^9, 3.8152890193567333`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"008c8c13-1262-49d7-9962-34b0e0f33c62"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.8152890283445272`*^9, 3.8152890283527946`*^9}, {
  3.8152956359263287`*^9, 3.815295641216794*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"ea031699-dc47-469f-833a-4171ab6f7f0e"],

Cell[BoxData[
 RowBox[{"modeldesign", "=", 
  RowBox[{"Import", "[", "\"\<modelandstrategies.png\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.815289034236218*^9, 3.815289034242384*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"733a8a16-e533-4ed7-bac7-54fd67372afd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Title",
 CellChangeTimes->{{3.815289045531537*^9, 
  3.815289046734529*^9}},ExpressionUUID->"4e9b5054-64c4-47ee-bf76-\
cba21f66835c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Example", " ", "values", " ", "for", " ", "testing"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"examplevalues", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.1", ",", "5", ",", "6.798"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"examplen0", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"exampleRgerm", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"examplecellgen", "=", "20"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"examplengen", "=", "10"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"examplePb", "=", "1.0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"examplespeedeq", "=", "1.0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"exampleenv", "=", "0.9"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.815289053712186*^9, 3.815289053719915*^9}, 
   3.8206466435843687`*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"173bbc86-127f-4b69-aa4d-7696a9016297"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"equil", ",", "equilneg"}], "]"}], ";"}], "\n", 
  RowBox[{"(*", "FUNCTION", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"equil", "[", 
    RowBox[{"{", 
     RowBox[{"b_", ",", "d_", ",", "m_", ",", "\[Mu]_"}], "}"}], "]"}], ":=", 
   
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"b", " ", "m"}], "-", 
       RowBox[{"d", " ", "m"}], "+", 
       RowBox[{"b", " ", "\[Mu]"}], "+", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"4", " ", "b", " ", "d", " ", "m", " ", "\[Mu]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"d", " ", "m"}], "-", 
            RowBox[{"b", " ", 
             RowBox[{"(", 
              RowBox[{"m", "+", "\[Mu]"}], ")"}]}]}], ")"}], "^", "2"}]}], 
        "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], ")"}]}], 
  RowBox[{"(*", 
   RowBox[{"Function", " ", "for", " ", 
    RowBox[{"Subscript", "[", 
     RowBox[{
      RowBox[{"Overscript", "[", 
       RowBox[{"n", ",", " ", "^"}], "]"}], ",", "w"}], "]"}], " ", "#1"}], 
   "*)"}], "\n", 
  RowBox[{"(*", "FUNCTION", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"equilneg", "[", 
   RowBox[{"{", 
    RowBox[{"b_", ",", "d_", ",", "m_", ",", "\[Mu]_"}], "}"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "m"}], "-", 
      RowBox[{"d", " ", "m"}], "+", 
      RowBox[{"b", " ", "\[Mu]"}], "-", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"4", " ", "b", " ", "d", " ", "m", " ", "\[Mu]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", " ", "m"}], "-", 
           RowBox[{"b", " ", 
            RowBox[{"(", 
             RowBox[{"m", "+", "\[Mu]"}], ")"}]}]}], ")"}], "^", "2"}]}], 
       "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", "b", " ", "d"}], ")"}]}], ")"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Function", " ", "for", " ", 
     RowBox[{"Subscript", "[", 
      RowBox[{
       RowBox[{"Overscript", "[", 
        RowBox[{"n", ",", " ", "^"}], "]"}], ",", "w"}], "]"}], " ", "#2"}], 
    ";", 
    RowBox[{
    "this", " ", "equilibrium", " ", "contains", " ", "negative", " ", 
     "values", " ", "and", " ", "is", " ", "therefore", " ", "biologically", 
     " ", "irrelevant"}]}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.8152890630372887`*^9, 3.8152890630439253`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"9a399f38-1e31-4619-80f1-31a6153ebc87"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "solution", "]"}], ";"}], "\n", 
  RowBox[{"(*", "FUNCTION", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solution", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"b_", ",", "d_", ",", "m_", ",", "\[Mu]_"}], "}"}], ",", "n0_", 
    ",", "cellgen_", ",", "speedeq_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"n", "[", "t", "]"}], ",", "t"}], "]"}], "\[Equal]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"speedeq", " ", "b"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"speedeq", " ", "b", " ", 
                  RowBox[{"n", "[", "t", "]"}]}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"speedeq", " ", "m"}], ")"}]}]}], ")"}]}], "-", 
            RowBox[{"speedeq", " ", "d"}]}], ")"}], " ", 
          RowBox[{"n", "[", "t", "]"}]}], "+", 
         RowBox[{"speedeq", " ", "\[Mu]"}]}]}], ",", 
       RowBox[{
        RowBox[{"n", "[", "0", "]"}], "\[Equal]", "n0"}]}], "}"}], ",", 
     RowBox[{"n", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], "//", 
   "FullSimplify", " ", 
   RowBox[{"(*", 
    RowBox[{"Function", " ", "to", " ", "plot", " ", "the", " ", "solution"}],
     "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.815289070462111*^9, 3.815289070469667*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"8dc428ed-3c81-479e-b2ca-5cfcede7fa22"],

Cell[BoxData[
 RowBox[{"solution", "[", 
  RowBox[{
  "examplevalues", ",", "examplen0", ",", "examplecellgen", ",", 
   "examplespeedeq"}], "]"}]], "Input",
 CellChangeTimes->{{3.815289078594409*^9, 3.8152890786007223`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"03ab6761-a84e-4f32-b5ea-4caccb390756"],

Cell[BoxData[
 RowBox[{"exampledevdynamics", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"n", "[", "t", "]"}], "/.", 
       RowBox[{"solution", "[", 
        RowBox[{
        "examplevalues", ",", "examplen0", ",", "examplecellgen", ",", 
         "examplespeedeq"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "examplecellgen"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.815289086975904*^9, 3.815289086981257*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"cb8f25a9-4b2b-4299-8f2a-90350a671bc2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "acrosswithingen1condplot", "]"}], ";"}], "\n", 
  RowBox[{"(*", "FUNCTION", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"acrosswithingen1condplot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"b_", ",", "d_", ",", "m_", ",", "\[Mu]_"}], "}"}], ",", "n0_", 
    ",", "Rgerm_", ",", "ngen_", ",", "cellgen_", ",", "ylim_", ",", "color_",
     ",", "speedeq_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"interpolvalues", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "ngen"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"cellgen", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"interpolvalues", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "All"}], "]"}], "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"n", "[", "t", "]"}], "/.", 
          RowBox[{"solution", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"b", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
            "n0", ",", "cellgen", ",", "speedeq"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "2"}], ",", 
       RowBox[{"i", "\[LessSlantEqual]", "ngen"}], ",", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{
        RowBox[{"newn0", "=", 
         RowBox[{"Rgerm", " ", 
          RowBox[{"interpolvalues", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"i", "-", "1"}], ",", 
             RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"interpolvalues", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "All"}], "]"}], "]"}], "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Evaluate", "[", 
            RowBox[{
             RowBox[{"n", "[", "t", "]"}], "/.", 
             RowBox[{"solution", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"b", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
               "newn0", ",", "cellgen", ",", "speedeq"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}]}]}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"lastn", "=", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"interpolvalues", "[", 
         RowBox[{"[", 
          RowBox[{"ngen", ",", 
           RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"plotticks", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"i", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "ngen"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"plotticks", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1"}], "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"plotticks", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], "*", 
       RowBox[{"(", 
        RowBox[{"cellgen", "+", "1"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"plotinfo", "=", 
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "StringTemplate", "[", 
               "\"\<\\!\\(\\*SubscriptBox[\\(r\\), \\(germ\\)]\\)=`1`\>\"", 
               "]"}], "[", "Rgerm", "]"}], ",", 
             RowBox[{"FontSize", "\[Rule]", "20"}], ",", "color"}], "]"}], 
           ",", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\<,\>\"", ",", 
             RowBox[{"FontSize", "\[Rule]", "20"}], ",", "Black"}], "]"}], 
           ",", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"StringTemplate", "[", "\"\<c=`1`\>\"", "]"}], "[", 
              "cellgen", "]"}], ",", 
             RowBox[{"FontSize", "\[Rule]", "20"}], ",", "Black"}], "]"}]}], 
          "}"}], "}"}], ",", 
        RowBox[{"Frame", "\[Rule]", "None"}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}]}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", "interpolvalues", "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"color", ",", "Thick", ",", "20"}], "]"}]}], ",", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<b=`1`, d=`2`, m=`3`, \[Mu]=`4`, Rgerm=`5`, cellgen=`6`, \n\
Subscript[\n         n, eq]=`7`\>\"", "]"}], "[", 
             RowBox[{
             "b", ",", "d", ",", "m", ",", "\[Mu]", ",", "Rgerm", ",", 
              "cellgen", ",", "lastn"}], "]"}], ",", 
            RowBox[{"FontSize", "\[Rule]", "10"}]}], "]"}]}], ","}], "*)"}], 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ylim"}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Generations\>\"", ",", "\"\<sRNA level (n)\>\""}], 
         "}"}]}], ",", 
       RowBox[{"FrameStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"plotticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"Inset", "[", 
         RowBox[{"plotinfo", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "*", "cellgen"}], ",", 
            RowBox[{"0.95", "*", "ylim"}]}], "}"}]}], "]"}]}]}], "]"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.815289099164485*^9, 3.8152890991718616`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"b3b9ffa0-462c-4ede-bac0-eb96b2c63cd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"acrosswithingen1condplot", "[", 
   RowBox[{
   "examplevalues", ",", "examplen0", ",", "exampleRgerm", ",", "examplengen",
     ",", "examplecellgen", ",", "70", ",", "Blue", ",", "examplespeedeq"}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8152891076725273`*^9, 3.815289107679888*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"e07d1e28-8dda-444e-a360-c97f34c9c0a3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "fitfuncPb", ",", "\[Beta]", ",", "\[Alpha]", ",", "l", ",", "ncost", ",",
      "mid"}], "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Realized", " ", "fitness"}], ",", 
    RowBox[{"after", " ", "b", " ", "changes"}], ",", 
    RowBox[{"throughout", " ", 
     RowBox[{"development", ".", "The"}], " ", "fitness", " ", "of", " ", 
     "an", " ", "individual", " ", "is", " ", "the", " ", "geometric", " ", 
     "mean", " ", "fitness", " ", "across", " ", "cell", " ", "division", " ",
      "from", " ", "0", " ", "to", " ", "20", " ", 
     RowBox[{"(", 
      RowBox[{"21", " ", "values", " ", "in", " ", "total"}], ")"}]}]}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "FUNCTION", "*)"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fitfuncPb", "[", 
    RowBox[{"\[Epsilon]_", ",", "n_", ",", "Pb_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"fitvector", "=", 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "l"}], " ", "\[Epsilon]"}], "]"}], 
        RowBox[{"(*", 
         RowBox[{"cost", " ", "of", " ", "environmental", " ", 
          RowBox[{"stress", ":", 
           RowBox[{
           "fitness", " ", "declines", " ", "exponentially", " ", "with", " ",
             "stress"}]}]}], "*)"}], "*", 
        RowBox[{"(", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"ncost", " ", "n"}], "+", 
            RowBox[{"Pbcost", " ", "Pb"}]}], ")"}]}], ")"}], 
        RowBox[{"(*", 
         RowBox[{"cost", " ", "of", " ", "producing", " ", "more", " ", 
          RowBox[{"sRNA", ":", 
           RowBox[{
           "fitness", " ", "declines", " ", "close", " ", "to", " ", 
            "linearly", " ", "but", " ", "has", " ", "a", " ", "minimum", " ",
             "of", " ", "0"}]}]}], "*)"}], 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"And", " ", "cost", " ", "of", " ", "changing", " ", "b"}], 
          ",", 
          RowBox[{
          "where", " ", "Pb", " ", "is", " ", "the", " ", "plasticity", " ", 
           "in", " ", "b"}]}], "*)"}], "*", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"\[Beta]", "+", 
             RowBox[{"\[Alpha]", " ", "\[Epsilon]"}]}], ")"}]}], " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"E", "^", "n"}], "-", "1"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"E", "^", "n"}], "+", 
                RowBox[{"E", "^", "mid"}], "-", "2"}], ")"}]}], "-", 
             "\[Epsilon]"}], ")"}], "^", "2"}]}], "]"}]}]}], 
      RowBox[{"(*", 
       RowBox[{"benefit", " ", "of", " ", "matching", " ", "environment"}], 
       "*)"}], ";", "\[IndentingNewLine]", 
      RowBox[{"GeometricMean", "[", "fitvector", "]"}]}]}], "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Beta]", "=", "0.1"}], 
  RowBox[{"(*", "0.1", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", "15"}], 
  RowBox[{"(*", "4", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"l", "=", "0"}], 
  RowBox[{"(*", "0", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ncost", "=", "0.00001"}], 
  RowBox[{"(*", "0.005", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Pbcost", "=", 
   RowBox[{"50", " ", "ncost"}]}], 
  RowBox[{"(*", 
   RowBox[{"2", " ", "ncost"}], "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"mid", "=", "5"}], 
   RowBox[{"(*", "5", "*)"}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "l"}], " ", "\[Epsilon]"}], "]"}], 
   RowBox[{"(*", 
    RowBox[{"cost", " ", "of", " ", "environmental", " ", 
     RowBox[{"stress", ":", 
      RowBox[{
      "fitness", " ", "declines", " ", "exponentially", " ", "with", " ", 
       "stress"}]}]}], "*)"}], "*", 
   RowBox[{"(", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"ncost", " ", "n"}], "+", 
       RowBox[{"Pbcost", " ", "Pb"}]}], ")"}]}], ")"}], 
   RowBox[{"(*", 
    RowBox[{"cost", " ", "of", " ", "producing", " ", "more", " ", 
     RowBox[{"sRNA", ":", 
      RowBox[{
      "fitness", " ", "declines", " ", "close", " ", "to", " ", "linearly", 
       " ", "but", " ", "has", " ", "a", " ", "minimum", " ", "of", " ", 
       "0"}]}]}], "*)"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"And", " ", "cost", " ", "of", " ", "changing", " ", "b"}], ",", 
     
     RowBox[{
     "where", " ", "Pb", " ", "is", " ", "the", " ", "plasticity", " ", "in", 
      " ", "b"}]}], "*)"}], "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"\[Beta]", "+", 
        RowBox[{"\[Alpha]", " ", "\[Epsilon]"}]}], ")"}]}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"E", "^", "n"}], "-", "1"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"E", "^", "n"}], "+", 
           RowBox[{"E", "^", "mid"}], "-", "2"}], ")"}]}], "-", 
        "\[Epsilon]"}], ")"}], "^", "2"}]}], "]"}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.815289116316299*^9, 3.81528911632368*^9}, 
   3.815910111661517*^9, {3.815910212489148*^9, 3.815910214593754*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"32a3642b-876f-40a0-bad2-86f38a838036"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "fitfuncPbvector", "]"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Realized", " ", "fitness"}], ",", 
    RowBox[{"after", " ", "b", " ", "changes"}], ",", 
    RowBox[{"throughout", " ", 
     RowBox[{"development", ".", "The"}], " ", "fitness", " ", "of", " ", 
     "an", " ", "individual", " ", "is", " ", "the", " ", "geometric", " ", 
     "mean", " ", "fitness", " ", "across", " ", "cell", " ", "division", " ",
      "from", " ", "0", " ", "to", " ", "20", " ", 
     RowBox[{"(", 
      RowBox[{"21", " ", "values", " ", "in", " ", "total"}], ")"}]}]}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "FUNCTION", "*)"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fitfuncPbvector", "[", 
   RowBox[{"\[Epsilon]_", ",", "n_", ",", "Pb_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"fitvector", "=", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "l"}], " ", "\[Epsilon]"}], "]"}], 
       RowBox[{"(*", 
        RowBox[{"cost", " ", "of", " ", "environmental", " ", 
         RowBox[{"stress", ":", 
          RowBox[{
          "fitness", " ", "declines", " ", "exponentially", " ", "with", " ", 
           "stress"}]}]}], "*)"}], "*", 
       RowBox[{"(", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"ncost", " ", "n"}], "+", 
           RowBox[{"Pbcost", " ", "Pb"}]}], ")"}]}], ")"}], 
       RowBox[{"(*", 
        RowBox[{"cost", " ", "of", " ", "producing", " ", "more", " ", 
         RowBox[{"sRNA", ":", 
          RowBox[{
          "fitness", " ", "declines", " ", "close", " ", "to", " ", 
           "linearly", " ", "but", " ", "has", " ", "a", " ", "minimum", " ", 
           "of", " ", "0"}]}]}], "*)"}], 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"And", " ", "cost", " ", "of", " ", "changing", " ", "b"}], 
         ",", 
         RowBox[{
         "where", " ", "Pb", " ", "is", " ", "the", " ", "plasticity", " ", 
          "in", " ", "b"}]}], "*)"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"\[Beta]", "+", 
            RowBox[{"\[Alpha]", " ", "\[Epsilon]"}]}], ")"}]}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"E", "^", "n"}], "-", "1"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"E", "^", "n"}], "+", 
               RowBox[{"E", "^", "mid"}], "-", "2"}], ")"}]}], "-", 
            "\[Epsilon]"}], ")"}], "^", "2"}]}], "]"}]}]}], 
     RowBox[{"(*", 
      RowBox[{"benefit", " ", "of", " ", "matching", " ", "environment"}], 
      "*)"}], ";", "\[IndentingNewLine]", "fitvector"}]}], "]"}]}]}], "Input",\

 CellChangeTimes->{{3.8152891299826403`*^9, 3.815289129988291*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"d42ff67a-92e2-4f40-9439-612d08068b98"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "This", " ", "function", " ", "calculates", " ", "the", " ", "last", " ", 
     "adult", " ", "value", " ", "of", " ", "n", " ", "given", " ", "a", " ", 
     "number", " ", "of", " ", 
     RowBox[{"generations", ".", "Given"}], " ", "a", " ", "large", " ", 
     "enough", " ", "number", " ", "of", " ", "generations"}], ",", 
    RowBox[{
     RowBox[{
     "the", " ", "value", " ", "will", " ", "be", " ", "the", " ", "adult", 
      " ", "equilibrium", " ", 
      RowBox[{"value", ".", "this"}], " ", "function", " ", "returns", " ", 
      "the", " ", "value", " ", "of", " ", "n", " ", "at", " ", "time", " ", 
      "ngen"}], "-", 
     RowBox[{"1", " ", "and", " ", 
      RowBox[{"ngen", ".", "If"}], " ", "these", " ", "two", " ", "values", 
      " ", "are", " ", "equal"}]}], ",", 
    RowBox[{
    "the", " ", "system", " ", "has", " ", "reached", " ", "the", " ", 
     "equilibrium"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "overgenadulteq", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "FUNCTION", "*)"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"overgenadulteq", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"b_", ",", "d_", ",", "m_", ",", "\[Mu]_"}], "}"}], ",", 
      "Rgerm_", ",", "n0_", ",", "cellgen_", ",", "ngen_", ",", "speedeq_"}], 
     "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"adult", "[", "0", "]"}], "=", "n0"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", "ngen"}], ",", 
         RowBox[{"j", "++"}], ",", 
         RowBox[{
          RowBox[{"adult", "[", "j", "]"}], "=", 
          RowBox[{
           RowBox[{"Evaluate", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"n", "[", "t", "]"}], "/.", 
              RowBox[{"solution", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"b", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
                
                RowBox[{"Rgerm", " ", 
                 RowBox[{"adult", "[", 
                  RowBox[{"j", "-", "1"}], "]"}]}], ",", "cellgen", ",", 
                "speedeq"}], "]"}]}], "/.", 
             RowBox[{"t", "\[Rule]", "cellgen"}]}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"j", ",", 
            RowBox[{"adult", "[", "j", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "ngen"}], "}"}]}], "]"}], "*)"}], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"adult", "[", 
          RowBox[{"ngen", "-", "1"}], "]"}], ",", 
         RowBox[{"adult", "[", "ngen", "]"}]}], "}"}]}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.815289158568972*^9, 3.815289158575726*^9}, 
   3.8153873827311563`*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"ccb78194-b03f-4c52-bab4-cc68e6057341"],

Cell[BoxData[
 RowBox[{"overgenadulteq", "[", 
  RowBox[{
  "examplevalues", ",", "exampleRgerm", ",", "examplen0", ",", 
   "examplecellgen", ",", "examplengen", ",", "examplespeedeq"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.815289165887516*^9, 3.815289165894367*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"4d8d51aa-ae56-4503-bab1-6d05bd5a1727"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "bchangecellgen", "]"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "FUNCTION", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bchangecellgen", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"b_", ",", "d_", ",", "m_", ",", "\[Mu]_"}], "}"}], ",", "env_", 
    ",", "Pb_", ",", "n0_", ",", "ncelldivisions_", ",", "speedeq_"}], "]"}], 
  ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"Clear", "[", 
      RowBox[{"idealb", ",", "newb"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"btableW", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"testb", ",", 
          RowBox[{"fitfuncPb", "[", 
           RowBox[{"env", ",", 
            RowBox[{"Flatten", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Evaluate", "[", 
                RowBox[{
                 RowBox[{"n", "[", "t", "]"}], "/.", 
                 RowBox[{"solution", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"testb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                    "}"}], ",", "n0", ",", "ncelldivisions", ",", "speedeq"}],
                   "]"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"t", ",", "0", ",", "ncelldivisions"}], "}"}]}], 
              "]"}], "]"}], ",", "Pb"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"testb", ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", "10", ",", "0.001"}], "]"}], ",", "b"}], 
            "}"}], "]"}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"idealb", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Nearest", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"btableW", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{"Position", "[", 
               RowBox[{
                RowBox[{"btableW", "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
                RowBox[{"Max", "[", 
                 RowBox[{"btableW", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], "]"}], 
              "]"}], ",", "All"}], "]"}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", "b"}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"newb", "=", 
      RowBox[{"First", "[", 
       RowBox[{"b", "+", 
        RowBox[{"Pb", "*", 
         RowBox[{"(", 
          RowBox[{"idealb", "-", "b"}], ")"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "newb"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.815289173391337*^9, 3.815289173399094*^9}, {
  3.815387377160523*^9, 3.815387388894713*^9}, {3.815910174180807*^9, 
  3.8159101896391907`*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"f67ee56a-1e1a-48cc-b424-3bc9c2af0278"],

Cell[BoxData[
 RowBox[{"bchangecellgen", "[", 
  RowBox[{
  "examplevalues", ",", "exampleenv", ",", "examplePb", ",", "examplen0", ",",
    "examplecellgen", ",", "examplespeedeq"}], "]"}]], "Input",
 CellChangeTimes->{{3.815289179609725*^9, 3.81528917961705*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"f532c1d6-b0f8-420d-a1b2-72f0c6ea48de"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "selcoeff", "]"}], ";"}], "\n", 
  RowBox[{"(*", "FUNCTION", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"selcoeff", "[", 
   RowBox[{"fitmut_", ",", "fitwild_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"fitmut", "/", "fitwild"}], ")"}], "-", "1"}]}]}], "Input",
 CellChangeTimes->{{3.81528918696282*^9, 3.815289186969905*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"be314ea1-9fee-4596-bf34-920ce02ec6f5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "acrosswithingenPb", "]"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"UPDATED", " ", "FUNCTION"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "This", " ", "function", " ", "returns", " ", "tables", " ", "with", " ", 
    "the", " ", "dynamic", " ", "changes", " ", "in", " ", "n", " ", "and", 
    " ", "the", " ", "geometric", " ", "mean", " ", 
    RowBox[{"fitness", "."}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"output", "=", 
    RowBox[{"List", "[", 
     RowBox[{
     "input", ",", "envvector", ",", "interpolvalues", ",", "geofitness"}], 
     "]"}]}], "*)"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"acrosswithingenPb", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"b0_", ",", "d_", ",", "m_", ",", "\[Mu]_"}], "}"}], ",", 
    "Rgerm_", ",", "n0_", ",", "cellgen_", ",", "Pb_", ",", "envvector_", ",",
     "strategy_", ",", "speedeq_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"ngen", "=", 
      RowBox[{"Length", "[", "envvector", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"interpolvalues", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "ngen"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"cellgen", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fitness", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "ngen"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
        RowBox[{"In", " ", "strategy", " ", "A"}], "-", 
        RowBox[{"C", " ", 
         RowBox[{"(", "1", ")"}]}]}], ",", 
       RowBox[{
       "the", " ", "amplification", " ", "and", " ", "transmission", " ", 
        "rates", " ", "are", " ", "constant", " ", "across", " ", 
        RowBox[{"generations", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"strategy", "\[Equal]", "1"}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"zygoten", "=", "n0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"zygoteb", "=", "b0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"germlineb", "=", "b0"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"interpolvalues", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "All"}], "]"}], "]"}], "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{
               RowBox[{"n", "[", "t", "]"}], "/.", 
               RowBox[{"solution", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                  "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fitness", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", 
          RowBox[{"fitfuncPb", "[", 
           RowBox[{
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"interpolvalues", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}], ",", "Pb"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"zygoten", "=", 
              RowBox[{"Rgerm", " ", 
               RowBox[{"interpolvalues", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", 
                  RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"zygoteb", "=", "b0"}], ";", "\[IndentingNewLine]", 
             RowBox[{"germlineb", "=", "zygoteb"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"interpolvalues", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "All"}], "]"}], "]"}], "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Evaluate", "[", 
                  RowBox[{
                   RowBox[{"n", "[", "t", "]"}], "/.", 
                   RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                    "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                    "]"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"fitness", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"fitfuncPb", "[", 
               RowBox[{
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"interpolvalues", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "All"}], "]"}], "]"}], ",", "Pb"}], 
               "]"}]}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", "ngen"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"geofitness", "=", 
          RowBox[{"GeometricMean", "[", "fitness", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"input", "=", 
          RowBox[{"{", 
           RowBox[{
           "b0", ",", "d", ",", "m", ",", "\[Mu]", ",", "Rgerm", ",", "n0", 
            ",", "cellgen", ",", "Pb", ",", "strategy", ",", "speedeq"}], 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"output", "=", 
          RowBox[{"List", "[", 
           RowBox[{
           "input", ",", "envvector", ",", "interpolvalues", ",", 
            "geofitness"}], "]"}]}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"In", " ", "strategy", " ", "D", " ", 
        RowBox[{"(", "2", ")"}]}], ",", 
       RowBox[{
       "the", " ", "amplification", " ", "rate", " ", "in", " ", "the", " ", 
        "zygote", " ", "in", " ", "the", " ", "current", " ", "generation", 
        " ", "changes", " ", "from", " ", "the", " ", "baseline", " ", 
        "value", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"no", " ", "effect", " ", "across", " ", "generations"}], 
          ")"}], "."}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"strategy", "\[Equal]", "2"}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"zygoten", "=", "n0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"zygoteb", "=", 
          RowBox[{"bchangecellgen", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"b0", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Pb", ",", "zygoten", ",", 
            "cellgen", ",", "speedeq"}], "]"}]}], ";", "\[IndentingNewLine]", 
         
         RowBox[{"germlineb", "=", "b0"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"interpolvalues", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "All"}], "]"}], "]"}], "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{
               RowBox[{"n", "[", "t", "]"}], "/.", 
               RowBox[{"solution", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                  "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fitness", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", 
          RowBox[{"fitfuncPb", "[", 
           RowBox[{
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"interpolvalues", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}], ",", "Pb"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"zygoten", "=", 
              RowBox[{"Rgerm", " ", 
               RowBox[{"interpolvalues", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", 
                  RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"zygoteb", "=", 
              RowBox[{"bchangecellgen", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"b0", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", "Pb", ",", "zygoten", 
                ",", "cellgen", ",", "speedeq"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"germlineb", "=", "b0"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"interpolvalues", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "All"}], "]"}], "]"}], "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Evaluate", "[", 
                  RowBox[{
                   RowBox[{"n", "[", "t", "]"}], "/.", 
                   RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                    "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                    "]"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"fitness", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"fitfuncPb", "[", 
               RowBox[{
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"interpolvalues", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "All"}], "]"}], "]"}], ",", "Pb"}], 
               "]"}]}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", "ngen"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"geofitness", "=", 
          RowBox[{"GeometricMean", "[", "fitness", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"input", "=", 
          RowBox[{"{", 
           RowBox[{
           "b0", ",", "d", ",", "m", ",", "\[Mu]", ",", "Rgerm", ",", "n0", 
            ",", "cellgen", ",", "Pb", ",", "strategy", ",", "speedeq"}], 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"output", "=", 
          RowBox[{"List", "[", 
           RowBox[{
           "input", ",", "envvector", ",", "interpolvalues", ",", 
            "geofitness"}], "]"}]}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"In", " ", "strategy", " ", "E", " ", 
        RowBox[{"(", "3", ")"}]}], ",", 
       RowBox[{
       "the", " ", "amplification", " ", "rate", " ", "in", " ", "the", " ", 
        "zygote", " ", "in", " ", "the", " ", "current", " ", "generation", 
        " ", "changes", " ", "from", " ", "the", " ", "value", " ", "in", " ",
         "the", " ", "germline", " ", "of", " ", "the", " ", "previous", " ", 
        
        RowBox[{"generation", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"strategy", "\[Equal]", "3"}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"zygoten", "=", "n0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"zygoteb", "=", 
          RowBox[{"bchangecellgen", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"b0", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Pb", ",", "n0", ",", 
            "cellgen", ",", "speedeq"}], "]"}]}], ";", "\[IndentingNewLine]", 
         
         RowBox[{"germlineb", "=", "zygoteb"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"interpolvalues", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "All"}], "]"}], "]"}], "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{
               RowBox[{"n", "[", "t", "]"}], "/.", 
               RowBox[{"solution", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                  "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fitness", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", 
          RowBox[{"fitfuncPb", "[", 
           RowBox[{
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"interpolvalues", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}], ",", "Pb"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"zygoten", "=", 
              RowBox[{"Rgerm", " ", 
               RowBox[{"interpolvalues", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", 
                  RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"zygoteb", "=", 
              RowBox[{"bchangecellgen", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"germlineb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                 "}"}], ",", 
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", "Pb", ",", "zygoten", 
                ",", "cellgen", ",", "speedeq"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"germlineb", "=", "zygoteb"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"interpolvalues", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "All"}], "]"}], "]"}], "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Evaluate", "[", 
                  RowBox[{
                   RowBox[{"n", "[", "t", "]"}], "/.", 
                   RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                    "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                    "]"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"fitness", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"fitfuncPb", "[", 
               RowBox[{
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"interpolvalues", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "All"}], "]"}], "]"}], ",", "Pb"}], 
               "]"}]}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", "ngen"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"geofitness", "=", 
          RowBox[{"GeometricMean", "[", "fitness", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"input", "=", 
          RowBox[{"{", 
           RowBox[{
           "b0", ",", "d", ",", "m", ",", "\[Mu]", ",", "Rgerm", ",", "n0", 
            ",", "cellgen", ",", "Pb", ",", "strategy", ",", "speedeq"}], 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"output", "=", 
          RowBox[{"List", "[", 
           RowBox[{
           "input", ",", "envvector", ",", "interpolvalues", ",", 
            "geofitness"}], "]"}]}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"In", " ", "strategy", " ", "F", " ", 
        RowBox[{"(", "4", ")"}]}], ",", 
       RowBox[{
       "the", " ", "amplification", " ", "rate", " ", "in", " ", "the", " ", 
        "zygote", " ", "in", " ", "the", " ", "current", " ", "generation", 
        " ", "equals", " ", "the", " ", "amplification", " ", "rate", " ", 
        "in", " ", "the", " ", "germline", " ", "of", " ", "the", " ", 
        "previous", " ", 
        RowBox[{"generation", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"strategy", "\[Equal]", "4"}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"zygoten", "=", "n0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"zygoteb", "=", 
          RowBox[{"bchangecellgen", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"b0", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Pb", ",", "zygoten", ",", 
            "cellgen", ",", "speedeq"}], "]"}]}], ";", 
         RowBox[{"(*", 
          RowBox[{
          "Start", " ", "with", " ", "an", " ", "optimal", " ", "b", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Pb", "=", "1.0"}], ")"}], "."}]}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"germlineb", "=", "zygoteb"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"interpolvalues", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "All"}], "]"}], "]"}], "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{
               RowBox[{"n", "[", "t", "]"}], "/.", 
               RowBox[{"solution", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                  "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fitness", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", 
          RowBox[{"fitfuncPb", "[", 
           RowBox[{
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"interpolvalues", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}], ",", "Pb"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"zygoten", "=", 
              RowBox[{"Rgerm", " ", 
               RowBox[{"interpolvalues", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", 
                  RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"zygoteb", "=", "germlineb"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"germlineb", "=", 
              RowBox[{"bchangecellgen", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}],
                 ",", 
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", "Pb", ",", "zygoten", 
                ",", "cellgen", ",", "speedeq"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"interpolvalues", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "All"}], "]"}], "]"}], "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Evaluate", "[", 
                  RowBox[{
                   RowBox[{"n", "[", "t", "]"}], "/.", 
                   RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                    "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                    "]"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"fitness", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"fitfuncPb", "[", 
               RowBox[{
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"interpolvalues", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "All"}], "]"}], "]"}], ",", "Pb"}], 
               "]"}]}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", "ngen"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"geofitness", "=", 
          RowBox[{"GeometricMean", "[", "fitness", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"input", "=", 
          RowBox[{"{", 
           RowBox[{
           "b0", ",", "d", ",", "m", ",", "\[Mu]", ",", "Rgerm", ",", "n0", 
            ",", "cellgen", ",", "Pb", ",", "strategy", ",", "speedeq"}], 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"output", "=", 
          RowBox[{"List", "[", 
           RowBox[{
           "input", ",", "envvector", ",", "interpolvalues", ",", 
            "geofitness"}], "]"}]}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
          "strategy"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
        "output", "=", 
         "\"\<Biological strategy not valid. Select a valid strategy: 1 \
(A-C), 2 (D), 3 (E), 4 (F).\>\""}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "output"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.81528920200369*^9, 3.8152892020110292`*^9}, {
   3.815387144141039*^9, 3.81538720398866*^9}, 3.8159084611138563`*^9, 
   3.815908817468576*^9},
 CellLabel->"In[41]:=",ExpressionUUID->"d4ecdb80-5632-4114-9cc3-5b9f9c176442"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "Notify", "]"}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "This", " ", "function", " ", "should", " ", "be", " ", "put", " ", "at", 
     " ", "the", " ", "end", " ", "of", " ", "time"}], "-", 
    RowBox[{
    "consuming", " ", "calculations", " ", "so", " ", "that", " ", "you", " ",
      "are", " ", "notified", " ", "when", " ", "the", " ", "calculations", 
     " ", "are", " ", 
     RowBox[{"done", ".", "Remember"}], " ", "to", " ", "turn", " ", "up", 
     " ", "the", " ", 
     RowBox[{"volume", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "FUNCTION", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Notify", ":=", 
  RowBox[{
  "Speak", "[", 
   "\"\<Willian, your results are ready! You can now continue working!\>\"", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.815289209851067*^9, 3.8152892098578253`*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"56d74aea-63f8-4960-91fd-d1bf314f9b2d"],

Cell[BoxData["Notify"], "Input",
 CellChangeTimes->{{3.815289216986698*^9, 3.8152892169933157`*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"cf3bbcc0-1420-4094-b5b4-a6ccc3336179"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "acrosswithingenPbspeed", "]"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"UPDATED", " ", "FUNCTION", " ", "WITH", " ", "NON"}], "-", 
    RowBox[{"INSTANTANEOUS", " ", "PLASTICTY"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "This", " ", "function", " ", "returns", " ", "tables", " ", "with", " ", 
    "the", " ", "dynamic", " ", "changes", " ", "in", " ", "n", " ", "and", 
    " ", "the", " ", "geometric", " ", "mean", " ", 
    RowBox[{"fitness", "."}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"output", "=", 
    RowBox[{"List", "[", 
     RowBox[{
     "input", ",", "envvector", ",", "interpolvalues", ",", "geofitness"}], 
     "]"}]}], "*)"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"acrosswithingenPbspeed", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"b0_", ",", "d_", ",", "m_", ",", "\[Mu]_"}], "}"}], ",", 
    "Rgerm_", ",", "n0_", ",", "cellgen_", ",", "Pb_", ",", "Pbspeed_", ",", 
    "envvector_", ",", "strategy_", ",", "speedeq_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"ngen", "=", 
      RowBox[{"Length", "[", "envvector", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"interpolvalues", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "ngen"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"cellgen", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"fitness", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "ngen"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
        RowBox[{"In", " ", "strategy", " ", "A"}], "-", 
        RowBox[{"C", " ", 
         RowBox[{"(", "1", ")"}]}]}], ",", 
       RowBox[{
       "the", " ", "amplification", " ", "and", " ", "transmission", " ", 
        "rates", " ", "are", " ", "constant", " ", "across", " ", 
        RowBox[{"generations", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"strategy", "\[Equal]", "1"}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"zygoten", "=", "n0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"zygoteb", "=", "b0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"germlineb", "=", "b0"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"interpolvalues", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "All"}], "]"}], "]"}], "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{
               RowBox[{"n", "[", "t", "]"}], "/.", 
               RowBox[{"solution", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                  "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fitness", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", 
          RowBox[{"fitfuncPb", "[", 
           RowBox[{
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"interpolvalues", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}], ",", "Pb"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"zygoten", "=", 
              RowBox[{"Rgerm", " ", 
               RowBox[{"interpolvalues", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", 
                  RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"zygoteb", "=", "b0"}], ";", "\[IndentingNewLine]", 
             RowBox[{"germlineb", "=", "zygoteb"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"interpolvalues", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "All"}], "]"}], "]"}], "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Evaluate", "[", 
                  RowBox[{
                   RowBox[{"n", "[", "t", "]"}], "/.", 
                   RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                    "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                    "]"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"fitness", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"fitfuncPb", "[", 
               RowBox[{
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"interpolvalues", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "All"}], "]"}], "]"}], ",", "Pb"}], 
               "]"}]}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", "ngen"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"geofitness", "=", 
          RowBox[{"GeometricMean", "[", "fitness", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"input", "=", 
          RowBox[{"{", 
           RowBox[{
           "b0", ",", "d", ",", "m", ",", "\[Mu]", ",", "Rgerm", ",", "n0", 
            ",", "cellgen", ",", "Pb", ",", "strategy", ",", "speedeq"}], 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"output", "=", 
          RowBox[{"List", "[", 
           RowBox[{
           "input", ",", "envvector", ",", "interpolvalues", ",", 
            "geofitness"}], "]"}]}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"In", " ", "strategy", " ", "D", " ", 
        RowBox[{"(", "2", ")"}]}], ",", 
       RowBox[{
       "the", " ", "amplification", " ", "rate", " ", "in", " ", "the", " ", 
        "zygote", " ", "in", " ", "the", " ", "current", " ", "generation", 
        " ", "changes", " ", "from", " ", "the", " ", "baseline", " ", 
        "value", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"no", " ", "effect", " ", "across", " ", "generations"}], 
          ")"}], "."}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"strategy", "\[Equal]", "2"}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"zygoten", "=", "n0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"zygoteb", "=", 
          RowBox[{
           RowBox[{"bchangecellgen", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"b0", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
             RowBox[{"envvector", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "Pb", ",", "zygoten", ",", 
             "cellgen", ",", "speedeq"}], "]"}], "-", "b0"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"germlineb", "=", "b0"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"interpolvalues", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "All"}], "]"}], "]"}], "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{
               RowBox[{"n", "[", "t", "]"}], "/.", 
               RowBox[{"solution", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"b0", "+", 
                    RowBox[{"zygoteb", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "t"}], "*", "Pbspeed"}], "]"}]}], ")"}]}]}], 
                   ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", "zygoten", 
                 ",", "cellgen", ",", "speedeq"}], "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fitness", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", 
          RowBox[{"fitfuncPb", "[", 
           RowBox[{
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"interpolvalues", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}], ",", "Pb"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"zygoten", "=", 
              RowBox[{"Rgerm", " ", 
               RowBox[{"interpolvalues", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", 
                  RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"zygoteb", "=", 
              RowBox[{
               RowBox[{"bchangecellgen", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"b0", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], 
                 ",", 
                 RowBox[{"envvector", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", "Pb", ",", "zygoten", 
                 ",", "cellgen", ",", "speedeq"}], "]"}], "-", "b0"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"germlineb", "=", "b0"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"interpolvalues", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "All"}], "]"}], "]"}], "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Evaluate", "[", 
                  RowBox[{
                   RowBox[{"n", "[", "t", "]"}], "/.", 
                   RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"b0", "+", 
                    RowBox[{"zygoteb", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "t"}], "*", "Pbspeed"}], "]"}]}], ")"}]}]}], 
                    ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", "zygoten",
                     ",", "cellgen", ",", "speedeq"}], "]"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"fitness", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"fitfuncPb", "[", 
               RowBox[{
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"interpolvalues", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "All"}], "]"}], "]"}], ",", "Pb"}], 
               "]"}]}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", "ngen"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"geofitness", "=", 
          RowBox[{"GeometricMean", "[", "fitness", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"input", "=", 
          RowBox[{"{", 
           RowBox[{
           "b0", ",", "d", ",", "m", ",", "\[Mu]", ",", "Rgerm", ",", "n0", 
            ",", "cellgen", ",", "Pb", ",", "strategy", ",", "speedeq"}], 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"output", "=", 
          RowBox[{"List", "[", 
           RowBox[{
           "input", ",", "envvector", ",", "interpolvalues", ",", 
            "geofitness"}], "]"}]}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"In", " ", "strategy", " ", "E", " ", 
        RowBox[{"(", "3", ")"}]}], ",", 
       RowBox[{
       "the", " ", "amplification", " ", "rate", " ", "in", " ", "the", " ", 
        "zygote", " ", "in", " ", "the", " ", "current", " ", "generation", 
        " ", "changes", " ", "from", " ", "the", " ", "value", " ", "in", " ",
         "the", " ", "germline", " ", "of", " ", "the", " ", "previous", " ", 
        
        RowBox[{"generation", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"strategy", "\[Equal]", "3"}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"zygoten", "=", "n0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"zygoteb", "=", 
          RowBox[{
           RowBox[{"bchangecellgen", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"b0", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
             RowBox[{"envvector", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "Pb", ",", "n0", ",", 
             "cellgen", ",", "speedeq"}], "]"}], "-", "b0"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"germlineb", "=", 
          RowBox[{"b0", "+", 
           RowBox[{"zygoteb", "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"Exp", "[", 
               RowBox[{
                RowBox[{"-", "cellgen"}], "*", "Pbspeed"}], "]"}]}], 
             ")"}]}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"interpolvalues", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "All"}], "]"}], "]"}], "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{
               RowBox[{"n", "[", "t", "]"}], "/.", 
               RowBox[{"solution", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"b0", "+", 
                    RowBox[{"zygoteb", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "t"}], "*", "Pbspeed"}], "]"}]}], ")"}]}]}], 
                   ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", "zygoten", 
                 ",", "cellgen", ",", "speedeq"}], "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fitness", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", 
          RowBox[{"fitfuncPb", "[", 
           RowBox[{
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"interpolvalues", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}], ",", "Pb"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"zygoten", "=", 
              RowBox[{"Rgerm", " ", 
               RowBox[{"interpolvalues", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", 
                  RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"zygoteb", "=", 
              RowBox[{
               RowBox[{"bchangecellgen", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"germlineb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                  "}"}], ",", 
                 RowBox[{"envvector", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", "Pb", ",", "zygoten", 
                 ",", "cellgen", ",", "speedeq"}], "]"}], "-", "b0"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"germlineb", "=", 
              RowBox[{"b0", "+", 
               RowBox[{"zygoteb", "*", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"Exp", "[", 
                   RowBox[{
                    RowBox[{"-", "cellgen"}], "*", "Pbspeed"}], "]"}]}], 
                 ")"}]}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"interpolvalues", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "All"}], "]"}], "]"}], "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Evaluate", "[", 
                  RowBox[{
                   RowBox[{"n", "[", "t", "]"}], "/.", 
                   RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"b0", "+", 
                    RowBox[{"zygoteb", "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "t"}], "*", "Pbspeed"}], "]"}]}], ")"}]}]}], 
                    ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", "zygoten",
                     ",", "cellgen", ",", "speedeq"}], "]"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"fitness", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"fitfuncPb", "[", 
               RowBox[{
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"interpolvalues", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "All"}], "]"}], "]"}], ",", "Pb"}], 
               "]"}]}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", "ngen"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"geofitness", "=", 
          RowBox[{"GeometricMean", "[", "fitness", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"input", "=", 
          RowBox[{"{", 
           RowBox[{
           "b0", ",", "d", ",", "m", ",", "\[Mu]", ",", "Rgerm", ",", "n0", 
            ",", "cellgen", ",", "Pb", ",", "strategy", ",", "speedeq"}], 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"output", "=", 
          RowBox[{"List", "[", 
           RowBox[{
           "input", ",", "envvector", ",", "interpolvalues", ",", 
            "geofitness"}], "]"}]}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"In", " ", "strategy", " ", "F", " ", 
        RowBox[{"(", "4", ")"}]}], ",", 
       RowBox[{
       "the", " ", "amplification", " ", "rate", " ", "in", " ", "the", " ", 
        "zygote", " ", "in", " ", "the", " ", "current", " ", "generation", 
        " ", "equals", " ", "the", " ", "amplification", " ", "rate", " ", 
        "in", " ", "the", " ", "germline", " ", "of", " ", "the", " ", 
        "previous", " ", 
        RowBox[{"generation", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"strategy", "\[Equal]", "4"}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"zygoten", "=", "n0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"zygoteb", "=", 
          RowBox[{
           RowBox[{"bchangecellgen", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"b0", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", 
             RowBox[{"envvector", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "Pb", ",", "zygoten", ",", 
             "cellgen", ",", "speedeq"}], "]"}], "-", "b0"}]}], ";", 
         RowBox[{"(*", 
          RowBox[{
          "Start", " ", "with", " ", "an", " ", "optimal", " ", "b", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Pb", "=", "1.0"}], ")"}], "."}]}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"germlineb", "=", 
          RowBox[{"b0", "+", 
           RowBox[{"zygoteb", "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"Exp", "[", 
               RowBox[{
                RowBox[{"-", "cellgen"}], "*", "Pbspeed"}], "]"}]}], 
             ")"}]}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"interpolvalues", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "All"}], "]"}], "]"}], "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Evaluate", "[", 
              RowBox[{
               RowBox[{"n", "[", "t", "]"}], "/.", 
               RowBox[{"solution", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"b0", "+", "zygoteb"}], ",", "d", ",", "m", ",", 
                   "\[Mu]"}], "}"}], ",", "zygoten", ",", "cellgen", ",", 
                 "speedeq"}], "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"fitness", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", 
          RowBox[{"fitfuncPb", "[", 
           RowBox[{
            RowBox[{"envvector", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"interpolvalues", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}], ",", "Pb"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"zygoten", "=", 
              RowBox[{"Rgerm", " ", 
               RowBox[{"interpolvalues", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"i", "-", "1"}], ",", 
                  RowBox[{"cellgen", "+", "1"}]}], "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"zygoteb", "=", "germlineb"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"germlineb", "=", 
              RowBox[{"zygoteb", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"bchangecellgen", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                    "}"}], ",", 
                    RowBox[{"envvector", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "Pb", ",", "zygoten",
                     ",", "cellgen", ",", "speedeq"}], "]"}], "-", 
                  "zygoteb"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"Exp", "[", 
                   RowBox[{
                    RowBox[{"-", "cellgen"}], "*", "Pbspeed"}], "]"}]}], 
                 ")"}]}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"interpolvalues", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "All"}], "]"}], "]"}], "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Evaluate", "[", 
                  RowBox[{
                   RowBox[{"n", "[", "t", "]"}], "/.", 
                   RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"zygoteb", ",", "d", ",", "m", ",", "\[Mu]"}], 
                    "}"}], ",", "zygoten", ",", "cellgen", ",", "speedeq"}], 
                    "]"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"fitness", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"fitfuncPb", "[", 
               RowBox[{
                RowBox[{"envvector", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"interpolvalues", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "All"}], "]"}], "]"}], ",", "Pb"}], 
               "]"}]}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", "ngen"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"geofitness", "=", 
          RowBox[{"GeometricMean", "[", "fitness", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"input", "=", 
          RowBox[{"{", 
           RowBox[{
           "b0", ",", "d", ",", "m", ",", "\[Mu]", ",", "Rgerm", ",", "n0", 
            ",", "cellgen", ",", "Pb", ",", "strategy", ",", "speedeq"}], 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"output", "=", 
          RowBox[{"List", "[", 
           RowBox[{
           "input", ",", "envvector", ",", "interpolvalues", ",", 
            "geofitness"}], "]"}]}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
          "strategy"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
        "output", "=", 
         "\"\<Biological strategy not valid. Select a valid strategy: 1 \
(A-C), 2 (D), 3 (E), 4 (F).\>\""}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "output"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.815900794537951*^9, 3.815901025195437*^9}, {
   3.815901068759823*^9, 3.815901097496099*^9}, {3.8159012190560417`*^9, 
   3.8159012367681503`*^9}, {3.8159012777429*^9, 3.8159013110917683`*^9}, {
   3.8159013830364237`*^9, 3.8159014577605*^9}, {3.815901569827154*^9, 
   3.81590157095166*^9}, {3.815908481463052*^9, 3.815908483934596*^9}, {
   3.815908597753533*^9, 3.8159086070279913`*^9}, 3.815908811340035*^9},
 CellLabel->"In[46]:=",ExpressionUUID->"3153d8d4-8e6b-40b4-9d94-d929eaa8233b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Title",
 CellChangeTimes->{{3.8152892279694853`*^9, 
  3.815289229419649*^9}},ExpressionUUID->"68e888f4-3e1d-4b0d-9d05-\
d7f3c9545f70"],

Cell["\<\
n: sRNA level (amount).
b: (Density-dependent) amplification rate of sRNAs by RNA-dependent RNA \
polymerases, as a saturating function dependent on polymerase activity, \
b/(1+b n/m).
m: Maximum production rate of sRNAs at saturation level (maximum polymerase \
activity).
[Mu]: Transcription rate of sRNAs from nuclear DNA.
d: Degradation rate of sRNAs.
rgerm: Fraction of n that is transmitted to the next generations.
W: Logistic fitness function.
[Epsilon]: environmental condition.
cellgen (c=20): Number of cell divisions per generation.\
\>", "Text",
 CellChangeTimes->{{3.815289235813978*^9, 
  3.815289244338785*^9}},ExpressionUUID->"72f115f0-1b15-4db6-ad76-\
8bf1269bcf08"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dynamics of sRNA production within a generation", "Title",
 CellChangeTimes->{{3.815289256398148*^9, 
  3.8152892579017897`*^9}},ExpressionUUID->"ca85f9b0-5118-40f5-9b50-\
4f276d892300"],

Cell["\<\
The production of sRNAs follows the following pattern: D[n[t],t]=(b/(1+b \
n[t]/m)-d) n[t]+[Mu]\
\>", "Text",
 CellChangeTimes->{
  3.815289266162829*^9},ExpressionUUID->"2db96c8b-2f52-4d70-9e1a-\
28f21950f754"],

Cell[BoxData[
 RowBox[{"productionrate", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"speedeq", " ", "b"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"speedeq", " ", "b", " ", "n"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"speedeq", " ", "m"}], ")"}]}]}], ")"}]}], "/.", 
         RowBox[{"b", "\[Rule]", "0.1"}]}], "/.", 
        RowBox[{"m", "\[Rule]", "1"}]}], "/.", 
       RowBox[{"speedeq", "\[Rule]", "1.0"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "0", ",", "50"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Blue", ",", "Thick"}], "]"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<sRNA level (n)\>\"", ",", "\"\<Production rate\>\""}], 
      "}"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
    RowBox[{"FrameTicksStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "50"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815289276748457*^9, 3.8152892767573147`*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"1317de87-7b03-4b6f-b0ed-7b53c17dc59f"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{"\"\<a5si-productionrate.pdf\>\"", ",", "productionrate", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.815289366895438*^9, 3.8152893669006643`*^9}, {
  3.815295950724419*^9, 3.81529595381528*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"9b05c6fe-b483-47a2-b1e2-c6993c961892"],

Cell[BoxData[
 RowBox[{"devequilibria", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"speedeq", " ", "b"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"speedeq", " ", "b", " ", 
                RowBox[{"n", "[", "t", "]"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"speedeq", " ", "m"}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{"speedeq", " ", "d"}]}], ")"}], " ", 
        RowBox[{"n", "[", "t", "]"}]}], "+", 
       RowBox[{"speedeq", " ", "\[Mu]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{"n", "[", "t", "]"}]}], "]"}], "//", "Simplify", 
   RowBox[{"(*", 
    RowBox[{"Solve", " ", "for", " ", 
     RowBox[{"n", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"equilibrium", " ", 
       RowBox[{"Subscript", "[", 
        RowBox[{
         RowBox[{"Overscript", "[", 
          RowBox[{"n", ",", " ", "^"}], "]"}], ",", "w"}], "]"}], " ", 
       "within", " ", "a", " ", "generation"}], ")"}]}], "*)"}]}]}]], "Input",\

 CellChangeTimes->{{3.815289372578308*^9, 3.81528937258517*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"6b826bea-46fd-4893-a19c-ded0a50c2617"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{"\"\<a5si-devequilibria.pdf\>\"", ",", "devequilibria", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8152893790519733`*^9, 3.8152893790589733`*^9}, {
  3.8152959598225393`*^9, 3.815295962588738*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"0116a5d7-b8b3-4e6d-9cc6-fcec0c364e9a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"speedeq", " ", "b"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", " ", "+", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"speedeq", " ", "b", " ", 
                RowBox[{"n", "[", "t", "]"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"speedeq", " ", "m"}], ")"}]}]}], ")"}]}], " ", "-", 
          " ", 
          RowBox[{"speedeq", " ", "d"}]}], ")"}], " ", 
        RowBox[{"n", "[", "\n", "       ", "t", "]"}]}], " ", "+", " ", 
       RowBox[{"speedeq", " ", "\[Mu]"}]}], " ", "==", " ", "0"}], " ", "/.", 
     " ", "\n", "         ", 
     RowBox[{
      RowBox[{"n", "[", "t", "]"}], " ", "->", " ", 
      FormBox[
       SubscriptBox[
        OverscriptBox["n", "^"], "w"],
       TraditionalForm]}]}], ",", " ", "\[Mu]"}], "]"}], " ", "//", " ", 
  "FullSimplify", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Solve", " ", "\\\n", "for"}], " ", "\[Mu]"}], "*)"}]}]], "Input",\

 CellChangeTimes->{{3.815289384697692*^9, 3.8152893847049217`*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"1659b6ce-494b-418a-b1fe-e25a386c5596"],

Cell[BoxData[
 RowBox[{"solution", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.20", ",", "0.09", ",", "1.00", ",", "0.01"}], "}"}], ",", "0", 
   ",", "200", ",", "1.0"}], "]"}]], "Input",
 CellChangeTimes->{{3.8152893905862093`*^9, 3.815289390593707*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"634e6ed9-47c8-4ca8-8296-a89e5da88360"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wildtype parameter values", "Title",
 CellChangeTimes->{
  3.815289402294834*^9},ExpressionUUID->"928c9b19-1426-46d2-b7ce-\
0b812b7991df"],

Cell["\<\
The resident wildtype population is assumed to be adapted to environmental \
conditions fluctuating between [Epsilon]=0.1 and [Epsilon]=0.9 (with an \
average [Epsilon]=0.5).\
\>", "Text",
 CellChangeTimes->{
  3.815289410663602*^9},ExpressionUUID->"87009074-4e7d-4216-9e3b-\
a20a32363f6b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ngen", "=", "20"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wthomeenv", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0.1", ",", 
        RowBox[{"ngen", "/", "2"}]}], "]"}], ",", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0.9", ",", 
        RowBox[{"ngen", "/", "2"}]}], "]"}]}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtb", "=", "0.000"}], 
  RowBox[{"(*", 
   RowBox[{"no", " ", "amplification"}], "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtd", "=", "0.100"}], 
  RowBox[{"(*", 
   RowBox[{
   "degradation", " ", "rate", " ", "is", " ", "assumed", " ", "to", " ", 
    "be", " ", "an", " ", "intrisic", " ", "stability", " ", "property", " ", 
    "of", " ", "the", " ", "specific", " ", "sRNA", " ", "molecule", " ", 
    "under", " ", "focus"}], "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"wtm", "=", "5.000"}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"wtRgerm", "=", "0"}], 
  RowBox[{"(*", 
   RowBox[{"no", " ", "transmission"}], "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtPb", "=", "0"}], 
  RowBox[{"(*", 
   RowBox[{"no", " ", "responsiveness"}], "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtstrategy", "=", "1"}], 
  RowBox[{"(*", 
   RowBox[{"strategy", " ", "A"}], "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtcellgen", "=", "20"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtn0", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtspeedeq", "=", "1.0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.815289416964863*^9, 3.815289416971792*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"7641103b-d9a5-43ee-a407-34bfc43b1585"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Geometric", " ", "mean", " ", "fitness", " ", "for", " ", "different", 
      " ", "values", " ", "of", " ", "mu", " ", "under", " ", "fluctuating", 
      " ", "environmental", " ", "conditions", " ", "between", " ", 
      "\[Epsilon]"}], "=", 
     RowBox[{
      RowBox[{"0.1", " ", "and", " ", "\[Epsilon]"}], "=", 
      RowBox[{
       RowBox[{"0.9", ".", "Note"}], " ", "that", " ", "because", " ", "the", 
       " ", "wild", " ", "type", " ", "does", " ", "not", " ", "transmit", 
       " ", "information", " ", "across", " ", "generations"}]}]}], ",", 
    RowBox[{
    "the", " ", "pattern", " ", "of", " ", "the", " ", "environmental", " ", 
     "fluctuations", " ", "does", " ", "not", " ", 
     RowBox[{"matter", "."}]}]}], "*)"}], 
  RowBox[{"Now", "\n", 
   RowBox[{
    RowBox[{"bdmmunfite0109", "=", 
     RowBox[{"ParallelTable", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wtmu", ",", 
         RowBox[{
          RowBox[{"overgenadulteq", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",",
             "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "ngen", ",", 
            "wtspeedeq"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"GeometricMean", "[", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"ConstantArray", "[", 
              RowBox[{
               RowBox[{"fitfuncPb", "[", 
                RowBox[{"0.1", ",", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}],
                   "]"}], ",", "wtPb"}], "]"}], ",", 
               RowBox[{"ngen", "/", "2"}]}], "]"}], ",", 
             RowBox[{"ConstantArray", "[", 
              RowBox[{
               RowBox[{"fitfuncPb", "[", 
                RowBox[{"0.9", ",", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}],
                   "]"}], ",", "wtPb"}], "]"}], ",", 
               RowBox[{"ngen", "/", "2"}]}], "]"}]}], "}"}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"wtmu", ",", "0", ",", "10", ",", "0.001"}], "}"}]}], "]"}]}],
     ";"}], "\n", "Now"}]}]], "Input",
 CellChangeTimes->{{3.815289425592101*^9, 3.815289425599166*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"f868b017-da3e-4abe-91b3-36114ef753f0"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{"\"\<a5si-bdmmunfite0109.mx\>\"", ",", "bdmmunfite0109"}], "]"}], 
   ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.815289432137741*^9, 3.815289432146531*^9}, {
  3.815296046247426*^9, 3.815296048750641*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"f035ca3f-ccc5-4cf5-b601-1bc1bdf1a1d2"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"bdmmunfite0109", "=", 
    RowBox[{"Import", "[", "\"\<a5si-bdmmunfite0109.mx\>\"", "]"}]}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.815289438178773*^9, 3.815289438185899*^9}, {
  3.8152960503511972`*^9, 3.8152960527690353`*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"88f809fd-a887-4791-9fcc-8af47bfbdcb1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mumaxgeofit", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"bdmmunfite0109", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "3"}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Flatten", "[", 
  RowBox[{"Select", "[", 
   RowBox[{"bdmmunfite0109", ",", 
    RowBox[{
     RowBox[{"And", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "mumaxgeofit"}], "]"}], 
     "&"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.815289443816395*^9, 3.815289443824518*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"3ccccca5-fdf5-41d3-8779-a1f3725abfb8"],

Cell[BoxData[
 RowBox[{"wtmu", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Select", "[", 
     RowBox[{"bdmmunfite0109", ",", 
      RowBox[{
       RowBox[{"And", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "mumaxgeofit"}], "]"}], 
       "&"}]}], "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815289450133326*^9, 3.8152894501404943`*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"36fe7c4a-777c-4eb1-aef6-f443614fa184"],

Cell[BoxData[
 RowBox[{"wtnfinal", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",", 
       "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "wtPb", ",", 
       "wthomeenv", ",", "wtstrategy", ",", "wtspeedeq"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"wtcellgen", "+", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815289455743952*^9, 3.8152894557522373`*^9}},
 CellLabel->"In[79]:=",ExpressionUUID->"9f69ecf6-b26c-40b8-8cf0-283561541af6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wildtype parameter values for low stress environments", "Title",
 CellChangeTimes->{{3.815289470092882*^9, 
  3.8152894715089493`*^9}},ExpressionUUID->"ab5262e3-a773-4e5f-a0b7-\
028a76897a65"],

Cell[BoxData[{"Now", "\n", 
 RowBox[{
  RowBox[{"bdmmunfite01", "=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"wtmu", ",", 
       RowBox[{
        RowBox[{"overgenadulteq", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",", 
          "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "ngen", ",", 
          "wtspeedeq"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"GeometricMean", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ConstantArray", "[", 
            RowBox[{
             RowBox[{"fitfuncPb", "[", 
              RowBox[{"0.1", ",", 
               RowBox[{"Flatten", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Evaluate", "[", 
                   RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}], 
                "]"}], ",", "wtPb"}], "]"}], ",", 
             RowBox[{"ngen", "/", "2"}]}], "]"}], ",", 
           RowBox[{"ConstantArray", "[", 
            RowBox[{
             RowBox[{"fitfuncPb", "[", 
              RowBox[{"0.1", ",", 
               RowBox[{"Flatten", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Evaluate", "[", 
                   RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}], 
                "]"}], ",", "wtPb"}], "]"}], ",", 
             RowBox[{"ngen", "/", "2"}]}], "]"}]}], "}"}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"wtmu", ",", "0", ",", "10", ",", "0.001"}], "}"}]}], "]"}]}], 
  ";"}], "\n", "Now"}], "Input",
 CellChangeTimes->{{3.815289478516892*^9, 3.8152894785239897`*^9}, 
   3.815296382114547*^9},
 CellLabel->
  "In[392]:=",ExpressionUUID->"df02e9b7-5817-47d4-86eb-d66bfdc4e66d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mumaxgeofite01", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"bdmmunfite01", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "3"}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Flatten", "[", 
  RowBox[{"Select", "[", 
   RowBox[{"bdmmunfite01", ",", 
    RowBox[{
     RowBox[{"And", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "mumaxgeofite01"}], "]"}],
      "&"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8152894886190357`*^9, 3.8152894886262836`*^9}},
 CellLabel->
  "In[395]:=",ExpressionUUID->"cf1ad59d-80f0-479a-b0a7-f7489be90eb8"],

Cell[BoxData[
 RowBox[{"wtmue01", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Select", "[", 
     RowBox[{"bdmmunfite01", ",", 
      RowBox[{
       RowBox[{"And", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "mumaxgeofite01"}], 
        "]"}], "&"}]}], "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8152894935653877`*^9, 3.815289493573708*^9}},
 CellLabel->
  "In[397]:=",ExpressionUUID->"10da78a6-543a-4bc8-87c4-8faf2011da87"],

Cell[BoxData[
 RowBox[{"wtnfinale01", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmue01"}], "}"}], ",", 
       "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "wtPb", ",", 
       "wthomeenv", ",", "wtstrategy", ",", "wtspeedeq"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"wtcellgen", "+", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815289499620265*^9, 3.815289499629176*^9}},
 CellLabel->
  "In[398]:=",ExpressionUUID->"efcc5c6c-1ece-4518-9834-0268c53fd1e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wildtype parameter values for high stress environments", "Title",
 CellChangeTimes->{
  3.815289509166664*^9},ExpressionUUID->"408a7951-1f72-48b8-a823-\
9a83be54d04d"],

Cell[BoxData[{"Now", "\n", 
 RowBox[{
  RowBox[{"bdmmunfite09", "=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"wtmu", ",", 
       RowBox[{
        RowBox[{"overgenadulteq", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",", 
          "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "ngen", ",", 
          "wtspeedeq"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"GeometricMean", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ConstantArray", "[", 
            RowBox[{
             RowBox[{"fitfuncPb", "[", 
              RowBox[{"0.9", ",", 
               RowBox[{"Flatten", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Evaluate", "[", 
                   RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}], 
                "]"}], ",", "wtPb"}], "]"}], ",", 
             RowBox[{"ngen", "/", "2"}]}], "]"}], ",", 
           RowBox[{"ConstantArray", "[", 
            RowBox[{
             RowBox[{"fitfuncPb", "[", 
              RowBox[{"0.9", ",", 
               RowBox[{"Flatten", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Evaluate", "[", 
                   RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}], 
                "]"}], ",", "wtPb"}], "]"}], ",", 
             RowBox[{"ngen", "/", "2"}]}], "]"}]}], "}"}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"wtmu", ",", "0", ",", "10", ",", "0.001"}], "}"}]}], "]"}]}], 
  ";"}], "\n", "Now"}], "Input",
 CellChangeTimes->{{3.815289523247401*^9, 3.81528952325486*^9}, 
   3.8152963763739643`*^9},
 CellLabel->
  "In[399]:=",ExpressionUUID->"40707f0f-5142-4b87-8a8d-a0d570b18222"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mumaxgeofite09", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"bdmmunfite09", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "3"}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Flatten", "[", 
  RowBox[{"Select", "[", 
   RowBox[{"bdmmunfite09", ",", 
    RowBox[{
     RowBox[{"And", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "mumaxgeofite09"}], "]"}],
      "&"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.815289540389244*^9, 3.815289540397059*^9}},
 CellLabel->
  "In[402]:=",ExpressionUUID->"b8e11398-ce7a-4337-8cd3-c8d66094e36c"],

Cell[BoxData[
 RowBox[{"wtmue09", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Select", "[", 
     RowBox[{"bdmmunfite09", ",", 
      RowBox[{
       RowBox[{"And", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "mumaxgeofite09"}], 
        "]"}], "&"}]}], "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815289546203558*^9, 3.815289546211224*^9}},
 CellLabel->
  "In[404]:=",ExpressionUUID->"eb902c93-d4d2-4faf-91e7-fc8e846e8f8e"],

Cell[BoxData[
 RowBox[{"wtnfinale09", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmue09"}], "}"}], ",", 
       "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "wtPb", ",", 
       "wthomeenv", ",", "wtstrategy", ",", "wtspeedeq"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"wtcellgen", "+", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815289552403562*^9, 3.815289552410919*^9}},
 CellLabel->
  "In[405]:=",ExpressionUUID->"1567343c-3c66-463f-ba5b-47a6551cf2b3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wildtype parameter values for Rgerm=0.1", "Title",
 CellChangeTimes->{
  3.815289560979497*^9},ExpressionUUID->"75149c7d-6d81-4b54-bc23-\
529e6f7d1c48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rgerm01", "=", "0.1"}], ";"}]], "Input",
 CellChangeTimes->{{3.8152895698350277`*^9, 3.815289569841564*^9}},
 CellLabel->
  "In[406]:=",ExpressionUUID->"c97a08f1-42b8-478a-a2b4-402ff5a1233b"],

Cell[BoxData[{"Now", "\n", 
 RowBox[{
  RowBox[{"bdmmunfite0109Rgerm01", "=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"wtmu", ",", 
       RowBox[{
        RowBox[{"overgenadulteq", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",", 
          "Rgerm01", ",", "wtn0", ",", "wtcellgen", ",", "ngen", ",", 
          "wtspeedeq"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"GeometricMean", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ConstantArray", "[", 
            RowBox[{
             RowBox[{"fitfuncPb", "[", 
              RowBox[{"0.1", ",", 
               RowBox[{"Flatten", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Evaluate", "[", 
                   RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", 
                    RowBox[{"Rgerm01", "*", 
                    RowBox[{
                    RowBox[{"overgenadulteq", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "Rgerm01", ",", "wtn0", ",", "wtcellgen", ",",
                     "ngen", ",", "wtspeedeq"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ",", "wtcellgen", ",", 
                    "wtspeedeq"}], "]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}], 
                "]"}], ",", "wtPb"}], "]"}], ",", 
             RowBox[{"ngen", "/", "2"}]}], "]"}], ",", 
           RowBox[{"ConstantArray", "[", 
            RowBox[{
             RowBox[{"fitfuncPb", "[", 
              RowBox[{"0.9", ",", 
               RowBox[{"Flatten", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Evaluate", "[", 
                   RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", 
                    RowBox[{"Rgerm01", "*", 
                    RowBox[{
                    RowBox[{"overgenadulteq", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "Rgerm01", ",", "wtn0", ",", "wtcellgen", ",",
                     "ngen", ",", "wtspeedeq"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ",", "wtcellgen", ",", 
                    "wtspeedeq"}], "]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}], 
                "]"}], ",", "wtPb"}], "]"}], ",", 
             RowBox[{"ngen", "/", "2"}]}], "]"}]}], "}"}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"wtmu", ",", "0", ",", "10", ",", "0.001"}], "}"}]}], "]"}]}], 
  ";"}], "\n", "Now"}], "Input",
 CellChangeTimes->{{3.815289581514635*^9, 3.815289581521147*^9}, {
  3.815296365159028*^9, 3.815296365794566*^9}},
 CellLabel->
  "In[407]:=",ExpressionUUID->"fcb1d292-5246-44cf-811c-710652506640"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mumaxgeofite0109Rgerm01", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"bdmmunfite0109Rgerm01", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "3"}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Flatten", "[", 
  RowBox[{"Select", "[", 
   RowBox[{"bdmmunfite0109Rgerm01", ",", 
    RowBox[{
     RowBox[{"And", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", 
       "mumaxgeofite0109Rgerm01"}], "]"}], "&"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8152895889620323`*^9, 3.815289588968686*^9}},
 CellLabel->
  "In[410]:=",ExpressionUUID->"615fb6ca-fa85-4761-a965-1d88c99e4654"],

Cell[BoxData[
 RowBox[{"wtmue0109Rgerm01", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Select", "[", 
     RowBox[{"bdmmunfite0109Rgerm01", ",", 
      RowBox[{
       RowBox[{"And", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", 
         "mumaxgeofite0109Rgerm01"}], "]"}], "&"}]}], "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815289595252026*^9, 3.8152895952594423`*^9}},
 CellLabel->
  "In[412]:=",ExpressionUUID->"2bd9d94c-673a-41d0-b4da-5e38d1dd8ff2"],

Cell[BoxData[
 RowBox[{"wtnfinale0109Rgerm01", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmue0109Rgerm01"}], 
        "}"}], ",", "Rgerm01", ",", 
       RowBox[{"Rgerm01", "*", 
        RowBox[{
         RowBox[{"overgenadulteq", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmue0109Rgerm01"}], 
            "}"}], ",", "Rgerm01", ",", "wtn0", ",", "wtcellgen", ",", "ngen",
            ",", "wtspeedeq"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", "wtcellgen", ",", "wtPb", ",",
        "wthomeenv", ",", "wtstrategy", ",", "wtspeedeq"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"wtcellgen", "+", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815289604244475*^9, 3.815289604251759*^9}},
 CellLabel->
  "In[413]:=",ExpressionUUID->"66216dc7-3e5e-45be-bbb5-a905cd17204b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Why is mu for Rgerm=0.1 higher than mu for Rgerm=0?", "Title",
 CellChangeTimes->{3.815289627963347*^9, 
  3.8152901990516167`*^9},ExpressionUUID->"62163b02-2dcd-4a93-bfb7-\
4116de640474"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "sRNA", " ", "dynamics", " ", "for", " ", "wtmu", " ", "and", " ", 
    "wtRgerm"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"ndynRgerm0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",", 
       "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "wtPb", ",", 
       "wthomeenv", ",", "wtstrategy", ",", "wtspeedeq"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.815290200168841*^9, 3.815290204080234*^9}},
 CellLabel->
  "In[414]:=",ExpressionUUID->"57e4d12a-177e-45f6-87fa-6a92db5ce80e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "sRNA", " ", "dynamics", " ", "for", " ", "mu", " ", "when", " ", 
     "Rgerm"}], "=", "0.1"}], "*)"}], 
  RowBox[{"ndynRgerm01", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmue0109Rgerm01"}], 
        "}"}], ",", "Rgerm01", ",", 
       RowBox[{"Rgerm01", "*", 
        RowBox[{
         RowBox[{"overgenadulteq", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmue0109Rgerm01"}], 
            "}"}], ",", "Rgerm01", ",", "wtn0", ",", "wtcellgen", ",", "ngen",
            ",", "wtspeedeq"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", "wtcellgen", ",", "wtPb", ",",
        "wthomeenv", ",", "wtstrategy", ",", "wtspeedeq"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.815290211633016*^9, 3.815290211641156*^9}},
 CellLabel->
  "In[415]:=",ExpressionUUID->"fb3d02ea-a1b3-40d7-944a-32b8bc053581"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"sRNA", " ", "dynamics", " ", "when", " ", "Rgerm"}], "=", "0"}],
     ",", 
    RowBox[{
     RowBox[{"for", " ", "mu", " ", "when", " ", "Rgerm"}], "=", "0.1"}]}], 
   "*)"}], 
  RowBox[{"ndynmuRgerm01Rgerm0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmue0109Rgerm01"}], 
        "}"}], ",", "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "wtPb", 
       ",", "wthomeenv", ",", "wtstrategy", ",", "wtspeedeq"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8152902191816387`*^9, 3.8152902191888437`*^9}},
 CellLabel->
  "In[416]:=",ExpressionUUID->"3e339c7e-f6ea-44cb-bc89-ea1c94a769b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"sRNA", " ", "dynamics", " ", "when", " ", "Rgerm"}], "=", 
     "0.1"}], ",", 
    RowBox[{
     RowBox[{"for", " ", "mu", " ", "when", " ", "Rgerm"}], "=", "0"}]}], 
   "*)"}], 
  RowBox[{"ndynmuRgerm0Rgerm01", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",", 
       "Rgerm01", ",", 
       RowBox[{"Rgerm01", "*", 
        RowBox[{
         RowBox[{"overgenadulteq", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",", 
           "Rgerm01", ",", "wtn0", ",", "wtcellgen", ",", "ngen", ",", 
           "wtspeedeq"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", "wtcellgen", ",", "wtPb", ",",
        "wthomeenv", ",", "wtstrategy", ",", "wtspeedeq"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8152902274755373`*^9, 3.815290227482522*^9}},
 CellLabel->
  "In[417]:=",ExpressionUUID->"f505d355-0433-48ac-aade-10f431a1caf8"],

Cell[BoxData[{
 RowBox[{"fitfuncPbvector", "[", 
  RowBox[{"0.1", ",", "ndynRgerm0", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPbvector", "[", 
  RowBox[{"0.9", ",", "ndynRgerm0", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPb", "[", 
  RowBox[{"0.1", ",", "ndynRgerm0", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPb", "[", 
  RowBox[{"0.9", ",", "ndynRgerm0", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"GeometricMean", "[", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.1", ",", "ndynRgerm0", ",", "wtPb"}], "]"}], ",", "10"}], 
      "]"}], ",", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.9", ",", "ndynRgerm0", ",", "wtPb"}], "]"}], ",", "10"}], 
      "]"}]}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8152902342064953`*^9, 3.815290234213842*^9}},
 CellLabel->
  "In[418]:=",ExpressionUUID->"d53d0758-3897-42bf-afde-8f184399e727"],

Cell[BoxData[{
 RowBox[{"fitfuncPbvector", "[", 
  RowBox[{"0.1", ",", "ndynRgerm01", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPbvector", "[", 
  RowBox[{"0.9", ",", "ndynRgerm01", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPb", "[", 
  RowBox[{"0.1", ",", "ndynRgerm01", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPb", "[", 
  RowBox[{"0.9", ",", "ndynRgerm01", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"GeometricMean", "[", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.1", ",", "ndynRgerm01", ",", "wtPb"}], "]"}], ",", "10"}], 
      "]"}], ",", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.9", ",", "ndynRgerm01", ",", "wtPb"}], "]"}], ",", "10"}], 
      "]"}]}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.815290241605214*^9, 3.815290241612945*^9}},
 CellLabel->
  "In[423]:=",ExpressionUUID->"4292b21c-9835-4cc5-97a2-1ca27fc762f8"],

Cell[BoxData[{
 RowBox[{"fitfuncPbvector", "[", 
  RowBox[{"0.1", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPbvector", "[", 
  RowBox[{"0.9", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPb", "[", 
  RowBox[{"0.1", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPb", "[", 
  RowBox[{"0.9", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"GeometricMean", "[", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.1", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], "]"}], ",", 
       "10"}], "]"}], ",", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.9", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], "]"}], ",", 
       "10"}], "]"}]}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.81529024841004*^9, 3.8152902484187193`*^9}},
 CellLabel->
  "In[428]:=",ExpressionUUID->"9d1476c7-ad01-4a6d-a38d-3b46e665a1cb"],

Cell[BoxData[{
 RowBox[{"fitfuncPbvector", "[", 
  RowBox[{"0.1", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPbvector", "[", 
  RowBox[{"0.9", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPb", "[", 
  RowBox[{"0.1", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"fitfuncPb", "[", 
  RowBox[{"0.9", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], "]"}], "\n", 
 RowBox[{"GeometricMean", "[", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.1", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], "]"}], ",", 
       "10"}], "]"}], ",", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.9", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], "]"}], ",", 
       "10"}], "]"}]}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.815290255142425*^9, 3.815290255151267*^9}},
 CellLabel->
  "In[433]:=",ExpressionUUID->"bf07d010-2d58-4bf6-a1f1-be6a1183046b"],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{"ndynRgerm0", ",", "ndynRgerm0"}], "}"}], "]"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{"ndynRgerm01", ",", "ndynRgerm01"}], "}"}], "]"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"ListLinePlot", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{"ndynmuRgerm01Rgerm0", ",", "ndynmuRgerm01Rgerm0"}], 
              "}"}], "]"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", "Orange"}], ",", 
            RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
          RowBox[{"ListLinePlot", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{"ndynmuRgerm0Rgerm01", ",", "ndynmuRgerm0Rgerm01"}], 
              "}"}], "]"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", "Purple"}], ",", 
            RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ","}], "*)"}], 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Directive", "[", "Thick", "]"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Cell division\>\"", ",", "\"\<sRNA level\>\""}], 
          "}"}]}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
        RowBox[{"FrameTicksStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "42"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dotted"}], "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"21", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"21", ",", "70"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
       "]"}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"fitfuncPbvector", "[", 
              RowBox[{"0.1", ",", "ndynRgerm0", ",", "wtPb"}], "]"}], ",", 
             RowBox[{"fitfuncPbvector", "[", 
              RowBox[{"0.9", ",", "ndynRgerm0", ",", "wtPb"}], "]"}]}], "}"}],
            "]"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"fitfuncPbvector", "[", 
              RowBox[{"0.1", ",", "ndynRgerm01", ",", "wtPb"}], "]"}], ",", 
             RowBox[{"fitfuncPbvector", "[", 
              RowBox[{"0.9", ",", "ndynRgerm01", ",", "wtPb"}], "]"}]}], 
            "}"}], "]"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"ListLinePlot", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"fitfuncPbvector", "[", 
                RowBox[{"0.1", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], 
                "]"}], ",", 
               RowBox[{"fitfuncPbvector", "[", 
                RowBox[{"0.9", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], 
                "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", "Orange"}], ",", 
            RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
          RowBox[{"ListLinePlot", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"fitfuncPbvector", "[", 
                RowBox[{"0.1", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], 
                "]"}], ",", 
               RowBox[{"fitfuncPbvector", "[", 
                RowBox[{"0.9", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], 
                "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", "Purple"}], ",", 
            RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ","}], "*)"}], 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Directive", "[", "Thick", "]"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Cell division\>\"", ",", "\"\<Fitness\>\""}], "}"}]}], 
        ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
        RowBox[{"FrameTicksStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "42"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dotted"}], "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"21", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"21", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
       "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{"ndynRgerm0", ",", "ndynRgerm0"}], "}"}], "]"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{"ndynRgerm01", ",", "ndynRgerm01"}], "}"}], "]"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ","}], "*)"}], 
       RowBox[{
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{"ndynmuRgerm01Rgerm0", ",", "ndynmuRgerm01Rgerm0"}], 
            "}"}], "]"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Green"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{"ndynmuRgerm0Rgerm01", ",", "ndynmuRgerm0Rgerm01"}], 
            "}"}], "]"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Purple"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Directive", "[", "Thick", "]"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Cell division\>\"", ",", "\"\<sRNA level\>\""}], 
          "}"}]}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
        RowBox[{"FrameTicksStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "42"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dotted"}], "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"21", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"21", ",", "70"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
       "]"}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"fitfuncPbvector", "[", 
               RowBox[{"0.1", ",", "ndynRgerm0", ",", "wtPb"}], "]"}], ",", 
              RowBox[{"fitfuncPbvector", "[", 
               RowBox[{"0.9", ",", "ndynRgerm0", ",", "wtPb"}], "]"}]}], 
             "}"}], "]"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"fitfuncPbvector", "[", 
               RowBox[{"0.1", ",", "ndynRgerm01", ",", "wtPb"}], "]"}], ",", 
              RowBox[{"fitfuncPbvector", "[", 
               RowBox[{"0.9", ",", "ndynRgerm01", ",", "wtPb"}], "]"}]}], 
             "}"}], "]"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ","}], "*)"}], 
       RowBox[{
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"fitfuncPbvector", "[", 
              RowBox[{"0.1", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], "]"}],
              ",", 
             RowBox[{"fitfuncPbvector", "[", 
              RowBox[{"0.9", ",", "ndynmuRgerm01Rgerm0", ",", "wtPb"}], 
              "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Green"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
        RowBox[{"ListLinePlot", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"fitfuncPbvector", "[", 
              RowBox[{"0.1", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], "]"}],
              ",", 
             RowBox[{"fitfuncPbvector", "[", 
              RowBox[{"0.9", ",", "ndynmuRgerm0Rgerm01", ",", "wtPb"}], 
              "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Purple"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Directive", "[", "Thick", "]"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Cell division\>\"", ",", "\"\<Fitness\>\""}], "}"}]}], 
        ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
        RowBox[{"FrameTicksStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "42"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "Dotted"}], "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"21", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"21", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
       "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.815290277336239*^9, 3.815290277342704*^9}},
 CellLabel->
  "In[438]:=",ExpressionUUID->"4916e13b-55ec-453d-855e-d92c18794ddb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Developmental equilibrium (wildtype and mutants)", "Title",
 CellChangeTimes->{
  3.815290297060431*^9},ExpressionUUID->"98c9793e-4504-421d-a3fc-\
55965cfee2d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Test", " ", "different", " ", "parameter", " ", "values"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"biocond1", "=", 
     RowBox[{"{", 
      RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}]}], 
    RowBox[{"(*", 
     RowBox[{"b", ",", "d", ",", "m", ",", "\[Mu]"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"biocond2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.75", "*", "wtb"}], ",", 
       RowBox[{"0.75", "*", "wtd"}], ",", 
       RowBox[{"0.75", "*", "wtm"}], ",", 
       RowBox[{"0.75", "*", "wtmu"}]}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"biocond3", "=", 
     RowBox[{"{", 
      RowBox[{"0.1", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}]}], 
    RowBox[{"(*", 
     RowBox[{"Increased", " ", "RNA", " ", "polymerase", " ", "activity", " ", 
      RowBox[{"(", "m", ")"}]}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"biocond4", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.75", "*", "0.1"}], ",", 
       RowBox[{"0.75", "*", "wtd"}], ",", 
       RowBox[{"0.75", "*", "wtm"}], ",", 
       RowBox[{"0.75", "*", "wtmu"}]}], "}"}]}], 
    RowBox[{"(*", 
     RowBox[{"Increased", " ", "nuclear", " ", "production", " ", 
      RowBox[{"(", "\[Mu]", ")"}]}], "*)"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"biocond5", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "*", "wtb"}], ",", 
       RowBox[{"2", "*", "wtd"}], ",", 
       RowBox[{"2", "*", "wtm"}], ",", 
       RowBox[{"2", "*", "wtmu"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"biocond6", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "*", "0.1"}], ",", 
       RowBox[{"2", "*", "wtd"}], ",", 
       RowBox[{"2", "*", "wtm"}], ",", 
       RowBox[{"2", "*", "wtmu"}]}], "}"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.815290307741466*^9, 3.815290307748898*^9}, 
   3.815310548932931*^9, {3.821290687930764*^9, 3.821290731724565*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"81028b68-0b48-45cd-b15d-b0513555c3ef"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotequillegend", "=", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<Legend\>\"", ",", "Black", ",", "16"}], "]"}], "]"}], 
         ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<b\>\"", ",", "Black", ",", "16"}], "]"}], "]"}], ",", 
         
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<d\>\"", ",", "Black", ",", "16"}], "]"}], "]"}], ",", 
         
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<m\>\"", ",", "Black", ",", "16"}], "]"}], "]"}], ",", 
         
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\[Mu]\>\"", ",", "Black", ",", "16"}], "]"}], "]"}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Blue", 
         RowBox[{"(*", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"LineLegend", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Blue", ",", "Thick"}], "}"}], ",", 
              RowBox[{"{", "\"\<\>\"", "}"}], ",", 
              RowBox[{"LegendMarkers", "\[Rule]", "\"\<\>\""}], ",", 
              RowBox[{"LegendMarkerSize", "\[Rule]", "20"}]}], "]"}], ",", 
            "16"}], "]"}], "*)"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond1", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond1", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond1", "[", 
               RowBox[{"[", "3", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond1", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Red", 
         RowBox[{"(*", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"LineLegend", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Red", ",", "Thick"}], "}"}], ",", 
              RowBox[{"{", "\"\<\>\"", "}"}], ",", 
              RowBox[{"LegendMarkers", "\[Rule]", "\"\<\>\""}], ",", 
              RowBox[{"LegendMarkerSize", "\[Rule]", "20"}]}], "]"}], ",", 
            "16"}], "]"}], "*)"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond2", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond2", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond2", "[", 
               RowBox[{"[", "3", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond2", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Orange", 
         RowBox[{"(*", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"LineLegend", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Purple", ",", "Thick"}], "}"}], ",", 
              RowBox[{"{", "\"\<\>\"", "}"}], ",", 
              RowBox[{"LegendMarkers", "\[Rule]", "\"\<\>\""}], ",", 
              RowBox[{"LegendMarkerSize", "\[Rule]", "20"}]}], "]"}], ",", 
            "16"}], "]"}], "*)"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond3", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond3", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond3", "[", 
               RowBox[{"[", "3", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond3", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Purple", 
         RowBox[{"(*", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"LineLegend", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Purple", ",", "Thick"}], "}"}], ",", 
              RowBox[{"{", "\"\<\>\"", "}"}], ",", 
              RowBox[{"LegendMarkers", "\[Rule]", "\"\<\>\""}], ",", 
              RowBox[{"LegendMarkerSize", "\[Rule]", "20"}]}], "]"}], ",", 
            "16"}], "]"}], "*)"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond4", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond4", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond4", "[", 
               RowBox[{"[", "3", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond4", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"Pink", 
         RowBox[{"(*", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"LineLegend", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Purple", ",", "Thick"}], "}"}], ",", 
              RowBox[{"{", "\"\<\>\"", "}"}], ",", 
              RowBox[{"LegendMarkers", "\[Rule]", "\"\<\>\""}], ",", 
              RowBox[{"LegendMarkerSize", "\[Rule]", "20"}]}], "]"}], ",", 
            "16"}], "]"}], "*)"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond5", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond5", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond5", "[", 
               RowBox[{"[", "3", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond5", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"Cyan", 
         RowBox[{"(*", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"LineLegend", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Purple", ",", "Thick"}], "}"}], ",", 
              RowBox[{"{", "\"\<\>\"", "}"}], ",", 
              RowBox[{"LegendMarkers", "\[Rule]", "\"\<\>\""}], ",", 
              RowBox[{"LegendMarkerSize", "\[Rule]", "20"}]}], "]"}], ",", 
            "16"}], "]"}], "*)"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond6", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond6", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond6", "[", 
               RowBox[{"[", "3", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"NumberForm", "[", 
             RowBox[{
              RowBox[{"biocond6", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", "4"}], "]"}], ",", 
            "Black", ",", "16"}], "]"}], "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "All"}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick"}], "]"}]}], ",", 
     RowBox[{"Spacings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.5", ",", "0.3"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"Inset", "[", 
     RowBox[{"plotequillegend", ",", 
      RowBox[{"{", 
       RowBox[{"165", ",", "13"}], "}"}]}], "]"}]}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.815290317533985*^9, 3.8152903175424957`*^9}, {
  3.821291151532805*^9, 3.82129120295568*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"488642f5-0e13-4af9-b145-50fbe23ff229"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "cellgen", "]"}], ";", 
  RowBox[{"cellgen", "=", "150"}], ";", 
  RowBox[{"speedeq", "=", "wtspeedeq"}], ";"}], "\n", 
 RowBox[{"plotequilwtmut", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", 
        RowBox[{"solution", "[", 
         RowBox[{"biocond1", ",", "0", ",", "cellgen", ",", "speedeq"}], 
         "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", 
        RowBox[{"solution", "[", 
         RowBox[{"biocond1", ",", "0", ",", "cellgen", ",", "0.75"}], "]"}]}],
        "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Red", "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", 
        RowBox[{"solution", "[", 
         RowBox[{"biocond3", ",", "0", ",", "cellgen", ",", "speedeq"}], 
         "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Orange", ",", "Dashed"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", 
        RowBox[{"solution", "[", 
         RowBox[{"biocond3", ",", "0", ",", "cellgen", ",", "0.75"}], "]"}]}],
        "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Purple", ",", "Dashed"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", 
        RowBox[{"solution", "[", 
         RowBox[{"biocond1", ",", "0", ",", "cellgen", ",", "2"}], "]"}]}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Pink", "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"n", "[", "t", "]"}], "/.", 
        RowBox[{"solution", "[", 
         RowBox[{"biocond3", ",", "0", ",", "cellgen", ",", "2"}], "]"}]}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "cellgen"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Cyan", ",", "Dashed"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Blue", ",", "Thick"}], "]"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Cell generation\>\"", ",", "\"\<sRNA level (n)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
    RowBox[{"FrameTicksStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "cellgen"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"Inset", "[", 
      RowBox[{"plotequillegend", ",", 
       RowBox[{"{", 
        RowBox[{"110", ",", "30"}], "}"}]}], "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8152903273841753`*^9, 3.815290327390873*^9}, {
  3.820218804524963*^9, 3.820218806184708*^9}, {3.821290859457349*^9, 
  3.821290884268445*^9}, {3.821290921962809*^9, 3.821290926588648*^9}, {
  3.821290961818733*^9, 3.821290962574624*^9}, {3.821291070511841*^9, 
  3.8212911186637707`*^9}, {3.821300559035408*^9, 3.821300575102181*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"0085c0ce-75a4-400b-8852-dc8cc83134d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<a5si-plotequilwtmut.pdf\>\"", ",", "plotequilwtmut", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815290334223709*^9, 3.815290334231162*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"a1d4ffa9-3a52-4f73-b70d-81f9ff063b17"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dynamics of sRNA production across generations (wildtype)", "Title",
 CellChangeTimes->{{3.8152903437279463`*^9, 
  3.81529034448221*^9}},ExpressionUUID->"42ee50a8-3e7b-4eb1-8a8c-\
b37d478076eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"biocond", "=", 
   RowBox[{"{", 
    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.815290352594531*^9, 3.815290352601519*^9}},
 CellLabel->
  "In[446]:=",ExpressionUUID->"f5aa6522-636d-4781-a8f1-6f2c3fa94368"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ylim", "=", 
   RowBox[{"1.15", " ", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"n", "[", "t", "]"}], "/.", 
          RowBox[{"solution", "[", 
           RowBox[{"biocond", ",", "0", ",", "40", ",", "1.0"}], "]"}]}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "40"}], "}"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", "41", "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815290359106563*^9, 3.815290359113989*^9}},
 CellLabel->
  "In[447]:=",ExpressionUUID->"92b4834e-2999-4774-a5ba-d232ef596fc3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Function", ":", 
    RowBox[{"acrosswithingen1condplot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"b", ",", "d", ",", "m", ",", "\[Mu]"}], "}"}], ",", "n0", ",",
       "Rgerm", ",", "ngen", ",", "cellgen", ",", "ylim", ",", "color", ",", 
      "speedeq"}], "]"}]}], "*)"}], 
  RowBox[{"rgermcellgenplotswt", "=", 
   RowBox[{"Grid", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"acrosswithingen1condplot", "[", 
         RowBox[{
         "biocond", ",", "0", ",", "0", ",", "10", ",", "10", ",", "ylim", 
          ",", "Red", ",", "wtspeedeq"}], "]"}], ",", 
        RowBox[{"acrosswithingen1condplot", "[", 
         RowBox[{
         "biocond", ",", "0", ",", "0.5", ",", "10", ",", "10", ",", "ylim", 
          ",", "Blue", ",", "wtspeedeq"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"acrosswithingen1condplot", "[", 
         RowBox[{
         "biocond", ",", "0", ",", "0", ",", "10", ",", "20", ",", "ylim", 
          ",", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Dashed"}], "}"}], ",", "wtspeedeq"}], "]"}], 
        ",", 
        RowBox[{"acrosswithingen1condplot", "[", 
         RowBox[{
         "biocond", ",", "0", ",", "0.5", ",", "10", ",", "20", ",", "ylim", 
          ",", "Blue", ",", "wtspeedeq"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"acrosswithingen1condplot", "[", 
         RowBox[{
         "biocond", ",", "0", ",", "0", ",", "10", ",", "40", ",", "ylim", 
          ",", "Red", ",", "wtspeedeq"}], "]"}], ",", 
        RowBox[{"acrosswithingen1condplot", "[", 
         RowBox[{
         "biocond", ",", "0", ",", "0.5", ",", "10", ",", "40", ",", "ylim", 
          ",", "Blue", ",", "wtspeedeq"}], "]"}]}], "}"}]}], "}"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.815290367696945*^9, 3.815290367704412*^9}},
 CellLabel->
  "In[448]:=",ExpressionUUID->"b854227b-ccd4-435b-90c9-2d5fe5befbde"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-rgermcellgenplotswt.pdf\>\"", ",", "rgermcellgenplotswt", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815290376687484*^9, 3.815290376694824*^9}},
 CellLabel->
  "In[151]:=",ExpressionUUID->"f68e21c7-34b2-4b3a-a6f4-ecde1eddcbe5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["sRNA production by b and d (wildtype m and \[Mu])", "Title",
 CellChangeTimes->{
  3.815290400805861*^9, {3.8153106028970737`*^9, 
   3.815310606412876*^9}},ExpressionUUID->"b22f87d7-0237-4c44-a4ab-\
0490430799fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "The", " ", "following", " ", "calculates", " ", "the", " ", "adult", " ",
      "equilibrium", " ", "n", " ", "for", " ", "several", " ", 
     "combinations", " ", "of", " ", "b"}], ",", 
    RowBox[{
    "d", " ", "and", " ", "m", " ", "after", " ", "ngen", " ", "generations", 
     " ", "of", " ", "cellgen", " ", "cell", " ", "divisions"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ngen", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"bvalues", "=", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "5", ",", "0.005"}], "]"}]}], 
    RowBox[{"(*", 
     RowBox[{
     "Range", " ", "of", " ", "b", " ", "used", " ", "in", " ", "the", " ", 
      "simulations"}], "*)"}], ";", 
    RowBox[{"dvalues", "=", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "1", ",", "0.01"}], "]"}]}], 
    RowBox[{"(*", 
     RowBox[{
     "Range", " ", "of", " ", "d", " ", "used", " ", "in", " ", "the", " ", 
      "simulations"}], "*)"}], ";", 
    RowBox[{"mvalues", "=", 
     RowBox[{"{", "wtm", "}"}]}], 
    RowBox[{"(*", 
     RowBox[{
     "Range", " ", "of", " ", "m", " ", "used", " ", "in", " ", "the", " ", 
      "simulations"}], "*)"}], ";", 
    RowBox[{"muvalues", "=", 
     RowBox[{"{", "wtmu", "}"}]}], 
    RowBox[{"(*", 
     RowBox[{
     "Range", " ", "of", " ", "m", " ", "used", " ", "in", " ", "the", " ", 
      "simulations"}], "*)"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.815293263480342*^9, 3.8152932634883757`*^9}, 
   3.815310611825923*^9},
 CellLabel->
  "In[154]:=",ExpressionUUID->"055602f0-220a-4963-b422-57e7471e5681"],

Cell[BoxData[{"Now", "\n", 
 RowBox[{
  RowBox[{"bdmmun", "=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"bvalues", "[", 
        RowBox[{"[", "b", "]"}], "]"}], ",", 
       RowBox[{"dvalues", "[", 
        RowBox[{"[", "d", "]"}], "]"}], ",", 
       RowBox[{"mvalues", "[", 
        RowBox[{"[", "m", "]"}], "]"}], ",", 
       RowBox[{"muvalues", "[", 
        RowBox[{"[", "mu", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"overgenadulteq", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"bvalues", "[", 
             RowBox[{"[", "b", "]"}], "]"}], ",", 
            RowBox[{"dvalues", "[", 
             RowBox[{"[", "d", "]"}], "]"}], ",", 
            RowBox[{"mvalues", "[", 
             RowBox[{"[", "m", "]"}], "]"}], ",", 
            RowBox[{"muvalues", "[", 
             RowBox[{"[", "mu", "]"}], "]"}]}], "}"}], ",", "wtRgerm", ",", 
          "wtn0", ",", "wtcellgen", ",", "ngen", ",", "wtspeedeq"}], "]"}], 
        "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"overgenadulteq", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"bvalues", "[", 
             RowBox[{"[", "b", "]"}], "]"}], ",", 
            RowBox[{"dvalues", "[", 
             RowBox[{"[", "d", "]"}], "]"}], ",", 
            RowBox[{"mvalues", "[", 
             RowBox[{"[", "m", "]"}], "]"}], ",", 
            RowBox[{"muvalues", "[", 
             RowBox[{"[", "mu", "]"}], "]"}]}], "}"}], ",", "wtRgerm", ",", 
          "wtn0", ",", "wtcellgen", ",", "ngen", ",", "wtspeedeq"}], "]"}], 
        "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", 
       RowBox[{"Length", "[", "bvalues", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", 
       RowBox[{"Length", "[", "dvalues", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"Length", "[", "mvalues", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"mu", ",", 
       RowBox[{"Length", "[", "muvalues", "]"}]}], "}"}]}], "]"}]}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Table", " ", "to", " ", "store", " ", "b"}], ",", "d", ",", 
    RowBox[{
    "m", " ", "and", " ", "mu", " ", "and", " ", "their", " ", "respective", 
     " ", "n"}]}], "*)"}], ";"}], "\n", "Now"}], "Input",
 CellChangeTimes->{{3.815293270690255*^9, 3.815293270697254*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"a979a5cf-0f48-4fa3-b879-68c898a06201"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bdmmun", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"bdmmun", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8152932768693953`*^9, 3.815293276876992*^9}},
 CellLabel->
  "In[159]:=",ExpressionUUID->"17ddd05c-779f-4be0-a4a8-b88a5a69634d"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
    "\"\<a5si-bdmmun-wtcellgen-b0to5-d0to1-wtm-wtmu-wtrgerm-wtn0.mx\>\"", ",",
      "bdmmun"}], "]"}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.81529328356882*^9, 3.815293283574184*^9}, {
  3.8153110360659018`*^9, 
  3.815311039085691*^9}},ExpressionUUID->"3cb58b30-eaf5-4fde-abe5-\
eec645983962"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"bdmmun", "=", 
    RowBox[{
    "Import", "[", 
     "\"\<a5si-bdmmun-wtcellgen-b0to5-d0to1-wtm-wtmu-wtrgerm-wtn0.mx\>\"", 
     "]"}]}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.815293290400373*^9, 3.8152932904083643`*^9}, {
  3.815311041156527*^9, 
  3.8153110439938393`*^9}},ExpressionUUID->"b320b8c9-667d-47ab-a1de-\
394951d10086"],

Cell[BoxData[
 RowBox[{"Length", "[", "bdmmun", "]"}]], "Input",
 CellChangeTimes->{{3.8152932963687553`*^9, 3.815293296374799*^9}},
 CellLabel->
  "In[160]:=",ExpressionUUID->"42f438b7-d988-4c23-b580-1d22bd4b7c0f"],

Cell[CellGroupData[{

Cell["Production plot", "Chapter",
 CellChangeTimes->{
  3.8152933098012733`*^9},ExpressionUUID->"0168e2ef-a573-4bc1-b139-\
ed55eaf81735"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"bdmmun", "=", 
    RowBox[{
    "Import", "[", 
     "\"\<a5si-bdmmun-wtcellgen-b0to5-d0to1-wtm-wtmu-wtrgerm-wtn0.mx\>\"", 
     "]"}]}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.815293319980637*^9, 3.815293319989821*^9}, {
  3.815311049936243*^9, 
  3.8153110538811417`*^9}},ExpressionUUID->"474cf568-d7db-4447-a779-\
d2d92850918b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nprodplotdata", "=", 
   RowBox[{"bdmmun", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "6"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.815293327218801*^9, 3.815293327226626*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"34a2df77-4079-4d2f-8b9c-9a3d695bb391"],

Cell[BoxData[
 RowBox[{"bdmmunplot", "=", 
  RowBox[{"ListContourPlot", "[", 
   RowBox[{"nprodplotdata", ",", 
    RowBox[{"Contours", "\[Rule]", "20"}], ",", 
    RowBox[{"ContourStyle", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}], "[", 
        RowBox[{"Rescale", "[", 
         RowBox[{"#", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"Max", "[", 
             RowBox[{"nprodplotdata", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "3"}], "]"}], "]"}], "]"}]}], "}"}]}], 
         "]"}], "]"}], "&"}], ")"}]}], ",", 
    RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<b\>\"", ",", "\"\<d\>\""}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
    RowBox[{"FrameTicksStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{
       RowBox[{"BarLegend", "[", 
        RowBox[{"Automatic", ",", "20", ",", 
         RowBox[{"LegendMarkerSize", "\[Rule]", "300"}], ",", 
         RowBox[{"LegendLabel", "\[Rule]", "\"\<n\>\""}], ",", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"Black", ",", "20"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"After", ",", "Top"}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815293333720888*^9, 3.815293333726255*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"6ec20ff3-46b6-4af0-8a89-662cd26fa177"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<a5si-bdn.png\>\"", ",", "bdmmunplot", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815293343951552*^9, 3.815293343957892*^9}},
 CellLabel->
  "In[163]:=",ExpressionUUID->"59337bd6-1d16-41ee-a604-3126b1fa2d31"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fitness", "Title",
 CellChangeTimes->{
  3.815293352852749*^9},ExpressionUUID->"e0ab9a17-d3a8-4031-a328-\
043d82f6d251"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Beta]", "=", "0.1"}], 
  RowBox[{"(*", "0.1", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", "15"}], 
  RowBox[{"(*", "4", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"l", "=", "0"}], 
  RowBox[{"(*", "0", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ncost", "=", "0.00001"}], 
  RowBox[{"(*", "0.005", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Pbcost", "=", 
   RowBox[{"50", " ", "ncost"}]}], 
  RowBox[{"(*", 
   RowBox[{"2", " ", "ncost"}], "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mid", "=", "5"}], 
  RowBox[{"(*", "5", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.815293359385498*^9, 3.8152933593923903`*^9}},
 CellLabel->
  "In[449]:=",ExpressionUUID->"d16336b2-a554-4706-bd49-b89848bb006a"],

Cell[CellGroupData[{

Cell["Fitness as a function of n and [Epsilon]", "Chapter",
 CellChangeTimes->{
  3.815293369742388*^9},ExpressionUUID->"9c7653b2-e85a-4296-acb8-\
a912def0f393"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"n1", "=", "10"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Epsilon]0", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Epsilon]1", "=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8152933786641827`*^9, 3.8152933786716347`*^9}},
 CellLabel->
  "In[455]:=",ExpressionUUID->"75710748-e3b0-4248-bdb4-90f5d73cefdd"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Pb", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtpointsenv01", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"wtdynamics", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "wtdynamics", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"wtpointsenv09", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"wtdynamics", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "0.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "wtdynamics", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"fitnessfunctionplotnePb0", "=", 
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{"fitfuncPb", "[", 
     RowBox[{"\[Epsilon]", ",", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"n", ",", 
        RowBox[{"wtcellgen", "+", "1"}]}], "]"}], ",", "Pb"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "n0", ",", "n1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "\[Epsilon]0", ",", "\[Epsilon]1"}], "}"}], 
    ",", 
    RowBox[{"Contours", "\[Rule]", "50"}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}], "[", 
        RowBox[{"Rescale", "[", 
         RowBox[{"#", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], "&"}], ")"}]}], 
    ",", 
    RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<sRNA level (n)\>\"", ",", 
       "\"\<Environmental condition (\[Epsilon])\>\""}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
    RowBox[{"FrameTicksStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"BarLegend", "[", 
          RowBox[{"Automatic", ",", 
           RowBox[{"LegendMarkerSize", "\[Rule]", "300"}], ",", 
           RowBox[{"LegendLabel", "\[Rule]", "\"\<Fitness (W)\>\""}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Black", ",", "16"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"After", ",", "Top"}], "}"}]}], "]"}]}], ","}], "*)"}], 
    RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], 
   RowBox[{"(*", 
    RowBox[{",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
          RowBox[{"Point", "[", "wtpointsenv01", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
          RowBox[{"Point", "[", "wtpointsenv09", "]"}]}], "}"}]}], "}"}]}]}], 
    "*)"}], 
   RowBox[{"(*", 
    RowBox[{",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Dashed"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"wildtypen", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"wildtypen", ",", "1.0"}], "}"}]}], "}"}], "]"}]}], 
       "}"}]}]}], "*)"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8152933865298033`*^9, 3.815293386537673*^9}, {
  3.815311114539248*^9, 3.815311120759907*^9}},
 CellLabel->
  "In[459]:=",ExpressionUUID->"29634695-ab27-4552-a4d5-39918fe1013f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-fitnessfunctionplotnePb0.pdf\>\"", ",", 
    "fitnessfunctionplotnePb0", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8152933956836576`*^9, 3.815293395691215*^9}, {
  3.815311154407248*^9, 3.815311160419986*^9}},
 CellLabel->
  "In[185]:=",ExpressionUUID->"7e76f2be-4444-4054-ae25-82889febdf51"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Pb", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Pbmutantpointsenv01", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Pbmutantdynamics", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "i"}], "]"}], "]"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "wtdynamics", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Pbmutantpointsenv09", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Pbmutantdynamics", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "i"}], "]"}], "]"}], ",", "0.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "wtdynamics", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"fitnessfunctionplotnePb1", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"fitfuncPb", "[", 
      RowBox[{"\[Epsilon]", ",", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"n", ",", 
         RowBox[{"wtcellgen", "+", "1"}]}], "]"}], ",", "Pb"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "n0", ",", "n1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "\[Epsilon]0", ",", "\[Epsilon]1"}], "}"}], 
     ",", 
     RowBox[{"Contours", "\[Rule]", "50"}], ",", 
     RowBox[{"ContourLabels", "\[Rule]", "None"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}], "[", 
         RowBox[{"Rescale", "[", 
          RowBox[{"#", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], "&"}], ")"}]}], 
     ",", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<sRNA level (n)\>\"", ",", 
        "\"\<Environmental condition (\[Epsilon])\>\""}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"Placed", "[", 
       RowBox[{
        RowBox[{"BarLegend", "[", 
         RowBox[{"Automatic", ",", 
          RowBox[{"LegendMarkerSize", "\[Rule]", "300"}], ",", 
          RowBox[{"LegendLabel", "\[Rule]", "\"\<Fitness (W)\>\""}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "16"}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"After", ",", "Top"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], 
    RowBox[{"(*", 
     RowBox[{",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
           RowBox[{"Point", "[", "Pbmutantpointsenv01", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
           RowBox[{"Point", "[", "Pbmutantpointsenv09", "]"}]}], "}"}]}], 
        "}"}]}]}], "*)"}], 
    RowBox[{"(*", 
     RowBox[{",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Line", "[", "optimumn", "]"}]}], "}"}]}]}], "*)"}], "]"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.815293405121913*^9, 3.815293405127408*^9}},
 CellLabel->
  "In[463]:=",ExpressionUUID->"3faaa7d6-2d7c-4f8d-85a1-0a52d2a44a58"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
    "\"\<a5si-fitnessfunctionplotnePb1.pdf\>\"", ",", 
     "fitnessfunctionplotnePb1", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.8152934130353737`*^9, 
  3.815293413043028*^9}},ExpressionUUID->"c7820f11-8210-4195-a352-\
399292d203c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitnessfunctionplotnePb", "=", 
   RowBox[{"Grid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"fitnessfunctionplotnePb0", ",", "fitnessfunctionplotnePb1"}], 
      "}"}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815293418847766*^9, 3.815293418855331*^9}, {
  3.8153111289718122`*^9, 3.8153111440986967`*^9}},
 CellLabel->
  "In[467]:=",ExpressionUUID->"30f7e3fd-75b5-4147-a56f-a57bb41502c1"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
    "\"\<a5si-fitnessfunctionplotnePb-largen.pdf\>\"", ",", 
     "fitnessfunctionplotnePb", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.815293425705792*^9, 3.815293425711734*^9}, {
  3.815311146946691*^9, 
  3.815311149880028*^9}},ExpressionUUID->"3ba2e602-700d-4644-8612-\
30b197357dc0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Best n for \[Epsilon]=0.1 and \[Epsilon]=0.9", "Subtitle",
 CellChangeTimes->{
  3.815293451625237*^9},ExpressionUUID->"905b7400-55d0-4707-a3b6-\
5051873baaba"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Pb", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"fitne01", "=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.1", ",", 
         RowBox[{"{", "n", "}"}], ",", "Pb"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "100", ",", "0.01"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"fitne09", "=", 
   RowBox[{"ParallelTable", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"fitfuncPb", "[", 
        RowBox[{"0.9", ",", 
         RowBox[{"{", "n", "}"}], ",", "Pb"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "100", ",", "0.01"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.815293504719412*^9, 3.815293504725388*^9}},
 CellLabel->
  "In[468]:=",ExpressionUUID->"83e30b70-9ce2-4f2b-ae86-c103a0fe337d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxfite01", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"fitne01", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"bestne01", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Select", "[", 
    RowBox[{"fitne01", ",", 
     RowBox[{
      RowBox[{"And", "[", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "maxfite01"}], "]"}], 
      "&"}]}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8152935123175707`*^9, 3.815293512323255*^9}},
 CellLabel->
  "In[471]:=",ExpressionUUID->"37d72dc6-1d7f-4bf5-9584-2c4c5e29ace5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxfite09", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"fitne09", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"bestne09", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Select", "[", 
    RowBox[{"fitne09", ",", 
     RowBox[{
      RowBox[{"And", "[", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "maxfite09"}], "]"}], 
      "&"}]}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8152935187742453`*^9, 3.81529351878402*^9}},
 CellLabel->
  "In[473]:=",ExpressionUUID->"1db4f1a8-0626-4c63-9a82-26cccd9ec342"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Production by d and \[Mu]", "Title",
 CellChangeTimes->{{3.815293528786788*^9, 
  3.8152935337982883`*^9}},ExpressionUUID->"3c620945-33a4-47c2-9f6d-\
b8cb1fa66033"],

Cell["\<\
The resident wildtype population is assumed to be adapted to environmental \
conditions fluctuating between \[Epsilon]=0.1 and \[Epsilon]=0.9 (with an \
average \[Epsilon]=0.5).\
\>", "Text",
 CellChangeTimes->{{3.815293543279601*^9, 
  3.815293558163385*^9}},ExpressionUUID->"5c59f8dd-c51d-4da6-b185-\
7627b44ba638"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ngen", "=", "20"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wthomeenv", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0.1", ",", 
        RowBox[{"ngen", "/", "2"}]}], "]"}], ",", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0.9", ",", 
        RowBox[{"ngen", "/", "2"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.815293565441394*^9, 3.81529356544803*^9}},
 CellLabel->
  "In[193]:=",ExpressionUUID->"2e608b88-2c7e-458c-afa3-bc8dc9ba5b9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Geometric", " ", "mean", " ", "fitness", " ", "for", " ", "different", 
      " ", "values", " ", "of", " ", "d", " ", "and", " ", "mu", " ", "under",
       " ", "fluctuating", " ", "environmental", " ", "conditions", " ", 
      "between", " ", "\[Epsilon]"}], "=", 
     RowBox[{
      RowBox[{"0.1", " ", "and", " ", "\[Epsilon]"}], "=", 
      RowBox[{
       RowBox[{"0.9", ".", "Note"}], " ", "that", " ", "because", " ", "the", 
       " ", "wild", " ", "type", " ", "does", " ", "not", " ", "transmit", 
       " ", "information", " ", "across", " ", "generations"}]}]}], ",", 
    RowBox[{
    "the", " ", "pattern", " ", "of", " ", "the", " ", "environmental", " ", 
     "fluctuations", " ", "does", " ", "not", " ", 
     RowBox[{"matter", "."}]}]}], "*)"}], 
  RowBox[{"Now", "\n", 
   RowBox[{
    RowBox[{"dmunfite0109", "=", 
     RowBox[{"ParallelTable", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"d", ",", "mu", ",", 
         RowBox[{
          RowBox[{"overgenadulteq", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"wtb", ",", "d", ",", "wtm", ",", "mu"}], "}"}], ",", 
            "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "ngen", ",", 
            "wtspeedeq"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"GeometricMean", "[", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"ConstantArray", "[", 
              RowBox[{
               RowBox[{"fitfuncPb", "[", 
                RowBox[{"0.1", ",", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "d", ",", "wtm", ",", "mu"}], "}"}], 
                    ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}],
                   "]"}], ",", "wtPb"}], "]"}], ",", 
               RowBox[{"ngen", "/", "2"}]}], "]"}], ",", 
             RowBox[{"ConstantArray", "[", 
              RowBox[{
               RowBox[{"fitfuncPb", "[", 
                RowBox[{"0.9", ",", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "d", ",", "wtm", ",", "mu"}], "}"}], 
                    ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}],
                   "]"}], ",", "wtPb"}], "]"}], ",", 
               RowBox[{"ngen", "/", "2"}]}], "]"}]}], "}"}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"mu", ",", "0", ",", "10", ",", "0.001"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", "0", ",", "1", ",", "0.01"}], "}"}]}], "]"}]}], 
    ";"}], "\n", "Now"}]}]], "Input",
 CellChangeTimes->{{3.815293573015483*^9, 3.815293573023819*^9}},
 CellLabel->
  "In[195]:=",ExpressionUUID->"e7c955a5-1a07-4082-8e8e-32a0afa57706"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dmunfite0109", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"dmunfite0109", ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815293579217332*^9, 3.815293579225025*^9}},
 CellLabel->
  "In[198]:=",ExpressionUUID->"d2399b0d-2804-4c4d-83f9-5552f6c5d88e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<a5si-dmunfite0109.mx\>\"", ",", "dmunfite0109"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8152935850361156`*^9, 3.815293585045743*^9}},
 CellLabel->
  "In[199]:=",ExpressionUUID->"ba3a65c4-e8b8-4702-ba01-da1e4a21ccca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dmunfite0109", "=", 
   RowBox[{"Import", "[", "\"\<a5si-dmunfite0109.mx\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8152935904089813`*^9, 
  3.815293590416367*^9}},ExpressionUUID->"feb900c0-c63d-4afe-988a-\
f62a46e3321a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dmumaxgeofit", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"dmunfite0109", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "4"}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Flatten", "[", 
  RowBox[{"Select", "[", 
   RowBox[{"dmunfite0109", ",", 
    RowBox[{
     RowBox[{"And", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "\[Equal]", "dmumaxgeofit"}], "]"}], 
     "&"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.81529359654778*^9, 3.8152935965561523`*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"69d86e0b-c659-468e-b651-18f70cada97a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"wtdmunfite0109", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"dmunfite0109", ",", 
     RowBox[{
      RowBox[{"And", "[", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0.1"}], "]"}], "&"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtdmunfite0109maxgeofit", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"wtdmunfite0109", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "4"}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Flatten", "[", 
  RowBox[{"Select", "[", 
   RowBox[{"wtdmunfite0109", ",", 
    RowBox[{
     RowBox[{"And", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "\[Equal]", 
       "wtdmunfite0109maxgeofit"}], "]"}], "&"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8152936024405622`*^9, 3.815293602448196*^9}},
 CellLabel->
  "In[202]:=",ExpressionUUID->"436d7070-b425-486b-9f3e-1df16548e630"],

Cell[CellGroupData[{

Cell["Plots", "Chapter",
 CellChangeTimes->{{3.815293613013603*^9, 
  3.8152936181228867`*^9}},ExpressionUUID->"8369367e-dd95-4862-99ea-\
bda5f1cf7a21"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dmunfite0109", "=", 
   RowBox[{"Import", "[", "\"\<a5si-dmunfite0109.mx\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.815293630160367*^9, 
  3.815293630169087*^9}},ExpressionUUID->"afcadfe0-c672-4c96-b3c0-\
cb4bbd519e31"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dmunfite0109subset", "=", 
   RowBox[{"dmunfite0109", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"1", ";;", 
       RowBox[{"Length", "[", "dmunfite0109", "]"}], ";;", "2"}], ",", 
      "All"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815293636774365*^9, 3.8152936367822237`*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"922a5fa1-0d17-4ff1-b73c-bd960312ee13"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"wtdmunfite0109", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"dmunfite0109subset", ",", 
     RowBox[{
      RowBox[{"And", "[", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0.1"}], "]"}], "&"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"wtdmunfite0109maxgeofit", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"wtdmunfite0109", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "4"}], "]"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.815293642504771*^9, 3.815293642513158*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"37c0db43-1924-484e-9c6f-b89a125ae731"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dmunplot", "=", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{
     RowBox[{"dmunfite0109subset", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Contours", "\[Rule]", "20"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}], "[", 
         RowBox[{"Rescale", "[", 
          RowBox[{"#", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"Max", "[", 
              RowBox[{"dmunfite0109subset", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "3"}], "]"}], "]"}], "]"}]}], "}"}]}], 
          "]"}], "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<d\>\"", ",", "\"\<\[Mu]\>\""}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"Placed", "[", 
       RowBox[{
        RowBox[{"BarLegend", "[", 
         RowBox[{"Automatic", ",", "20", ",", 
          RowBox[{"LegendMarkerSize", "\[Rule]", "300"}], ",", 
          RowBox[{"LegendLabel", "\[Rule]", "\"\<n\>\""}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "20"}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"After", ",", "Top"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"wtd", ",", "wtmu"}], "}"}], "]"}]}], "}"}], 
       RowBox[{"(*", 
        RowBox[{",", 
         RowBox[{"{", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"\"\<*\>\"", ",", "mincoord"}], "]"}], ",", "40"}], 
           "]"}], "}"}]}], "*)"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815293648820094*^9, 3.8152936488262*^9}},
 CellLabel->
  "In[208]:=",ExpressionUUID->"ae6adea0-9107-40cc-8f75-0ecddb1ed339"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{"\"\<a5si-bdmmunplot-dmun.pdf\>\"", ",", "dmunplot", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.815293654363406*^9, 
  3.8152936543707943`*^9}},ExpressionUUID->"8bc6332e-3ef2-4225-8439-\
0b4073050e77"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dmufitplot", "=", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{
     RowBox[{"dmunfite0109subset", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "4"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Contours", "\[Rule]", "20"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}], "[", 
         RowBox[{"Rescale", "[", 
          RowBox[{"#", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"Max", "[", 
              RowBox[{"dmunfite0109subset", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "4"}], "]"}], "]"}], "]"}]}], "}"}]}], 
          "]"}], "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<d\>\"", ",", "\"\<\[Mu]\>\""}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"Placed", "[", 
       RowBox[{
        RowBox[{"BarLegend", "[", 
         RowBox[{"Automatic", ",", "20", ",", 
          RowBox[{"LegendMarkerSize", "\[Rule]", "300"}], ",", 
          RowBox[{
          "LegendLabel", "\[Rule]", 
           "\"\<\\!\\(\\*SubscriptBox[\\(W\\), \\(GEO\\)]\\)\>\""}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", "20"}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"After", ",", "Top"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"wtd", ",", "wtmu"}], "}"}], "]"}]}], "}"}], 
       RowBox[{"(*", 
        RowBox[{",", 
         RowBox[{"{", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"\"\<*\>\"", ",", "mincoord"}], "]"}], ",", "40"}], 
           "]"}], "}"}]}], "*)"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815293660501543*^9, 3.815293660508678*^9}},
 CellLabel->
  "In[209]:=",ExpressionUUID->"210a31e7-0210-46db-b7c1-4ba992de89f8"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{"\"\<a5si-bdmmunplot-dmufit.pdf\>\"", ",", "dmufitplot", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.815293666304481*^9, 
  3.81529366631223*^9}},ExpressionUUID->"c0b75888-d94a-4572-b4c5-\
2c6a6f6dfbf1"],

Cell[BoxData[
 RowBox[{"dmunfitplot", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"dmunplot", ",", "dmufitplot"}], "}"}], "}"}], ",", 
    RowBox[{"ItemSize", "\[Rule]", "Medium"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815293672306394*^9, 3.815293672312739*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"c51c2ba6-17fa-49ed-ba91-4a21cd38f4e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<a5si-dmunfit.png\>\"", ",", "dmunfitplot", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815293678447699*^9, 3.815293678455186*^9}},
 CellLabel->
  "In[212]:=",ExpressionUUID->"258a5fba-32a9-4e94-9bea-810be7c2e553"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evolutionary Invasion Analysis", "Title",
 CellChangeTimes->{{3.815911043795261*^9, 3.8159110595565453`*^9}, {
  3.815911090934761*^9, 
  3.8159110932149057`*^9}},ExpressionUUID->"d8ae2f76-4bc6-4f2d-a942-\
7d2219105128"],

Cell[CellGroupData[{

Cell["\<\
Environmental scenarios switching between 0.1 and 0.9, with mean \
\[Epsilon]=0.5\
\>", "Chapter",
 CellChangeTimes->{{3.8152936970431843`*^9, 
  3.815293700193742*^9}},ExpressionUUID->"749779b9-0dca-43a4-a4de-\
de0e8b90cf26"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ngenerations", "=", "20"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"corrscenarios", "=", 
   RowBox[{"Permutations", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0.1", ",", 
         RowBox[{"ngenerations", "/", "2"}]}], "]"}], ",", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0.9", ",", 
         RowBox[{"ngenerations", "/", "2"}]}], "]"}]}], "}"}], "]"}], "]"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.815293711332637*^9, 3.815293711341593*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"da8dd828-8789-4abf-bc28-35362b69209a"],

Cell[BoxData[{"Now", "\n", 
 RowBox[{
  RowBox[{"envcorrvalues", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "corrscenarios", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"nchanges", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"nchanges", "=", 
           RowBox[{"nchanges", "+", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"Boole", "[", 
               RowBox[{
                RowBox[{"corrscenarios", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Equal]", 
                RowBox[{"corrscenarios", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", 
                   RowBox[{"j", "-", "1"}]}], "]"}], "]"}]}], "]"}]}], 
             ")"}]}]}], ";"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2", ",", "ngenerations"}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"envcorrvalues", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"1", "-", 
         RowBox[{"(", 
          RowBox[{"nchanges", "/", 
           RowBox[{"(", 
            RowBox[{"ngenerations", "-", "1"}], ")"}]}], ")"}]}], "//", 
        "N"}]}], ";"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "corrscenarios", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\n", "Now"}], "Input",
 CellChangeTimes->{{3.815293716956277*^9, 3.815293716964073*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"21f66dbe-96d4-4b58-8c90-c909b83e131f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Number", " ", "of", " ", "scenarios"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Length", "[", "corrscenarios", "]"}]}]], "Input",
 CellChangeTimes->{{3.815293722973898*^9, 3.815293722983061*^9}, 
   3.815385115216929*^9},
 CellLabel->"In[80]:=",ExpressionUUID->"7e6a7f3a-314a-49a4-92b9-84ba75b51f0f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Correlation", " ", "values"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Union", "[", "envcorrvalues", "]"}], "//", "N"}]}]], "Input",
 CellChangeTimes->{{3.8152937285886917`*^9, 3.815293728595813*^9}, {
  3.8153851199798803`*^9, 3.8153851222121058`*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"895b5ce5-8883-46a9-8d45-d53ba8b67272"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<a5si-corrscenarios.mx\>\"", ",", "corrscenarios"}], "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<a5si-envcorrvalues.mx\>\"", ",", "envcorrvalues"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8152937349563847`*^9, 3.8152937349634933`*^9}, {
  3.8153851324130583`*^9, 3.815385141282192*^9}, {3.815386514325315*^9, 
  3.815386522297037*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"e7fbe239-a72f-4e8d-a5d5-873deec628fd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example of environmental scenarios", "Subtitle",
 CellChangeTimes->{{3.815293744793991*^9, 
  3.815293747177868*^9}},ExpressionUUID->"23a34493-a5d0-48a8-a854-\
2f24871d5fe3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"envcorr", "=", "0.10526315789473684`"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envscenset", "=", 
   RowBox[{"corrscenarios", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{"envcorrvalues", ",", "envcorr"}], "]"}], "]"}], ",", "All"}],
      "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"exampleenvcorr010", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"envscenset", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "All"}], "]"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Blue", ",", "Thick"}], "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "20"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Generations\>\"", ",", 
        "\"\<Environmental condition (\[Epsilon])\>\""}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "StringTemplate", "[", 
            "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \\(\[Epsilon]\\)]\\)=`1`\>\"",
             "]"}], "[", 
           RowBox[{"NumberForm", "[", 
            RowBox[{"envcorr", ",", "2"}], "]"}], "]"}], ",", "16"}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "0.95"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.815293754937849*^9, 3.815293754945064*^9}},
 CellLabel->
  "In[483]:=",ExpressionUUID->"f0df8be8-7647-46ae-b640-5d01f54340bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"envcorr", "=", "0.5263157894736842`"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envscenset", "=", 
   RowBox[{"corrscenarios", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{"envcorrvalues", ",", "envcorr"}], "]"}], "]"}], ",", "All"}],
      "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"exampleenvcorr053", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"envscenset", "[", 
      RowBox[{"[", 
       RowBox[{"4", ",", "All"}], "]"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Blue", ",", "Thick"}], "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "20"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Generations\>\"", ",", 
        "\"\<Environmental condition (\[Epsilon])\>\""}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "StringTemplate", "[", 
            "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \\(\[Epsilon]\\)]\\)=`1`\>\"",
             "]"}], "[", 
           RowBox[{"NumberForm", "[", 
            RowBox[{"envcorr", ",", "2"}], "]"}], "]"}], ",", "16"}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "0.95"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.815293762307028*^9, 3.815293762317012*^9}},
 CellLabel->
  "In[486]:=",ExpressionUUID->"1da414c8-fc46-4b68-9f6e-d04ff2e49635"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"envcorr", "=", "0.8947368421052632`"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envscenset", "=", 
   RowBox[{"corrscenarios", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{"envcorrvalues", ",", "envcorr"}], "]"}], "]"}], ",", "All"}],
      "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"exampleenvcorr089", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"envscenset", "[", 
      RowBox[{"[", 
       RowBox[{"4", ",", "All"}], "]"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Blue", ",", "Thick"}], "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "20"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Generations\>\"", ",", 
        "\"\<Environmental condition (\[Epsilon])\>\""}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"Inset", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "StringTemplate", "[", 
            "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \\(\[Epsilon]\\)]\\)=`1`\>\"",
             "]"}], "[", 
           RowBox[{"NumberForm", "[", 
            RowBox[{"envcorr", ",", "2"}], "]"}], "]"}], ",", "16"}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "0.95"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8152937694791594`*^9, 3.815293769485691*^9}},
 CellLabel->
  "In[489]:=",ExpressionUUID->"2842d8ed-061c-484c-8d7d-32807bbe78b2"],

Cell[BoxData[
 RowBox[{"correnvsceexample", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "exampleenvcorr010", "}"}], ",", 
     RowBox[{"{", "exampleenvcorr053", "}"}], ",", 
     RowBox[{"{", "exampleenvcorr089", "}"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815293776212492*^9, 3.815293776220335*^9}},
 CellLabel->
  "In[492]:=",ExpressionUUID->"516eb51a-fceb-4a91-a9db-7e6cd64dcc1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-correnvsceexample.pdf\>\"", ",", "correnvsceexample", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815293783518016*^9, 3.81529378352487*^9}},
 CellLabel->
  "In[231]:=",ExpressionUUID->"e089258f-a0e8-4a03-8d57-22074a103a2f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Behavior of plastic mutants (strategy D)", "Chapter",
 CellChangeTimes->{
  3.815293793691337*^9},ExpressionUUID->"36272765-5762-4ec4-8f8e-\
b37df2abc2e0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"lowenvcorr", "=", "0.10526315789473684`"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"highenvcorr", "=", "0.8947368421052632`"}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"scenariolowp\[Epsilon]", "=", 
   RowBox[{
    RowBox[{"corrscenarios", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Position", "[", 
         RowBox[{"envcorrvalues", ",", "lowenvcorr"}], "]"}], "]"}], ",", 
       "All"}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "All"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"scenariohighp\[Epsilon]", "=", 
    RowBox[{
     RowBox[{"corrscenarios", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"Position", "[", 
          RowBox[{"envcorrvalues", ",", "highenvcorr"}], "]"}], "]"}], ",", 
        "All"}], "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "All"}], "]"}], "]"}]}], ";"}], "\n", "\n", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"wtdynamicslowenv", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"acrosswithingenPb", "[", 
        RowBox[{
        "examplevalues", ",", "0", ",", "0", ",", "20", ",", "0", ",", 
         "scenariolowp\[Epsilon]", ",", "1", ",", "1"}], "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ";", "\n", 
    RowBox[{"wtdynamicshighenv", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"acrosswithingenPb", "[", 
        RowBox[{
        "examplevalues", ",", "0", ",", "0", ",", "20", ",", "0", ",", 
         "scenariohighp\[Epsilon]", ",", "1", ",", "1"}], "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Pbmutantdynamicslowenv", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
      "examplevalues", ",", "0", ",", "0", ",", "20", ",", "1.0", ",", 
       "scenariolowp\[Epsilon]", ",", "2", ",", "1"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Pbmutantdynamicshighenv", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"acrosswithingenPb", "[", 
      RowBox[{
      "examplevalues", ",", "0", ",", "0", ",", "20", ",", "1.0", ",", 
       "scenariohighp\[Epsilon]", ",", "2", ",", "1"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"PbRgermmutantdynamicslowenv", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"acrosswithingenPb", "[", 
        RowBox[{
        "examplevalues", ",", "0.5", ",", "0", ",", "20", ",", "1.0", ",", 
         "scenariolowp\[Epsilon]", ",", "2", ",", "1"}], "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ";", "\n", 
    RowBox[{"PbRgermmutantdynamicshighenv", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"acrosswithingenPb", "[", 
        RowBox[{
        "examplevalues", ",", "0.5", ",", "0", ",", "20", ",", "1.0", ",", 
         "scenariohighp\[Epsilon]", ",", "2", ",", "1"}], "]"}], "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ";"}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.815293804024441*^9, 3.81529380403095*^9}, {
  3.8153864531512413`*^9, 3.815386463410819*^9}},
 CellLabel->
  "In[493]:=",ExpressionUUID->"8b246acb-2233-4597-a127-953b74b4325b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotticks", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"plotticks", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"plotticks", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{"20", "+", "1"}], ")"}]}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{"strategyDdynamics", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ListLinePlot", "[", 
       RowBox[{"Pbmutantdynamicslowenv", ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "100"}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Generations\>\"", ",", "\"\<sRNA level (n)\>\""}], 
          "}"}]}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
        RowBox[{"FrameTicks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"plotticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameTicksStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "StringTemplate", "[", 
               "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \\(\[Epsilon]\\)]\\)=`1`\>\
\"", "]"}], "[", 
              RowBox[{"NumberForm", "[", 
               RowBox[{"lowenvcorr", ",", "2"}], "]"}], "]"}], ",", "16"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"210", ",", "95"}], "}"}]}], "]"}]}]}], "]"}], ",", 
      RowBox[{"ListLinePlot", "[", 
       RowBox[{"Pbmutantdynamicshighenv", ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "100"}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<Generations\>\"", ",", "\"\<sRNA level (n)\>\""}], 
          "}"}]}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "16"}], "]"}]}], ",", 
        RowBox[{"FrameTicks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"plotticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameTicksStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "16"}], "]"}]}], ",", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"Inset", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "StringTemplate", "[", 
               "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \\(\[Epsilon]\\)]\\)=`1`\>\
\"", "]"}], "[", 
              RowBox[{"NumberForm", "[", 
               RowBox[{"highenvcorr", ",", "2"}], "]"}], "]"}], ",", "16"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"210", ",", "95"}], "}"}]}], "]"}]}]}], "]"}]}], "}"}], 
    "}"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.815293816607524*^9, 3.815293816614127*^9}},
 CellLabel->
  "In[499]:=",ExpressionUUID->"98018fac-1b75-4eb0-9570-12a4f72c2750"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyDdynamics.pdf\>\"", ",", "strategyDdynamics", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815293823716854*^9, 3.815293823723921*^9}},
 CellLabel->
  "In[245]:=",ExpressionUUID->"0c0c4c7d-8201-4ad2-819f-801e647a424c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evolutionary Invasion Analysis: instant plasticity", "Title",
 CellChangeTimes->{
  3.815293685604912*^9, {3.815908852499757*^9, 3.8159088607425756`*^9}, {
   3.8159112172469997`*^9, 
   3.815911219925005*^9}},ExpressionUUID->"3e4a9a7d-6f20-4a24-a9c6-\
c803d0724744"],

Cell[CellGroupData[{

Cell["Global settings", "Chapter",
 CellChangeTimes->{
  3.81529383508169*^9},ExpressionUUID->"8462b220-6e1d-4fcc-b968-b57e312e1f00"],

Cell["Choose parameters to be tested", "Subtitle",
 CellChangeTimes->{
  3.815293869098483*^9},ExpressionUUID->"f5531294-9e29-45c7-b431-\
6af5ac692639"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Choose", " ", "variable", " ", "to", " ", "be", " ", "tested"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"1", "=", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "B"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"2", "=", 
     RowBox[{"Rgerm", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "C"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"3", "=", 
     RowBox[{"PbD", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "D"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"4", "=", 
     RowBox[{"PbE", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "E"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"5", "=", 
     RowBox[{"PbF", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "F"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"6", "=", 
     RowBox[{"PbD", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "D"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"7", "=", 
     RowBox[{"PbE", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "E"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"8", "=", 
     RowBox[{"PbF", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "F"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"9", "=", 
     RowBox[{"b", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "B"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"testvar", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], ";"}], "*)"}], 
  RowBox[{
   RowBox[{"testvar", "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.815293874958054*^9, 3.815293874964964*^9}, {
  3.816142324525321*^9, 3.816142325341353*^9}, {3.8161429849676027`*^9, 
  3.816142988503957*^9}, {3.816144232935286*^9, 3.816144233138479*^9}, {
  3.8161836089448566`*^9, 3.8161836127614927`*^9}, {3.821283844826335*^9, 
  3.821283845279935*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"69721b26-837e-4ecb-8829-d198a6873093"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Select", " ", "envcorr", " ", "to", " ", "run", " ", "the", " ", 
    "analysis"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"nscenarios", "=", "1"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
    "Number", " ", "of", " ", "scenarios", " ", "per", " ", "correlation", 
     " ", "value"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"envcorr", "=", 
     RowBox[{"{", "0.10526315789473684`", "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"envcorr", "=", 
      RowBox[{"{", 
       RowBox[{
       "0.10526315789473684`", ",", "0.5263157894736842`", ",", 
        "0.8947368421052632`"}], "}"}]}], ";"}], "*)"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"envcorr", "=", 
      RowBox[{"{", "0.8947368421052632`", "}"}]}], ";"}], "*)"}]}]}]], "Input",\

 CellChangeTimes->{{3.815293881032152*^9, 3.815293881039572*^9}, 
   3.816142316132802*^9, {3.8161836214016523`*^9, 3.816183642048872*^9}, 
   3.8211776278568087`*^9, {3.821283850799286*^9, 3.821283859435916*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"854198ec-9327-417e-8be3-0bba4abe2403"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotfiletype", "=", "\"\<pdf\>\""}], 
  RowBox[{"(*", "pdf", "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.815293887126153*^9, 3.815293887133655*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"e76b4797-6e25-4694-b07e-921b7e131856"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ncosts", "=", 
   RowBox[{"{", "0.00001", "}"}]}], 
  RowBox[{"(*", "0.005", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Pbcosts", "=", 
   RowBox[{"{", "50", "}"}]}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "1.25", ",", "1.5", ",", "2.0"}], "}"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"{", "2", "}"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"Cb", " ", "relative", " ", "to", " ", "Cn"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{
    "0.0", ",", "0.5", ",", "1", ",", "2", ",", "5", ",", "10", ",", "20", 
     ",", "50"}], "}"}], "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.815293892688305*^9, 3.815293892695327*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"7d74b617-4429-4e39-b74a-4d3f1ce84ce1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"speed", "=", 
   RowBox[{"{", "2.0", "}"}]}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "0.75"}], "}"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"Developmental", " ", "speed"}], "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.815293897835882*^9, 3.815293897843685*^9}, {
  3.816142332513174*^9, 3.8161423327221212`*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"ad7641e2-d20e-44af-81af-05b941c03ae1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulations", "Chapter",
 CellChangeTimes->{
  3.815293908279591*^9},ExpressionUUID->"7d44e0a1-d367-41f0-9d7e-\
b92342b4d61f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"WT", " ", "values"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"wtb", "=", "0.000"}], 
    RowBox[{"(*", 
     RowBox[{"no", " ", "amplification"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtd", "=", "0.100"}], 
    RowBox[{"(*", 
     RowBox[{
     "degradation", " ", "rate", " ", "is", " ", "assumed", " ", "to", " ", 
      "be", " ", "an", " ", "intrisic", " ", "stability", " ", "property", 
      " ", "of", " ", "the", " ", "specific", " ", "sRNA", " ", "molecule", 
      " ", "under", " ", "focus"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtm", "=", "5.000"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtRgerm", "=", "0"}], 
    RowBox[{"(*", 
     RowBox[{"no", " ", "transmission"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtPb", "=", "0"}], 
    RowBox[{"(*", 
     RowBox[{"no", " ", "responsiveness"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtstrategy", "=", "1"}], 
    RowBox[{"(*", 
     RowBox[{"strategy", " ", "A"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtcellgen", "=", "20"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtn0", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtspeedeq", "=", "1.0"}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{"Fitness", " ", "function", " ", "values"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Beta]", "=", "0.1"}], 
    RowBox[{"(*", "0.1", "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"\[Alpha]", "=", "15"}], 
    RowBox[{"(*", "4", "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"l", "=", "0"}], 
    RowBox[{"(*", "0", "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"mid", "=", "5"}], 
    RowBox[{"(*", "5", "*)"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.815293915237474*^9, 3.8152939152449293`*^9}, 
   3.815385269543971*^9, {3.8161423852411337`*^9, 3.816142385444387*^9}, {
   3.816142466226388*^9, 3.816142466405497*^9}, {3.816144229213736*^9, 
   3.816144229455553*^9}, {3.816150972039716*^9, 3.816150972229404*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"94964efa-c683-43a3-996b-787bd416f201"],

Cell[BoxData[{"Now", "\n", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"envcorrpositions", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"envcorrvalues", "//", "N"}], ",", "corr"}], "]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"envscenset", "=", 
      RowBox[{"corrscenarios", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"RandomSample", "[", 
          RowBox[{"envcorrpositions", ",", "nscenarios"}], "]"}], ",", 
         "All"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
      "Costs", " ", "used", " ", "in", " ", "the", " ", "fitness", " ", 
       RowBox[{"function", "."}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ncost", "=", "cost1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Pbcost", "=", 
      RowBox[{"cost1", " ", "cost2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"corrvalue", "=", 
      RowBox[{"NumberForm", "[", 
       RowBox[{"corr", ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"spee", "=", 
      RowBox[{"NumberForm", "[", 
       RowBox[{"speedeq", ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Calculate", " ", "value", " ", "of", " ", "wildtype", " ", 
       RowBox[{"mu", "."}]}], "*)"}], 
     RowBox[{"mufit", "=", 
      RowBox[{"ParallelTable", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"wtmu", ",", 
          RowBox[{"GeometricMean", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ConstantArray", "[", 
               RowBox[{
                RowBox[{"fitfuncPb", "[", 
                 RowBox[{"0.1", ",", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}],
                    "]"}], ",", "wtPb"}], "]"}], ",", 
                RowBox[{"ngenerations", "/", "2"}]}], "]"}], ",", 
              RowBox[{"ConstantArray", "[", 
               RowBox[{
                RowBox[{"fitfuncPb", "[", 
                 RowBox[{"0.9", ",", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}],
                    "]"}], ",", "wtPb"}], "]"}], ",", 
                RowBox[{"ngenerations", "/", "2"}]}], "]"}]}], "}"}], "]"}], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"wtmu", ",", "0", ",", "10", ",", "0.001"}], "}"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mumaxgeofit", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"mufit", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"wtmu", "=", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Select", "[", 
         RowBox[{"mufit", ",", 
          RowBox[{
           RowBox[{"And", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "mumaxgeofit"}], 
            "]"}], "&"}]}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "b", "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "5", ",", "0.005"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "b", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "1"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[\\(b\\), \\(+\\)]\\)\>\"", 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyB-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n        5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "spee"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "2"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "Rgerm", "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.005"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "1"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \n\
\\(germ\\)], \\(+\\)]\\)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyC-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "spee"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "3"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "PbD", "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "2"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy D)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyD-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "spee"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "4"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "PbE", "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "3"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy E)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyE-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "spee"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "5"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "PbF", "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "4"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy F)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyF-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "spee"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "6"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"PbD", "+", "Rgerm"}], "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "0.2", ",", "0.01"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "2"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy D)\>\"", ",", 
            "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(germ\\)], \n\
\\(+\\)]\\)\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyCD-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\n\
speedeq`5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "spee"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "7"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"PbE", "+", "Rgerm"}], "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "0.2", ",", "0.01"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "3"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy E)\>\"", ",", 
            "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(germ\\)], \n\
\\(+\\)]\\)\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyCE-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\n\
speedeq`5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "spee"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "8"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"PbF", "+", "Rgerm"}], "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "0.2", ",", "0.01"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "4"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy F)\>\"", ",", 
            "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(germ\\)], \n\
\\(+\\)]\\)\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyCF-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\n\
speedeq`5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "spee"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "9"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"b", "+", "Rgerm"}], "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "0.5", ",", "0.0005"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "b", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "0.2", ",", "0.01"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "1"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\!\\(\\*SuperscriptBox[\\(b\\), \\(+\\)]\\)\>\"", ",", 
            "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(germ\\)], \n\
\\(+\\)]\\)\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyBC-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\n\
speedeq`5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "spee"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Table", " ", "to", " ", "collect", " ", "the", " ", 
       RowBox[{"result", ":", 
        RowBox[{"mutresult", "[", 
         RowBox[{"envscenario", ",", "varcombination", ",", "output"}], 
         "]"}]}]}], "*)"}], 
     RowBox[{"mutresult", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"env", ",", 
          RowBox[{"Length", "[", "envscenset", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"var", ",", 
          RowBox[{
           RowBox[{"Length", "[", "mutb", "]"}], "*", 
           RowBox[{"Length", "[", "mutRgerm", "]"}], "*", 
           RowBox[{"Length", "[", "mutPb", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"out", ",", "6"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"SetSharedVariable", "[", "mutresult", "]"}], 
     RowBox[{"(*", 
      RowBox[{
      "Make", " ", "it", " ", "available", " ", "to", " ", "all", " ", 
       "kernels"}], "*)"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ParallelDo", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"Wildtype", " ", "data"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"datawt", "=", 
          RowBox[{"acrosswithingenPb", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",",
             "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "wtPb", ",", 
            RowBox[{"envscenset", "[", 
             RowBox[{"[", 
              RowBox[{"env", ",", "All"}], "]"}], "]"}], ",", "wtstrategy", 
            ",", "speedeq"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"count", "=", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"b", "-", "1"}], ")"}], " ", 
                RowBox[{"Length", "[", "mutRgerm", "]"}], "*", 
                RowBox[{"Length", "[", "mutPb", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"r", "-", "1"}], ")"}], " ", 
                RowBox[{"Length", "[", "mutPb", "]"}]}], "+", "p"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"mutant", " ", "n0", " ", 
               RowBox[{"(", "equilibrium", ")"}]}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"mutn0", "=", 
              RowBox[{
               RowBox[{"mutRgerm", "[", 
                RowBox[{"[", "r", "]"}], "]"}], "*", 
               RowBox[{
                RowBox[{"overgenadulteq", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"mutb", "[", 
                    RowBox[{"[", "b", "]"}], "]"}], ",", "wtd", ",", "wtm", 
                    ",", "wtmu"}], "}"}], ",", 
                  RowBox[{"mutRgerm", "[", 
                   RowBox[{"[", "r", "]"}], "]"}], ",", "wtn0", ",", 
                  "wtcellgen", ",", "200", ",", "speedeq"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"mutant", " ", "data"}], "*)"}], "\[IndentingNewLine]", 
             
             RowBox[{"datamut", "=", 
              RowBox[{"acrosswithingenPb", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"mutb", "[", 
                   RowBox[{"[", "b", "]"}], "]"}], ",", "wtd", ",", "wtm", 
                  ",", "wtmu"}], "}"}], ",", 
                RowBox[{"mutRgerm", "[", 
                 RowBox[{"[", "r", "]"}], "]"}], ",", "mutn0", ",", 
                "wtcellgen", ",", 
                RowBox[{"mutPb", "[", 
                 RowBox[{"[", "p", "]"}], "]"}], ",", 
                RowBox[{"envscenset", "[", 
                 RowBox[{"[", 
                  RowBox[{"env", ",", "All"}], "]"}], "]"}], ",", 
                "mutstrategy", ",", "speedeq"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"Population", " ", "dynamics"}], ",", 
               RowBox[{"final", " ", "value", " ", "of", " ", "Nmut"}]}], 
              "*)"}], "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "1"}], "]"}], "]"}], "=", 
              "wtmu"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "2"}], "]"}], "]"}], "=", 
              RowBox[{"mutb", "[", 
               RowBox[{"[", "b", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "3"}], "]"}], "]"}], "=", 
              RowBox[{"mutRgerm", "[", 
               RowBox[{"[", "r", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "4"}], "]"}], "]"}], "=", 
              RowBox[{"mutPb", "[", 
               RowBox[{"[", "p", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "5"}], "]"}], "]"}], "=", 
              RowBox[{"datamut", "[", 
               RowBox[{"[", "4", "]"}], "]"}]}], 
             RowBox[{"(*", 
              RowBox[{
              "geometric", " ", "mean", " ", "fitness", " ", "of", " ", 
               "mutant"}], "*)"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "6"}], "]"}], "]"}], "=", 
              RowBox[{"selcoeff", "[", 
               RowBox[{
                RowBox[{"datamut", "[", 
                 RowBox[{"[", "4", "]"}], "]"}], ",", 
                RowBox[{"datawt", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], "]"}]}], 
             RowBox[{"(*", 
              RowBox[{
              "selection", " ", "coefficient", " ", "based", " ", "on", " ", 
               "geometric", " ", "mean", " ", "fitness"}], "*)"}], ";"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b", ",", "1", ",", 
             RowBox[{"Length", "[", "mutb", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "1", ",", 
             RowBox[{"Length", "[", "mutRgerm", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"p", ",", "1", ",", 
             RowBox[{"Length", "[", "mutPb", "]"}]}], "}"}]}], "]"}], ";"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"env", ",", "1", ",", 
         RowBox[{"Length", "[", "envscenset", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"output", "=", 
      RowBox[{"List", "[", 
       RowBox[{
       "envscenset", ",", "mutb", ",", "mutRgerm", ",", "mutPb", ",", 
        "mutstrategy", ",", "focalparameters", ",", "mutresult", ",", 
        "speedeq", ",", "ncost", ",", "Pbcost"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"StringTemplate", "[", "\"\<`1`.mx\>\"", "]"}], "[", 
        "outputfile", "]"}], ",", "output"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"PLOTS", ":", 
       RowBox[{
        RowBox[{"Strategies", " ", "A"}], "-", 
        RowBox[{"F", "."}]}]}], "*)"}], 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "focalparameters", "]"}], "\[Equal]", "1"}], 
       RowBox[{"(*", 
        RowBox[{"One", " ", "parameter", " ", "tested"}], "*)"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"envcolor", "=", 
          RowBox[{"GrayLevel", "[", "0.7", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "mutb", "]"}], ">", "1"}], ",", 
           RowBox[{"varvalues", "=", "mutb"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "mutRgerm", "]"}], ">", "1"}], ",", 
           RowBox[{"varvalues", "=", "mutRgerm"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "mutPb", "]"}], ">", "1"}], ",", 
           RowBox[{"varvalues", "=", "mutPb"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"xvalues", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"1", ",", 
               RowBox[{
                RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], 
                 ")"}], "/", "5"}]}], "]"}], ",", 
             RowBox[{"Length", "[", "varvalues", "]"}]}], "}"}], "]"}]}], ";",
          "\[IndentingNewLine]", 
         RowBox[{"xticks", "=", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"xvalues", ",", 
             RowBox[{"varvalues", "[", 
              RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ymax", "=", 
          RowBox[{"Max", "[", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"ymin", "=", 
          RowBox[{"Min", "[", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"ydistance", "=", 
          RowBox[{"Abs", "[", 
           RowBox[{"ymax", "-", "ymin"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutinvasionselcoeffplot", "=", 
          RowBox[{"Show", "[", 
           RowBox[{
            RowBox[{"ListLinePlot", "[", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
              RowBox[{"Joined", "\[Rule]", "True"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{"envcolor", ",", "Thick"}], "]"}]}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"ymin", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                   RowBox[{"ymax", "+", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
              ",", 
              RowBox[{"Axes", "\[Rule]", "False"}], ",", 
              RowBox[{"Frame", "\[Rule]", "True"}], ",", 
              RowBox[{"FrameLabel", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"focalparameters", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 "\"\<Selection coefficient (\\!\\(\\*SuperscriptBox[\\(s\\), \
\n\\(+\\)]\\))\>\""}], "}"}]}], ",", 
              RowBox[{"FrameStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
              RowBox[{"FrameTicks", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
              RowBox[{"FrameTicksStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
              RowBox[{"Epilog", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"(*", 
                 RowBox[{
                  RowBox[{"Text", "[", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "StringTemplate", "[", 
                    "\"\<Subscript[\n         p, \[Epsilon]]=`1`\>\"", "]"}], 
                    "[", "envcor", "]"}], ",", "20", ",", 
                    RowBox[{"Background", "\[Rule]", "None"}], ",", "Bold"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Round", "[", 
                    RowBox[{"0.5", 
                    RowBox[{"Length", "[", "varvalues", "]"}]}], "]"}], "+", 
                    "1"}], ",", 
                    RowBox[{"ymax", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "]"}], 
                  ","}], "*)"}], 
                RowBox[{"Line", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Length", "[", "varvalues", "]"}], ",", "0"}], 
                    "}"}]}], "}"}], "]"}], "}"}]}]}], "]"}], ",", 
            RowBox[{"ListLinePlot", "[", 
             RowBox[{
              RowBox[{"Mean", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
              ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"ymin", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                   RowBox[{"ymax", "+", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
              ",", 
              RowBox[{"PlotStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{
                 RowBox[{"GrayLevel", "[", "0", "]"}], ",", "Thick"}], 
                "]"}]}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"invasionselcoeffplot", "=", 
          RowBox[{"Show", "[", 
           RowBox[{"mutinvasionselcoeffplot", ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{"{", 
              RowBox[{"Blue", ",", 
               RowBox[{"Opacity", "[", "0.2", "]"}], ",", 
               RowBox[{"Rectangle", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "0.001"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Length", "[", "varvalues", "]"}], ",", "0.001"}], 
                  "}"}]}], "]"}]}], "}"}], "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Export", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "StringTemplate", "[", "\"\<`1`-mutinvasionselcoeffplot.`2`\>\"", 
             "]"}], "[", 
            RowBox[{"outputfile", ",", "plotfiletype"}], "]"}], ",", 
           "invasionselcoeffplot", ",", 
           RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"PLOTS", ":", 
       RowBox[{
        RowBox[{"Strategies", " ", "CD"}], "-", 
        RowBox[{"CF", "."}]}]}], "*)"}], 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "focalparameters", "]"}], "\[Equal]", "2"}], 
       RowBox[{"(*", 
        RowBox[{"Two", " ", "parameters", " ", "tested"}], "*)"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"var", "\[Equal]", "9"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xpar", "=", "2"}], 
             RowBox[{"(*", "b", "*)"}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xpar", "=", "4"}], 
             RowBox[{"(*", "Pb", "*)"}], ";"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"zmax", "=", 
              RowBox[{"Max", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"zmin", "=", 
              RowBox[{"Min", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"minpos", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
                 RowBox[{"Min", "[", 
                  RowBox[{"mutresult", "[", 
                   RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], 
                  "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"mincoord", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "minpos", ",", 
                  RowBox[{"{", 
                   RowBox[{"xpar", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"maxpos", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
                 RowBox[{"Max", "[", 
                  RowBox[{"mutresult", "[", 
                   RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], 
                  "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"maxcoord", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "maxpos", ",", 
                  RowBox[{"{", 
                   RowBox[{"xpar", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"mutinvasionselcoeffplot", "=", 
              RowBox[{"ListContourPlot", "[", 
               RowBox[{
                RowBox[{"mutresult", "[", 
                 RowBox[{"[", 
                  RowBox[{"env", ",", "All", ",", 
                   RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                 "]"}], ",", 
                RowBox[{"Contours", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"{", 
                    RowBox[{"Thick", ",", "Black", ",", "Dashed"}], "}"}]}], 
                    "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Thick", ",", "Dashed", ",", "Black"}], "}"}]}], 
                    "}"}], ",", 
                   RowBox[{"Sequence", "@@", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"#", ",", "None"}], "}"}], "&"}], "/@", 
                    RowBox[{"Range", "[", 
                    RowBox[{
                    RowBox[{"Min", "@", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", 
                    RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"Max", "@", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", 
                    RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                    "]"}]}], ",", ".0005"}], "]"}]}], ")"}]}]}], "}"}]}], 
                RowBox[{"(*", "50", "*)"}], ",", 
                RowBox[{"ContourStyle", "\[Rule]", "None"}], ",", 
                RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
                RowBox[{"ColorFunction", "\[Rule]", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}],
                     "[", 
                    RowBox[{"Rescale", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"zmin", ",", "zmax"}], "}"}]}], "]"}], "]"}], 
                   "&"}], ")"}]}], ",", 
                RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}], ",", 
                RowBox[{"FrameTicks", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
                RowBox[{"FrameLabel", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"focalparameters", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                   RowBox[{"focalparameters", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ",", 
                RowBox[{"FrameStyle", "\[Rule]", 
                 RowBox[{"Directive", "[", 
                  RowBox[{"Black", ",", "Thick", ",", "25"}], "]"}]}], ",", 
                RowBox[{"FrameTicksStyle", "\[Rule]", 
                 RowBox[{"Directive", "[", 
                  RowBox[{"Black", ",", "Thick", ",", "25"}], "]"}]}], ",", 
                RowBox[{"PlotLegends", "\[Rule]", 
                 RowBox[{"Placed", "[", 
                  RowBox[{
                   RowBox[{"BarLegend", "[", 
                    RowBox[{"Automatic", ",", "50", ",", 
                    RowBox[{"LegendMarkerSize", "\[Rule]", "500"}], ",", 
                    RowBox[{
                    "LegendLabel", "\[Rule]", 
                    "\"\<\\!\\(\\*SuperscriptBox[\\(s\\), \\(+\\)]\\)\>\""}], 
                    ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"Black", ",", "25"}], "]"}]}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"After", ",", "Top"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"Epilog", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"{", 
                   RowBox[{"Black", ",", 
                    RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
                    RowBox[{"Point", "[", 
                    RowBox[{"{", "maxcoord", "}"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "StringTemplate", "[", 
                    "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \
\\(\[Epsilon]\\)]\\)=`1`\>\"", "]"}], "[", "corr", "]"}], ",", "25", ",", 
                    RowBox[{"Background", "\[Rule]", "None"}], ",", "Bold"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Max", "[", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", "xpar"}], "]"}], "]"}], 
                    "]"}], "/", "2"}], ",", "0.95"}], "}"}]}], "]"}], "}"}]}],
                    "}"}], 
                  RowBox[{"(*", 
                   RowBox[{",", 
                    RowBox[{"{", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{"\"\<*\>\"", ",", "mincoord"}], "]"}], ",", 
                    "40"}], "]"}], "}"}]}], "*)"}], "}"}]}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Export", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "StringTemplate", "[", 
                 "\"\<`1`-invasionselcoeffplot-env`2`.`3`\>\"", "]"}], "[", 
                RowBox[{"outputfile", ",", "env", ",", "plotfiletype"}], 
                "]"}], ",", "mutinvasionselcoeffplot", ",", 
               RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"env", ",", "1", ",", 
             RowBox[{"Length", "[", "envscenset", "]"}]}], "}"}]}], "]"}], 
         ";"}], "}"}]}], "]"}], ";"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cost1", ",", "ncosts"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cost2", ",", "Pbcosts"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"var", ",", "testvar"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"corr", ",", "envcorr"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"speedeq", ",", "speed"}], "}"}]}], "]"}], "\n", "Now"}], "Input",\

 CellChangeTimes->{{3.815293935169242*^9, 3.815293935175419*^9}, {
  3.81652015946084*^9, 3.816520162206828*^9}, {3.821175468851982*^9, 
  3.821175472602264*^9}, {3.821177246213893*^9, 3.8211772533547373`*^9}, {
  3.8212844286032963`*^9, 
  3.821284492764654*^9}},ExpressionUUID->"f2dd58e1-8195-42ed-ac6a-\
c8f7182a65e8"],

Cell[BoxData["Notify"], "Input",
 CellChangeTimes->{{3.815293942670762*^9, 3.815293942679002*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"526e6a78-b301-417d-9df8-b51d88a78b89"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Dynamics for ",
 StyleBox["w", "Title"],
 "ildtype with transmission (Rgerm=0.1)"
}], "Title",
 CellChangeTimes->{
  3.815293982691114*^9},ExpressionUUID->"54fec5a7-c29f-4070-bf87-\
8eff0558c093"],

Cell[CellGroupData[{

Cell["Global settings", "Chapter",
 CellChangeTimes->{
  3.81529383508169*^9},ExpressionUUID->"4246f477-6009-407c-af1c-fe1ea9b169ea"],

Cell["Choose parameters to be tested", "Subtitle",
 CellChangeTimes->{
  3.815293869098483*^9},ExpressionUUID->"271fa2f5-1ee3-4fc1-9e3b-\
ad6618d94832"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Choose", " ", "variable", " ", "to", " ", "be", " ", "tested"}], 
   "*)"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"1", "=", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "B"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"2", "=", 
     RowBox[{"Rgerm", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "C"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"3", "=", 
     RowBox[{"PbD", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "D"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"4", "=", 
     RowBox[{"PbE", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "E"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"5", "=", 
     RowBox[{"PbF", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "F"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"6", "=", 
     RowBox[{"PbD", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "D"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"7", "=", 
     RowBox[{"PbE", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "E"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"8", "=", 
     RowBox[{"PbF", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "F"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"9", "=", 
     RowBox[{"b", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "B"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"testvar", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], ";"}], "*)"}], 
  RowBox[{
   RowBox[{"testvar", "=", 
    RowBox[{"{", "3", "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.815293874958054*^9, 3.815293874964964*^9}, 
   3.8152950366792*^9},ExpressionUUID->"29607578-782c-41ba-95f6-25e013b068e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Select", " ", "envcorr", " ", "to", " ", "run", " ", "the", " ", 
    "analysis"}], "*)"}], 
  RowBox[{
   RowBox[{"nscenarios", "=", "3"}], ";", 
   RowBox[{"(*", 
    RowBox[{
    "Number", " ", "of", " ", "scenarios", " ", "per", " ", "correlation", 
     " ", "value"}], "*)"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"envcorr", "=", 
      RowBox[{"{", "0.10526315789473684`", "}"}]}], ";"}], "*)"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"envcorr", "=", 
      RowBox[{"{", 
       RowBox[{
       "0.10526315789473684`", ",", "0.5263157894736842`", ",", 
        "0.8947368421052632`"}], "}"}]}], ";"}], "*)"}], 
   RowBox[{"envcorr", "=", 
    RowBox[{"{", 
     RowBox[{"0.10526315789473684`", ",", "0.8947368421052632`"}], "}"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.815293881032152*^9, 3.815293881039572*^9}, 
   3.8152950451298647`*^9},ExpressionUUID->"0ecac2b2-8b7d-4cbf-945c-\
26cc633e0c33"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotfiletype", "=", "\"\<pdf\>\""}], 
  RowBox[{"(*", "pdf", "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.815293887126153*^9, 
  3.815293887133655*^9}},ExpressionUUID->"fb93785b-2e00-4bb6-ba5a-\
e8f77a98de90"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ncosts", "=", 
   RowBox[{"{", "0.00001", "}"}]}], 
  RowBox[{"(*", "0.005", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Pbcosts", "=", 
   RowBox[{"{", "50", "}"}]}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "1.25", ",", "1.5", ",", "2.0"}], "}"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"{", "2", "}"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"Cb", " ", "relative", " ", "to", " ", "Cn"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{
    "0.0", ",", "0.5", ",", "1", ",", "2", ",", "5", ",", "10", ",", "20", 
     ",", "50"}], "}"}], "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.815293892688305*^9, 3.815293892695327*^9}, 
   3.8152950574536247`*^9},ExpressionUUID->"64694189-8f8f-4240-a450-\
ac64db5402d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"speed", "=", 
   RowBox[{"{", "1.0", "}"}]}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "0.75"}], "}"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"Developmental", " ", "speed"}], "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.815293897835882*^9, 
  3.815293897843685*^9}},ExpressionUUID->"fb9392ac-1351-4215-b380-\
02541f758d1c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulations", "Chapter",
 CellChangeTimes->{
  3.815295073085394*^9},ExpressionUUID->"04a9b5ac-a853-4b3e-b46c-\
310ca2a44c02"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"WT", " ", "values"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"wtb", "=", "0.000"}], 
    RowBox[{"(*", 
     RowBox[{"no", " ", "amplification"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtd", "=", "0.100"}], 
    RowBox[{"(*", 
     RowBox[{
     "degradation", " ", "rate", " ", "is", " ", "assumed", " ", "to", " ", 
      "be", " ", "an", " ", "intrisic", " ", "stability", " ", "property", 
      " ", "of", " ", "the", " ", "specific", " ", "sRNA", " ", "molecule", 
      " ", "under", " ", "focus"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtm", "=", "5.000"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtRgerm", "=", "0.1"}], 
    RowBox[{"(*", 
     RowBox[{"no", " ", "transmission"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtPb", "=", "0"}], 
    RowBox[{"(*", 
     RowBox[{"no", " ", "responsiveness"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtstrategy", "=", "1"}], 
    RowBox[{"(*", 
     RowBox[{"strategy", " ", "A"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtcellgen", "=", "20"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtspeedeq", "=", "1.0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtmu", "=", "wtmue0109Rgerm01"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtn0", "=", 
     RowBox[{"wtRgerm", "*", 
      RowBox[{
       RowBox[{"overgenadulteq", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",", 
         "wtRgerm", ",", "0", ",", "wtcellgen", ",", "200", ",", 
         "wtspeedeq"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Fitness", " ", "function", " ", "values"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Beta]", "=", "0.1"}], 
    RowBox[{"(*", "0.1", "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"\[Alpha]", "=", "15"}], 
    RowBox[{"(*", "4", "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"l", "=", "0"}], 
    RowBox[{"(*", "0", "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"mid", "=", "5"}], 
    RowBox[{"(*", "5", "*)"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.81529508098188*^9, 3.815295080989875*^9}, 
   3.8159088843427753`*^9},ExpressionUUID->"ca43076d-703d-44d4-a80e-\
5ac6fc96155d"],

Cell[BoxData[{"Now", "\n", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"envcorrpositions", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"envcorrvalues", "//", "N"}], ",", "corr"}], "]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"envscenset", "=", 
      RowBox[{"corrscenarios", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"RandomSample", "[", 
          RowBox[{"envcorrpositions", ",", "nscenarios"}], "]"}], ",", 
         "All"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
      "Costs", " ", "used", " ", "in", " ", "the", " ", "fitness", " ", 
       RowBox[{"function", "."}]}], "*)"}], 
     RowBox[{"ncost", "=", "cost1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Pbcost", "=", 
      RowBox[{"cost1", " ", "cost2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"corrvalue", "=", 
      RowBox[{"NumberForm", "[", 
       RowBox[{"corr", ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "3"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "PbD", "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"{", "0.1", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "2"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy D)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyD-envcorr`1`-wtrgerm01mu`2`-ncost`3`-Pbcost`4`\
-speedeq`\n5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "4"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "PbE", "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"{", "0.1", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "3"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy E)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyE-envcorr`1`-wtrgerm01mu`2`-ncost`3`-Pbcost`4`\
-speedeq`\n5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "5"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "PbF", "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"{", "0.1", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "4"}], ";", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy F)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyF-envcorr`1`-wtrgerm01mu`2`-ncost`3`-Pbcost`4`\
-speedeq`\n5`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Table", " ", "to", " ", "collect", " ", "the", " ", 
       RowBox[{"result", ":", 
        RowBox[{"mutresult", "[", 
         RowBox[{"envscenario", ",", "varcombination", ",", "output"}], 
         "]"}]}]}], "*)"}], 
     RowBox[{"mutresult", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"env", ",", 
          RowBox[{"Length", "[", "envscenset", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"var", ",", 
          RowBox[{
           RowBox[{"Length", "[", "mutb", "]"}], "*", 
           RowBox[{"Length", "[", "mutRgerm", "]"}], "*", 
           RowBox[{"Length", "[", "mutPb", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"out", ",", "6"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"SetSharedVariable", "[", "mutresult", "]"}], 
     RowBox[{"(*", 
      RowBox[{
      "Make", " ", "it", " ", "available", " ", "to", " ", "all", " ", 
       "kernels"}], "*)"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ParallelDo", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"Wildtype", " ", "data"}], "*)"}], 
        RowBox[{
         RowBox[{"datawt", "=", 
          RowBox[{"acrosswithingenPb", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",",
             "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "wtPb", ",", 
            RowBox[{"envscenset", "[", 
             RowBox[{"[", 
              RowBox[{"env", ",", "All"}], "]"}], "]"}], ",", "wtstrategy", 
            ",", "speedeq"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"count", "=", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"b", "-", "1"}], ")"}], " ", 
                RowBox[{"Length", "[", "mutRgerm", "]"}], "*", 
                RowBox[{"Length", "[", "mutPb", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"r", "-", "1"}], ")"}], " ", 
                RowBox[{"Length", "[", "mutPb", "]"}]}], "+", "p"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"mutant", " ", "n0", " ", 
               RowBox[{"(", "equilibrium", ")"}]}], "*)"}], 
             RowBox[{"mutn0", "=", 
              RowBox[{
               RowBox[{"mutRgerm", "[", 
                RowBox[{"[", "r", "]"}], "]"}], "*", 
               RowBox[{
                RowBox[{"overgenadulteq", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"mutb", "[", 
                    RowBox[{"[", "b", "]"}], "]"}], ",", "wtd", ",", "wtm", 
                    ",", "wtmu"}], "}"}], ",", 
                  RowBox[{"mutRgerm", "[", 
                   RowBox[{"[", "r", "]"}], "]"}], ",", "wtn0", ",", 
                  "wtcellgen", ",", "200", ",", "speedeq"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"mutant", " ", "data"}], "*)"}], 
             RowBox[{"datamut", "=", 
              RowBox[{"acrosswithingenPb", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"mutb", "[", 
                   RowBox[{"[", "b", "]"}], "]"}], ",", "wtd", ",", "wtm", 
                  ",", "wtmu"}], "}"}], ",", 
                RowBox[{"mutRgerm", "[", 
                 RowBox[{"[", "r", "]"}], "]"}], ",", "mutn0", ",", 
                "wtcellgen", ",", 
                RowBox[{"mutPb", "[", 
                 RowBox[{"[", "p", "]"}], "]"}], ",", 
                RowBox[{"envscenset", "[", 
                 RowBox[{"[", 
                  RowBox[{"env", ",", "All"}], "]"}], "]"}], ",", 
                "mutstrategy", ",", "speedeq"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"Population", " ", "dynamics"}], ",", 
               RowBox[{"final", " ", "value", " ", "of", " ", "Nmut"}]}], 
              "*)"}], 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "1"}], "]"}], "]"}], "=", 
              "wtmu"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "2"}], "]"}], "]"}], "=", 
              RowBox[{"mutb", "[", 
               RowBox[{"[", "b", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "3"}], "]"}], "]"}], "=", 
              RowBox[{"mutRgerm", "[", 
               RowBox[{"[", "r", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "4"}], "]"}], "]"}], "=", 
              RowBox[{"mutPb", "[", 
               RowBox[{"[", "p", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "5"}], "]"}], "]"}], "=", 
              RowBox[{"datamut", "[", 
               RowBox[{"[", "4", "]"}], "]"}]}], 
             RowBox[{"(*", 
              RowBox[{
              "geometric", " ", "mean", " ", "fitness", " ", "of", " ", 
               "mutant"}], "*)"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "6"}], "]"}], "]"}], "=", 
              RowBox[{"selcoeff", "[", 
               RowBox[{
                RowBox[{"datamut", "[", 
                 RowBox[{"[", "4", "]"}], "]"}], ",", 
                RowBox[{"datawt", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], "]"}]}], 
             RowBox[{"(*", 
              RowBox[{
              "selection", " ", "coefficient", " ", "based", " ", "on", " ", 
               "geometric", " ", "mean", " ", "fitness"}], "*)"}], ";"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b", ",", "1", ",", 
             RowBox[{"Length", "[", "mutb", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "1", ",", 
             RowBox[{"Length", "[", "mutRgerm", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"p", ",", "1", ",", 
             RowBox[{"Length", "[", "mutPb", "]"}]}], "}"}]}], "]"}], ";"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"env", ",", "1", ",", 
         RowBox[{"Length", "[", "envscenset", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"output", "=", 
      RowBox[{"List", "[", 
       RowBox[{
       "envscenset", ",", "mutb", ",", "mutRgerm", ",", "mutPb", ",", 
        "mutstrategy", ",", "focalparameters", ",", "mutresult", ",", 
        "speedeq", ",", "ncost", ",", "Pbcost"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"StringTemplate", "[", "\"\<`1`.mx\>\"", "]"}], "[", 
        "outputfile", "]"}], ",", "output"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"PLOTS", ":", 
       RowBox[{
        RowBox[{"Strategies", " ", "A"}], "-", 
        RowBox[{"F", "."}]}]}], "*)"}], 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "focalparameters", "]"}], "\[Equal]", "1"}], 
       RowBox[{"(*", 
        RowBox[{"One", " ", "parameter", " ", "tested"}], "*)"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"envcolor", "=", 
          RowBox[{"GrayLevel", "[", "0.7", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "mutb", "]"}], ">", "1"}], ",", 
           RowBox[{"varvalues", "=", "mutb"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "mutRgerm", "]"}], ">", "1"}], ",", 
           RowBox[{"varvalues", "=", "mutRgerm"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "mutPb", "]"}], ">", "1"}], ",", 
           RowBox[{"varvalues", "=", "mutPb"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"xvalues", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"1", ",", 
               RowBox[{
                RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], 
                 ")"}], "/", "5"}]}], "]"}], ",", 
             RowBox[{"Length", "[", "varvalues", "]"}]}], "}"}], "]"}]}], ";",
          "\[IndentingNewLine]", 
         RowBox[{"xticks", "=", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"xvalues", ",", 
             RowBox[{"varvalues", "[", 
              RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ymax", "=", 
          RowBox[{"Max", "[", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"ymin", "=", 
          RowBox[{"Min", "[", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"ydistance", "=", 
          RowBox[{"Abs", "[", 
           RowBox[{"ymax", "-", "ymin"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutinvasionselcoeffplot", "=", 
          RowBox[{"Show", "[", 
           RowBox[{
            RowBox[{"ListLinePlot", "[", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
              RowBox[{"Joined", "\[Rule]", "True"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{"envcolor", ",", "Thick"}], "]"}]}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"ymin", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                   RowBox[{"ymax", "+", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
              ",", 
              RowBox[{"Axes", "\[Rule]", "False"}], ",", 
              RowBox[{"Frame", "\[Rule]", "True"}], ",", 
              RowBox[{"FrameLabel", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"focalparameters", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 "\"\<Selection coefficient (\\!\\(\\*SuperscriptBox[\\(s\\), \
\n\\(+\\)]\\))\>\""}], "}"}]}], ",", 
              RowBox[{"FrameStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
              RowBox[{"FrameTicks", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
              RowBox[{"FrameTicksStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
              RowBox[{"Epilog", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"(*", 
                 RowBox[{
                  RowBox[{"Text", "[", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "StringTemplate", "[", 
                    "\"\<Subscript[\n         p, \[Epsilon]]=`1`\>\"", "]"}], 
                    "[", "envcor", "]"}], ",", "20", ",", 
                    RowBox[{"Background", "\[Rule]", "None"}], ",", "Bold"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Round", "[", 
                    RowBox[{"0.5", 
                    RowBox[{"Length", "[", "varvalues", "]"}]}], "]"}], "+", 
                    "1"}], ",", 
                    RowBox[{"ymax", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "]"}], 
                  ","}], "*)"}], 
                RowBox[{"Line", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Length", "[", "varvalues", "]"}], ",", "0"}], 
                    "}"}]}], "}"}], "]"}], "}"}]}]}], "]"}], ",", 
            RowBox[{"ListLinePlot", "[", 
             RowBox[{
              RowBox[{"Mean", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
              ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"ymin", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                   RowBox[{"ymax", "+", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
              ",", 
              RowBox[{"PlotStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{
                 RowBox[{"GrayLevel", "[", "0", "]"}], ",", "Thick"}], 
                "]"}]}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"invasionselcoeffplot", "=", 
          RowBox[{"Show", "[", 
           RowBox[{"mutinvasionselcoeffplot", ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{"{", 
              RowBox[{"Blue", ",", 
               RowBox[{"Opacity", "[", "0.2", "]"}], ",", 
               RowBox[{"Rectangle", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "0.001"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Length", "[", "varvalues", "]"}], ",", "0.001"}], 
                  "}"}]}], "]"}]}], "}"}], "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Export", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "StringTemplate", "[", "\"\<`1`-mutinvasionselcoeffplot.`2`\>\"", 
             "]"}], "[", 
            RowBox[{"outputfile", ",", "plotfiletype"}], "]"}], ",", 
           "invasionselcoeffplot", ",", 
           RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"PLOTS", ":", 
       RowBox[{
        RowBox[{"Strategies", " ", "CD"}], "-", 
        RowBox[{"CF", "."}]}]}], "*)"}], 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "focalparameters", "]"}], "\[Equal]", "2"}], 
       RowBox[{"(*", 
        RowBox[{"Two", " ", "parameters", " ", "tested"}], "*)"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"var", "\[Equal]", "9"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xpar", "=", "2"}], 
             RowBox[{"(*", "b", "*)"}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xpar", "=", "4"}], 
             RowBox[{"(*", "Pb", "*)"}], ";"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"zmax", "=", 
              RowBox[{"Max", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"zmin", "=", 
              RowBox[{"Min", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"minpos", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
                 RowBox[{"Min", "[", 
                  RowBox[{"mutresult", "[", 
                   RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], 
                  "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"mincoord", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "minpos", ",", 
                  RowBox[{"{", 
                   RowBox[{"xpar", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"maxpos", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
                 RowBox[{"Max", "[", 
                  RowBox[{"mutresult", "[", 
                   RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], 
                  "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"maxcoord", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "maxpos", ",", 
                  RowBox[{"{", 
                   RowBox[{"xpar", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"mutinvasionselcoeffplot", "=", 
              RowBox[{"ListContourPlot", "[", 
               RowBox[{
                RowBox[{"mutresult", "[", 
                 RowBox[{"[", 
                  RowBox[{"env", ",", "All", ",", 
                   RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                 "]"}], ",", 
                RowBox[{"Contours", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"{", 
                    RowBox[{"Thick", ",", "Black", ",", "Dashed"}], "}"}]}], 
                    "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Thick", ",", "Dashed", ",", "Black"}], "}"}]}], 
                    "}"}], ",", 
                   RowBox[{"Sequence", "@@", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"#", ",", "None"}], "}"}], "&"}], "/@", 
                    RowBox[{"Range", "[", 
                    RowBox[{
                    RowBox[{"Min", "@", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", 
                    RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"Max", "@", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", 
                    RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                    "]"}]}], ",", ".0005"}], "]"}]}], ")"}]}]}], "}"}]}], 
                RowBox[{"(*", "50", "*)"}], ",", 
                RowBox[{"ContourStyle", "\[Rule]", "None"}], ",", 
                RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
                RowBox[{"ColorFunction", "\[Rule]", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}],
                     "[", 
                    RowBox[{"Rescale", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"zmin", ",", "zmax"}], "}"}]}], "]"}], "]"}], 
                   "&"}], ")"}]}], ",", 
                RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}], ",", 
                RowBox[{"FrameTicks", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
                RowBox[{"FrameLabel", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"focalparameters", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                   RowBox[{"focalparameters", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ",", 
                RowBox[{"FrameStyle", "\[Rule]", 
                 RowBox[{"Directive", "[", 
                  RowBox[{"Black", ",", "Thick", ",", "25"}], "]"}]}], ",", 
                RowBox[{"FrameTicksStyle", "\[Rule]", 
                 RowBox[{"Directive", "[", 
                  RowBox[{"Black", ",", "Thick", ",", "25"}], "]"}]}], ",", 
                RowBox[{"PlotLegends", "\[Rule]", 
                 RowBox[{"Placed", "[", 
                  RowBox[{
                   RowBox[{"BarLegend", "[", 
                    RowBox[{"Automatic", ",", "50", ",", 
                    RowBox[{"LegendMarkerSize", "\[Rule]", "500"}], ",", 
                    RowBox[{
                    "LegendLabel", "\[Rule]", 
                    "\"\<\\!\\(\\*SuperscriptBox[\\(s\\), \\(+\\)]\\)\>\""}], 
                    ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"Black", ",", "25"}], "]"}]}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"After", ",", "Top"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"Epilog", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"{", 
                   RowBox[{"Black", ",", 
                    RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
                    RowBox[{"Point", "[", 
                    RowBox[{"{", "maxcoord", "}"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "StringTemplate", "[", 
                    "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \
\\(\[Epsilon]\\)]\\)=`1`\>\"", "]"}], "[", "corr", "]"}], ",", "25", ",", 
                    RowBox[{"Background", "\[Rule]", "None"}], ",", "Bold"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Max", "[", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", "xpar"}], "]"}], "]"}], 
                    "]"}], "/", "2"}], ",", "0.95"}], "}"}]}], "]"}], "}"}]}],
                    "}"}], 
                  RowBox[{"(*", 
                   RowBox[{",", 
                    RowBox[{"{", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{"\"\<*\>\"", ",", "mincoord"}], "]"}], ",", 
                    "40"}], "]"}], "}"}]}], "*)"}], "}"}]}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Export", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "StringTemplate", "[", 
                 "\"\<`1`-invasionselcoeffplot-env`2`.`3`\>\"", "]"}], "[", 
                RowBox[{"outputfile", ",", "env", ",", "plotfiletype"}], 
                "]"}], ",", "mutinvasionselcoeffplot", ",", 
               RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"env", ",", "1", ",", 
             RowBox[{"Length", "[", "envscenset", "]"}]}], "}"}]}], "]"}], 
         ";"}], "}"}]}], "]"}], ";"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cost1", ",", "ncosts"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cost2", ",", "Pbcosts"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"var", ",", "testvar"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"corr", ",", "envcorr"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"speedeq", ",", "speed"}], "}"}]}], "]"}], "\n", "Now"}], "Input",\

 CellChangeTimes->{{3.8152950941520576`*^9, 
  3.815295094158442*^9}},ExpressionUUID->"94ba51ef-c6eb-43b4-bdbe-\
54c60ef38c00"],

Cell[BoxData["Notify"], "Input",
 CellChangeTimes->{{3.815295100460415*^9, 
  3.815295100468918*^9}},ExpressionUUID->"4ddaa580-d692-446c-b2ca-\
7161bb52b5ce"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evolutionary Invasion Analysis: delayed plasticity", "Title",
 CellChangeTimes->{
  3.815293685604912*^9, {3.815908852499757*^9, 3.8159088607425756`*^9}, {
   3.81590892485189*^9, 3.815908926295252*^9}, {3.815911230034223*^9, 
   3.815911232356944*^9}},ExpressionUUID->"1a810bc8-71e7-48c2-9031-\
1942ae8b0a2b"],

Cell[CellGroupData[{

Cell["Global settings", "Chapter",
 CellChangeTimes->{
  3.81529383508169*^9},ExpressionUUID->"eedec05c-a776-4774-84b0-4217e2e9d65f"],

Cell["Choose parameters to be tested", "Subtitle",
 CellChangeTimes->{
  3.815293869098483*^9},ExpressionUUID->"608ff216-65f6-4f24-afbd-\
e45d3f2966a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Choose", " ", "variable", " ", "to", " ", "be", " ", "tested"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"1", "=", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "B"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"2", "=", 
     RowBox[{"Rgerm", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "C"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"3", "=", 
     RowBox[{"PbD", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "D"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"4", "=", 
     RowBox[{"PbE", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "E"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"5", "=", 
     RowBox[{"PbF", " ", 
      RowBox[{"(", 
       RowBox[{"Strategy", " ", "F"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{"6", "=", 
     RowBox[{"PbD", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "D"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"7", "=", 
     RowBox[{"PbE", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "E"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"8", "=", 
     RowBox[{"PbF", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "F"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"9", "=", 
     RowBox[{"b", "+", 
      RowBox[{"Rgerm", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Strategy", " ", "B"}], "+", 
         RowBox[{"Strategy", " ", "C"}]}], ")"}]}]}]}], ";"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"testvar", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], ";"}], "*)"}], 
  RowBox[{
   RowBox[{"testvar", "=", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4", ",", "5"}], "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.815293874958054*^9, 3.815293874964964*^9}, {
  3.8159098225573797`*^9, 3.8159098424375*^9}, {3.815965309577276*^9, 
  3.8159653098469143`*^9}, {3.821202514309339*^9, 3.821202514557962*^9}},
 CellLabel->
  "In[111]:=",ExpressionUUID->"d44e4732-6cf4-4498-96c1-1b1427dfc804"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Select", " ", "envcorr", " ", "to", " ", "run", " ", "the", " ", 
    "analysis"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"nscenarios", "=", "1"}], ";", 
   RowBox[{"(*", 
    RowBox[{
    "Number", " ", "of", " ", "scenarios", " ", "per", " ", "correlation", 
     " ", "value"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"envcorr", "=", 
      RowBox[{"{", "0.10526315789473684`", "}"}]}], ";"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"envcorr", "=", 
    RowBox[{"{", 
     RowBox[{
     "0.10526315789473684`", ",", "0.5263157894736842`", ",", 
      "0.8947368421052632`"}], "}"}]}], ";", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"envcorr", "=", 
      RowBox[{"{", "0.8947368421052632`", "}"}]}], ";"}], "*)"}]}]}]], "Input",\

 CellChangeTimes->{{3.815293881032152*^9, 3.815293881039572*^9}, {
   3.815909290629512*^9, 3.815909292919446*^9}, {3.815909798926952*^9, 
   3.81590980651018*^9}, {3.8159098545110283`*^9, 3.8159098571271677`*^9}, 
   3.8212025170644817`*^9},
 CellLabel->
  "In[112]:=",ExpressionUUID->"fc21cb7d-c095-4eae-aadc-4b2ac1b9957f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotfiletype", "=", "\"\<pdf\>\""}], 
  RowBox[{"(*", "pdf", "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.815293887126153*^9, 3.815293887133655*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"37e9ec0b-ada3-45a4-9157-ec3bb73bb996"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ncosts", "=", 
   RowBox[{"{", "0.00001", "}"}]}], 
  RowBox[{"(*", "0.005", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Pbcosts", "=", 
   RowBox[{"{", "50", "}"}]}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "1.25", ",", "1.5", ",", "2.0"}], "}"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"{", "2", "}"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"Cb", " ", "relative", " ", "to", " ", "Cn"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{
    "0.0", ",", "0.5", ",", "1", ",", "2", ",", "5", ",", "10", ",", "20", 
     ",", "50"}], "}"}], "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.815293892688305*^9, 3.815293892695327*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"ce4bb28e-5831-4b1e-beb9-429dd7dfcd73"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"speed", "=", 
   RowBox[{"{", "1.0", "}"}]}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", "0.75"}], "}"}], "*)"}], 
  RowBox[{"(*", 
   RowBox[{"Developmental", " ", "speed"}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"speedPb", "=", 
    RowBox[{"3", "/", "20"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"??", 
    RowBox[{"??", "?"}]}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.815293897835882*^9, 3.815293897843685*^9}, {
   3.815909242395515*^9, 3.8159092483401003`*^9}, {3.8159092981642437`*^9, 
   3.815909314235754*^9}, {3.8159095049932823`*^9, 3.815909521207282*^9}, 
   3.815909666270095*^9},
 CellLabel->
  "In[116]:=",ExpressionUUID->"2ccae347-261d-4042-aa92-91247995fa84"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulations", "Chapter",
 CellChangeTimes->{
  3.815293908279591*^9},ExpressionUUID->"98fef14b-371e-431e-b915-\
1b6b6d2dd1d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"WT", " ", "values"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"wtb", "=", "0.000"}], 
    RowBox[{"(*", 
     RowBox[{"no", " ", "amplification"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtd", "=", "0.100"}], 
    RowBox[{"(*", 
     RowBox[{
     "degradation", " ", "rate", " ", "is", " ", "assumed", " ", "to", " ", 
      "be", " ", "an", " ", "intrisic", " ", "stability", " ", "property", 
      " ", "of", " ", "the", " ", "specific", " ", "sRNA", " ", "molecule", 
      " ", "under", " ", "focus"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtm", "=", "5.000"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtRgerm", "=", "0"}], 
    RowBox[{"(*", 
     RowBox[{"no", " ", "transmission"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtPb", "=", "0"}], 
    RowBox[{"(*", 
     RowBox[{"no", " ", "responsiveness"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtstrategy", "=", "1"}], 
    RowBox[{"(*", 
     RowBox[{"strategy", " ", "A"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtcellgen", "=", "20"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtn0", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"wtspeedeq", "=", "1.0"}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{"Fitness", " ", "function", " ", "values"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Beta]", "=", "0.1"}], 
    RowBox[{"(*", "0.1", "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"\[Alpha]", "=", "15"}], 
    RowBox[{"(*", "4", "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"l", "=", "0"}], 
    RowBox[{"(*", "0", "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"mid", "=", "5"}], 
    RowBox[{"(*", "5", "*)"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.815293915237474*^9, 3.8152939152449293`*^9}, 
   3.815385269543971*^9},
 CellLabel->
  "In[118]:=",ExpressionUUID->"345506ae-eb2d-4725-9e18-35317b2af77f"],

Cell[BoxData[{"Now", "\n", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"envcorrpositions", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"envcorrvalues", "//", "N"}], ",", "corr"}], "]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"envscenset", "=", 
      RowBox[{"corrscenarios", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"RandomSample", "[", 
          RowBox[{"envcorrpositions", ",", "nscenarios"}], "]"}], ",", 
         "All"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
      "Costs", " ", "used", " ", "in", " ", "the", " ", "fitness", " ", 
       RowBox[{"function", "."}]}], "*)"}], 
     RowBox[{"ncost", "=", "cost1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Pbcost", "=", 
      RowBox[{"cost1", " ", "cost2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"corrvalue", "=", 
      RowBox[{"NumberForm", "[", 
       RowBox[{"corr", ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Pbvelo", "=", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        RowBox[{"speedPb", "//", "N"}], ",", "2"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Calculate", " ", "value", " ", "of", " ", "wildtype", " ", 
       RowBox[{"mu", "."}]}], "*)"}], 
     RowBox[{"mufit", "=", 
      RowBox[{"ParallelTable", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"wtmu", ",", 
          RowBox[{"GeometricMean", "[", 
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ConstantArray", "[", 
               RowBox[{
                RowBox[{"fitfuncPb", "[", 
                 RowBox[{"0.1", ",", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}],
                    "]"}], ",", "wtPb"}], "]"}], ",", 
                RowBox[{"ngenerations", "/", "2"}]}], "]"}], ",", 
              RowBox[{"ConstantArray", "[", 
               RowBox[{
                RowBox[{"fitfuncPb", "[", 
                 RowBox[{"0.9", ",", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Evaluate", "[", 
                    RowBox[{
                    RowBox[{"n", "[", "t", "]"}], "/.", 
                    RowBox[{"solution", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], 
                    "}"}], ",", "wtn0", ",", "wtcellgen", ",", "wtspeedeq"}], 
                    "]"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"t", ",", "0", ",", "wtcellgen"}], "}"}]}], "]"}],
                    "]"}], ",", "wtPb"}], "]"}], ",", 
                RowBox[{"ngenerations", "/", "2"}]}], "]"}]}], "}"}], "]"}], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"wtmu", ",", "0", ",", "10", ",", "0.001"}], "}"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mumaxgeofit", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"mufit", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"wtmu", "=", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Select", "[", 
         RowBox[{"mufit", ",", 
          RowBox[{
           RowBox[{"And", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "mumaxgeofit"}], 
            "]"}], "&"}]}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "b", "*)"}], 
        RowBox[{
         RowBox[{"mutb", "=", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "5", ",", "0.005"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"Mutant", " ", "b", " ", "values"}], "*)"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"mutRgerm", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutPb", "=", 
          RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutstrategy", "=", "1"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[\\(b\\), \\(+\\)]\\)\>\"", 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyB-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n        5`-Pbspeed`6`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq", ",", "Pbvelo"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "2"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "Rgerm", "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"mutb", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutRgerm", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "1", ",", "0.005"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutPb", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutstrategy", "=", "1"}], ";"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \n\
\\(germ\\)], \\(+\\)]\\)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyC-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n5`-Pbspeed`6`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq", ",", "Pbvelo"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "3"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "PbD", "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"mutb", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutRgerm", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutPb", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutstrategy", "=", "2"}], ";"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy D)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyD-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n5`-Pbspeed`6`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq", ",", "Pbvelo"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "4"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "PbE", "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"mutb", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutRgerm", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutPb", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutstrategy", "=", "3"}], ";"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy E)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyE-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n5`-Pbspeed`6`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq", ",", "Pbvelo"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "5"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", "PbF", "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"mutb", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutRgerm", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutPb", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutstrategy", "=", "4"}], ";"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{
          "{", "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy F)\>\"", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyF-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\
speedeq`\n5`-Pbspeed`6`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq", ",", "Pbvelo"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "6"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"PbD", "+", "Rgerm"}], "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"mutb", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutRgerm", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "0.2", ",", "0.01"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutPb", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutstrategy", "=", "2"}], ";"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy D)\>\"", ",", 
            "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(germ\\)], \n\
\\(+\\)]\\)\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyCD-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\n\
speedeq`5`-Pbspeed`6`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq", ",", "Pbvelo"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "7"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"PbE", "+", "Rgerm"}], "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"mutb", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutRgerm", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "0.2", ",", "0.01"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutPb", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutstrategy", "=", "3"}], ";"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy E)\>\"", ",", 
            "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(germ\\)], \n\
\\(+\\)]\\)\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyCE-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\n\
speedeq`5`-Pbspeed`6`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq", ",", "Pbvelo"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "8"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"PbF", "+", "Rgerm"}], "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"mutb", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutRgerm", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "0.2", ",", "0.01"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutPb", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "1", ",", "0.05"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Pb", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutstrategy", "=", "4"}], ";"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(P\\), \n\\(b\\)], \
\\(+\\)]\\) (Strategy F)\>\"", ",", 
            "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(germ\\)], \n\
\\(+\\)]\\)\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyCF-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\n\
speedeq`5`-Pbspeed`6`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq", ",", "Pbvelo"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"var", "\[Equal]", "9"}], ",", 
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"b", "+", "Rgerm"}], "*)"}], 
        RowBox[{
         RowBox[{
          RowBox[{"mutb", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "0.5", ",", "0.0005"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "b", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutRgerm", "=", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", "0.2", ",", "0.01"}], "]"}]}], 
          RowBox[{"(*", 
           RowBox[{"Mutant", " ", "Rgerm", " ", "values"}], "*)"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"mutPb", "=", 
           RowBox[{"{", "0", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"mutstrategy", "=", "1"}], ";"}], 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"Mutant", " ", 
             RowBox[{"strategy", ":", "1"}]}], "=", "A"}], ",", 
           RowBox[{"2", "=", "D"}], ",", 
           RowBox[{"3", "=", "E"}], ",", 
           RowBox[{"4", "=", "F"}]}], "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"focalparameters", "=", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\\!\\(\\*SuperscriptBox[\\(b\\), \\(+\\)]\\)\>\"", ",", 
            "\"\<\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(germ\\)], \n\
\\(+\\)]\\)\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"outputfile", "=", 
          RowBox[{"StringReplace", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<a5si-strategyBC-envcorr`1`-wtmu`2`-ncost`3`-Pbcost`4`-\n\
speedeq`5`-Pbspeed`6`\>\"", "]"}], "[", 
             RowBox[{
             "corrvalue", ",", "wtmu", ",", "ncost", ",", "Pbcost", ",", 
              "speedeq", ",", "Pbvelo"}], "]"}], ",", 
            RowBox[{"\"\<.\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}]}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Table", " ", "to", " ", "collect", " ", "the", " ", 
       RowBox[{"result", ":", 
        RowBox[{"mutresult", "[", 
         RowBox[{"envscenario", ",", "varcombination", ",", "output"}], 
         "]"}]}]}], "*)"}], 
     RowBox[{"mutresult", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"env", ",", 
          RowBox[{"Length", "[", "envscenset", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"var", ",", 
          RowBox[{
           RowBox[{"Length", "[", "mutb", "]"}], "*", 
           RowBox[{"Length", "[", "mutRgerm", "]"}], "*", 
           RowBox[{"Length", "[", "mutPb", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"out", ",", "6"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"SetSharedVariable", "[", "mutresult", "]"}], 
     RowBox[{"(*", 
      RowBox[{
      "Make", " ", "it", " ", "available", " ", "to", " ", "all", " ", 
       "kernels"}], "*)"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ParallelDo", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"(*", 
         RowBox[{"Wildtype", " ", "data"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"datawt", "=", 
          RowBox[{"acrosswithingenPbspeed", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"wtb", ",", "wtd", ",", "wtm", ",", "wtmu"}], "}"}], ",",
             "wtRgerm", ",", "wtn0", ",", "wtcellgen", ",", "wtPb", ",", 
            "speedPb", ",", 
            RowBox[{"envscenset", "[", 
             RowBox[{"[", 
              RowBox[{"env", ",", "All"}], "]"}], "]"}], ",", "wtstrategy", 
            ",", "speedeq"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"count", "=", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"b", "-", "1"}], ")"}], " ", 
                RowBox[{"Length", "[", "mutRgerm", "]"}], "*", 
                RowBox[{"Length", "[", "mutPb", "]"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"r", "-", "1"}], ")"}], " ", 
                RowBox[{"Length", "[", "mutPb", "]"}]}], "+", "p"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"mutant", " ", "n0", " ", 
               RowBox[{"(", "equilibrium", ")"}]}], "*)"}], 
             RowBox[{"mutn0", "=", 
              RowBox[{
               RowBox[{"mutRgerm", "[", 
                RowBox[{"[", "r", "]"}], "]"}], "*", 
               RowBox[{
                RowBox[{"overgenadulteq", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"mutb", "[", 
                    RowBox[{"[", "b", "]"}], "]"}], ",", "wtd", ",", "wtm", 
                    ",", "wtmu"}], "}"}], ",", 
                  RowBox[{"mutRgerm", "[", 
                   RowBox[{"[", "r", "]"}], "]"}], ",", "wtn0", ",", 
                  "wtcellgen", ",", "200", ",", "speedeq"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"mutant", " ", "data"}], "*)"}], 
             RowBox[{"datamut", "=", 
              RowBox[{"acrosswithingenPbspeed", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"mutb", "[", 
                   RowBox[{"[", "b", "]"}], "]"}], ",", "wtd", ",", "wtm", 
                  ",", "wtmu"}], "}"}], ",", 
                RowBox[{"mutRgerm", "[", 
                 RowBox[{"[", "r", "]"}], "]"}], ",", "mutn0", ",", 
                "wtcellgen", ",", 
                RowBox[{"mutPb", "[", 
                 RowBox[{"[", "p", "]"}], "]"}], ",", "speedPb", ",", 
                RowBox[{"envscenset", "[", 
                 RowBox[{"[", 
                  RowBox[{"env", ",", "All"}], "]"}], "]"}], ",", 
                "mutstrategy", ",", "speedeq"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"Population", " ", "dynamics"}], ",", 
               RowBox[{"final", " ", "value", " ", "of", " ", "Nmut"}]}], 
              "*)"}], 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "1"}], "]"}], "]"}], "=", 
              "wtmu"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "2"}], "]"}], "]"}], "=", 
              RowBox[{"mutb", "[", 
               RowBox[{"[", "b", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "3"}], "]"}], "]"}], "=", 
              RowBox[{"mutRgerm", "[", 
               RowBox[{"[", "r", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "4"}], "]"}], "]"}], "=", 
              RowBox[{"mutPb", "[", 
               RowBox[{"[", "p", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "5"}], "]"}], "]"}], "=", 
              RowBox[{"datamut", "[", 
               RowBox[{"[", "4", "]"}], "]"}]}], 
             RowBox[{"(*", 
              RowBox[{
              "geometric", " ", "mean", " ", "fitness", " ", "of", " ", 
               "mutant"}], "*)"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"env", ",", "count", ",", "6"}], "]"}], "]"}], "=", 
              RowBox[{"selcoeff", "[", 
               RowBox[{
                RowBox[{"datamut", "[", 
                 RowBox[{"[", "4", "]"}], "]"}], ",", 
                RowBox[{"datawt", "[", 
                 RowBox[{"[", "4", "]"}], "]"}]}], "]"}]}], 
             RowBox[{"(*", 
              RowBox[{
              "selection", " ", "coefficient", " ", "based", " ", "on", " ", 
               "geometric", " ", "mean", " ", "fitness"}], "*)"}], ";"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b", ",", "1", ",", 
             RowBox[{"Length", "[", "mutb", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "1", ",", 
             RowBox[{"Length", "[", "mutRgerm", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"p", ",", "1", ",", 
             RowBox[{"Length", "[", "mutPb", "]"}]}], "}"}]}], "]"}], ";"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"env", ",", "1", ",", 
         RowBox[{"Length", "[", "envscenset", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"output", "=", 
      RowBox[{"List", "[", 
       RowBox[{
       "envscenset", ",", "mutb", ",", "mutRgerm", ",", "mutPb", ",", 
        "mutstrategy", ",", "focalparameters", ",", "mutresult", ",", 
        "speedeq", ",", "ncost", ",", "Pbcost"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"StringTemplate", "[", "\"\<`1`.mx\>\"", "]"}], "[", 
        "outputfile", "]"}], ",", "output"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"PLOTS", ":", 
       RowBox[{
        RowBox[{"Strategies", " ", "A"}], "-", 
        RowBox[{"F", "."}]}]}], "*)"}], 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "focalparameters", "]"}], "\[Equal]", "1"}], 
       RowBox[{"(*", 
        RowBox[{"One", " ", "parameter", " ", "tested"}], "*)"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"envcolor", "=", 
          RowBox[{"GrayLevel", "[", "0.7", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "mutb", "]"}], ">", "1"}], ",", 
           RowBox[{"varvalues", "=", "mutb"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "mutRgerm", "]"}], ">", "1"}], ",", 
           RowBox[{"varvalues", "=", "mutRgerm"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "mutPb", "]"}], ">", "1"}], ",", 
           RowBox[{"varvalues", "=", "mutPb"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"xvalues", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"1", ",", 
               RowBox[{
                RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], 
                 ")"}], "/", "5"}]}], "]"}], ",", 
             RowBox[{"Length", "[", "varvalues", "]"}]}], "}"}], "]"}]}], ";",
          "\[IndentingNewLine]", 
         RowBox[{"xticks", "=", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"xvalues", ",", 
             RowBox[{"varvalues", "[", 
              RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ymax", "=", 
          RowBox[{"Max", "[", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"ymin", "=", 
          RowBox[{"Min", "[", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"ydistance", "=", 
          RowBox[{"Abs", "[", 
           RowBox[{"ymax", "-", "ymin"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"mutinvasionselcoeffplot", "=", 
          RowBox[{"Show", "[", 
           RowBox[{
            RowBox[{"ListLinePlot", "[", 
             RowBox[{
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
              RowBox[{"Joined", "\[Rule]", "True"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{"envcolor", ",", "Thick"}], "]"}]}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"ymin", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                   RowBox[{"ymax", "+", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
              ",", 
              RowBox[{"Axes", "\[Rule]", "False"}], ",", 
              RowBox[{"Frame", "\[Rule]", "True"}], ",", 
              RowBox[{"FrameLabel", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"focalparameters", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 "\"\<Selection coefficient (\\!\\(\\*SuperscriptBox[\\(s\\), \
\n\\(+\\)]\\))\>\""}], "}"}]}], ",", 
              RowBox[{"FrameStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
              RowBox[{"FrameTicks", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
              RowBox[{"FrameTicksStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
              RowBox[{"Epilog", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"(*", 
                 RowBox[{
                  RowBox[{"Text", "[", 
                   RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "StringTemplate", "[", 
                    "\"\<Subscript[\n         p, \[Epsilon]]=`1`\>\"", "]"}], 
                    "[", "envcor", "]"}], ",", "20", ",", 
                    RowBox[{"Background", "\[Rule]", "None"}], ",", "Bold"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Round", "[", 
                    RowBox[{"0.5", 
                    RowBox[{"Length", "[", "varvalues", "]"}]}], "]"}], "+", 
                    "1"}], ",", 
                    RowBox[{"ymax", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "]"}], 
                  ","}], "*)"}], 
                RowBox[{"Line", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Length", "[", "varvalues", "]"}], ",", "0"}], 
                    "}"}]}], "}"}], "]"}], "}"}]}]}], "]"}], ",", 
            RowBox[{"ListLinePlot", "[", 
             RowBox[{
              RowBox[{"Mean", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
              ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"ymin", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                   RowBox[{"ymax", "+", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
              ",", 
              RowBox[{"PlotStyle", "\[Rule]", 
               RowBox[{"Directive", "[", 
                RowBox[{
                 RowBox[{"GrayLevel", "[", "0", "]"}], ",", "Thick"}], 
                "]"}]}]}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"invasionselcoeffplot", "=", 
          RowBox[{"Show", "[", 
           RowBox[{"mutinvasionselcoeffplot", ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{"{", 
              RowBox[{"Blue", ",", 
               RowBox[{"Opacity", "[", "0.2", "]"}], ",", 
               RowBox[{"Rectangle", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "0.001"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Length", "[", "varvalues", "]"}], ",", "0.001"}], 
                  "}"}]}], "]"}]}], "}"}], "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Export", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "StringTemplate", "[", "\"\<`1`-mutinvasionselcoeffplot.`2`\>\"", 
             "]"}], "[", 
            RowBox[{"outputfile", ",", "plotfiletype"}], "]"}], ",", 
           "invasionselcoeffplot", ",", 
           RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
        "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"PLOTS", ":", 
       RowBox[{
        RowBox[{"Strategies", " ", "CD"}], "-", 
        RowBox[{"CF", "."}]}]}], "*)"}], 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "focalparameters", "]"}], "\[Equal]", "2"}], 
       RowBox[{"(*", 
        RowBox[{"Two", " ", "parameters", " ", "tested"}], "*)"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"var", "\[Equal]", "9"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xpar", "=", "2"}], 
             RowBox[{"(*", "b", "*)"}], ";"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xpar", "=", "4"}], 
             RowBox[{"(*", "Pb", "*)"}], ";"}], "}"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Do", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"zmax", "=", 
              RowBox[{"Max", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"zmin", "=", 
              RowBox[{"Min", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"minpos", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
                 RowBox[{"Min", "[", 
                  RowBox[{"mutresult", "[", 
                   RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], 
                  "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"mincoord", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "minpos", ",", 
                  RowBox[{"{", 
                   RowBox[{"xpar", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"maxpos", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"Position", "[", 
                RowBox[{
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
                 RowBox[{"Max", "[", 
                  RowBox[{"mutresult", "[", 
                   RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", "6"}], "]"}], "]"}], 
                  "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"maxcoord", "=", 
              RowBox[{"Flatten", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"env", ",", "maxpos", ",", 
                  RowBox[{"{", 
                   RowBox[{"xpar", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"mutinvasionselcoeffplot", "=", 
              RowBox[{"ListContourPlot", "[", 
               RowBox[{
                RowBox[{"mutresult", "[", 
                 RowBox[{"[", 
                  RowBox[{"env", ",", "All", ",", 
                   RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                 "]"}], ",", 
                RowBox[{"Contours", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"{", 
                    RowBox[{"Thick", ",", "Black", ",", "Dashed"}], "}"}]}], 
                    "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Thick", ",", "Dashed", ",", "Black"}], "}"}]}], 
                    "}"}], ",", 
                   RowBox[{"Sequence", "@@", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"#", ",", "None"}], "}"}], "&"}], "/@", 
                    RowBox[{"Range", "[", 
                    RowBox[{
                    RowBox[{"Min", "@", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", 
                    RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"Max", "@", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", 
                    RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                    "]"}]}], ",", ".0005"}], "]"}]}], ")"}]}]}], "}"}]}], 
                RowBox[{"(*", "50", "*)"}], ",", 
                RowBox[{"ContourStyle", "\[Rule]", "None"}], ",", 
                RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
                RowBox[{"ColorFunction", "\[Rule]", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}],
                     "[", 
                    RowBox[{"Rescale", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"zmin", ",", "zmax"}], "}"}]}], "]"}], "]"}], 
                   "&"}], ")"}]}], ",", 
                RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
                RowBox[{"Frame", "\[Rule]", "True"}], ",", 
                RowBox[{"FrameTicks", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
                RowBox[{"FrameLabel", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"focalparameters", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                   RowBox[{"focalparameters", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ",", 
                RowBox[{"FrameStyle", "\[Rule]", 
                 RowBox[{"Directive", "[", 
                  RowBox[{"Black", ",", "Thick", ",", "25"}], "]"}]}], ",", 
                RowBox[{"FrameTicksStyle", "\[Rule]", 
                 RowBox[{"Directive", "[", 
                  RowBox[{"Black", ",", "Thick", ",", "25"}], "]"}]}], ",", 
                RowBox[{"PlotLegends", "\[Rule]", 
                 RowBox[{"Placed", "[", 
                  RowBox[{
                   RowBox[{"BarLegend", "[", 
                    RowBox[{"Automatic", ",", "50", ",", 
                    RowBox[{"LegendMarkerSize", "\[Rule]", "500"}], ",", 
                    RowBox[{
                    "LegendLabel", "\[Rule]", 
                    "\"\<\\!\\(\\*SuperscriptBox[\\(s\\), \\(+\\)]\\)\>\""}], 
                    ",", 
                    RowBox[{"LabelStyle", "\[Rule]", 
                    RowBox[{"Directive", "[", 
                    RowBox[{"Black", ",", "25"}], "]"}]}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"After", ",", "Top"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"Epilog", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"{", 
                   RowBox[{"Black", ",", 
                    RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
                    RowBox[{"Point", "[", 
                    RowBox[{"{", "maxcoord", "}"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Text", "[", 
                    RowBox[{
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "StringTemplate", "[", 
                    "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \
\\(\[Epsilon]\\)]\\)=`1`\>\"", "]"}], "[", "corr", "]"}], ",", "25", ",", 
                    RowBox[{"Background", "\[Rule]", "None"}], ",", "Bold"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Max", "[", 
                    RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"env", ",", "All", ",", "xpar"}], "]"}], "]"}], 
                    "]"}], "/", "2"}], ",", "0.95"}], "}"}]}], "]"}], "}"}]}],
                    "}"}], 
                  RowBox[{"(*", 
                   RowBox[{",", 
                    RowBox[{"{", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Text", "[", 
                    RowBox[{"\"\<*\>\"", ",", "mincoord"}], "]"}], ",", 
                    "40"}], "]"}], "}"}]}], "*)"}], "}"}]}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Export", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "StringTemplate", "[", 
                 "\"\<`1`-invasionselcoeffplot-env`2`.`3`\>\"", "]"}], "[", 
                RowBox[{"outputfile", ",", "env", ",", "plotfiletype"}], 
                "]"}], ",", "mutinvasionselcoeffplot", ",", 
               RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"env", ",", "1", ",", 
             RowBox[{"Length", "[", "envscenset", "]"}]}], "}"}]}], "]"}], 
         ";"}], "}"}]}], "]"}], ";"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cost1", ",", "ncosts"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cost2", ",", "Pbcosts"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"var", ",", "testvar"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"corr", ",", "envcorr"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"speedeq", ",", "speed"}], "}"}]}], "]"}], "\n", "Now"}], "Input",\

 CellChangeTimes->{{3.815293935169242*^9, 3.815293935175419*^9}, {
  3.8159093440540743`*^9, 3.8159094486014013`*^9}, {3.815909894927163*^9, 
  3.815910000332191*^9}, {3.821177436257063*^9, 3.8211775049634323`*^9}, {
  3.821177571131987*^9, 3.821177572388097*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"9de2b292-2a74-4b1c-ad0c-4b2e671dd021"],

Cell[BoxData["Notify"], "Input",
 CellChangeTimes->{{3.815293942670762*^9, 3.815293942679002*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"5e23eabd-e93c-4d15-af5c-e2860a73411d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots", "Title",
 CellChangeTimes->{{3.815295108980255*^9, 
  3.8152951101385527`*^9}},ExpressionUUID->"26a16030-ae08-4131-9a63-\
5fb6ac9a3ed0"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.815295258331588*^9, 3.815295258338398*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"40fd1e18-1729-49b9-868d-711af23e2bb1"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.815295264017021*^9, 3.815295264024865*^9}, 
   3.8152956548305817`*^9},
 CellLabel->"In[2]:=",ExpressionUUID->"8f24a24c-494a-4dfd-8a80-87902931666f"],

Cell[CellGroupData[{

Cell["Import files", "Chapter",
 CellChangeTimes->{
  3.815295140125601*^9},ExpressionUUID->"e1394684-4f75-4eec-9fed-\
cca3874056e0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "fileB", "=", 
   "\"\<a5si-strategyB-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileBslow", "=", 
   "\"\<a5si-strategyB-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq075.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"testvarB", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorB", "=", "\"\<{0.11, 0.53, 0.89}\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.815295146358206*^9, 3.815295146365436*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"95ac5582-e244-4521-aaee-f5939d2a7696"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "fileC", "=", 
   "\"\<a5si-strategyC-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileCslow", "=", 
   "\"\<a5si-strategyC-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq075.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"testvarC", "=", "2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorC", "=", "\"\<{0.11, 0.53, 0.89}\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.815295152191834*^9, 3.8152951521989326`*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"98f614e0-4201-4759-8984-1d53e89fea93"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "fileD", "=", 
   "\"\<a5si-strategyD-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileDslow", "=", 
   "\"\<a5si-strategyD-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq075.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"testvarD", "=", "3"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorD", "=", "\"\<{0.11, 0.53, 0.89}\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.815295157283977*^9, 3.815295157291671*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"a3010059-1eb9-4d4b-8c0a-f809cd3f7164"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "fileE1", "=", 
   "\"\<a5si-strategyE-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileE2", "=", 
   "\"\<a5si-strategyE-envcorr053-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileE3", "=", 
   "\"\<a5si-strategyE-envcorr089-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileE1slow", "=", 
   "\"\<a5si-strategyE-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq075.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileE2slow", "=", 
   "\"\<a5si-strategyE-envcorr053-wtmu6798-ncost000001-Pbcost00005-speedeq075.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileE3slow", "=", 
   "\"\<a5si-strategyE-envcorr089-wtmu6798-ncost000001-Pbcost00005-speedeq075.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"testvarE", "=", "4"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorE1", "=", "\"\<0.11\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorE2", "=", "\"\<0.53\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorE3", "=", "\"\<0.89\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.8152951635838327`*^9, 3.815295163590787*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"92d1a042-4ef7-4675-9633-e3ff20a2918b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "fileF1", "=", 
   "\"\<a5si-strategyF-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileF2", "=", 
   "\"\<a5si-strategyF-envcorr053-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileF3", "=", 
   "\"\<a5si-strategyF-envcorr089-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileF1slow", "=", 
   "\"\<a5si-strategyF-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq075.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileF2slow", "=", 
   "\"\<a5si-strategyF-envcorr053-wtmu6798-ncost000001-Pbcost00005-speedeq075.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileF3slow", "=", 
   "\"\<a5si-strategyF-envcorr089-wtmu6798-ncost000001-Pbcost00005-speedeq075.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"testvarF", "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorF1", "=", "\"\<0.11\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorF2", "=", "\"\<0.53\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorF3", "=", "\"\<0.89\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.815295170571475*^9, 3.815295170579783*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"9b1b5fed-06a3-44ed-9388-ac62a904f25e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "fileDhighPbcost", "=", 
   "\"\<a5si-strategyD-envcorr011-wtmu6798-ncost000001-Pbcost0005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileE1highPbcost", "=", 
   "\"\<a5si-strategyE-envcorr011-wtmu6798-ncost000001-Pbcost0005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileE3highPbcost", "=", 
   "\"\<a5si-strategyE-envcorr089-wtmu6798-ncost000001-Pbcost0005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileF1highPbcost", "=", 
   "\"\<a5si-strategyF-envcorr011-wtmu6798-ncost000001-Pbcost0005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileF3highPbcost", "=", 
   "\"\<a5si-strategyF-envcorr089-wtmu6798-ncost000001-Pbcost0005-speedeq10.\
mx\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.815295178443129*^9, 3.815295178451415*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"c69b539c-5add-4723-99d5-eafabc6c922a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "fileBC", "=", 
     "\"\<a5si-strategyBC-envcorr011-wtmu6798-ncost000001-Pbcost00005-\
speedeq10.mx\>\""}], ";"}], "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{
    "fileBC", "=", 
     "\"\<a5si-strategyBC-envcorr089-wtmu6798-ncost000001-Pbcost00005-\
speedeq10.mx\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{"envcorBC", "=", "\"\<{0.11, 0.53, 0.89}\>\""}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.815295186850514*^9, 3.815295186860108*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"50d85788-0a00-433a-8189-57f7866da318"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "fileCD1", "=", 
   "\"\<a5si-strategyCD-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileCD3", "=", 
   "\"\<a5si-strategyCD-envcorr089-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileCE1", "=", 
   "\"\<a5si-strategyCE-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileCE3", "=", 
   "\"\<a5si-strategyCE-envcorr089-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileCF1", "=", 
   "\"\<a5si-strategyCF-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "fileCF3", "=", 
   "\"\<a5si-strategyCF-envcorr089-wtmu6798-ncost000001-Pbcost00005-speedeq10.\
mx\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorCD1", "=", "\"\<0.11\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorCD3", "=", "\"\<0.89\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorCE1", "=", "\"\<0.11\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorCE3", "=", "\"\<0.89\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorCF1", "=", "\"\<0.11\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{"envcorCF3", "=", "\"\<0.89\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.815295193800193*^9, 3.815295193806584*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"af644773-4945-48bb-9f76-9226d12e1a71"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "fileDdelayedPb", "=", 
   "\"\<a5si-strategyD-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq-\
Pbspeed015.mx\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "fileE1delayedPb", "=", 
   "\"\<a5si-strategyE-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq-\
Pbspeed015.mx\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "fileE2delayedPb", "=", 
   "\"\<a5si-strategyE-envcorr053-wtmu6798-ncost000001-Pbcost00005-speedeq-\
Pbspeed015.mx\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "fileE3delayedPb", "=", 
   "\"\<a5si-strategyE-envcorr089-wtmu6798-ncost000001-Pbcost00005-speedeq-\
Pbspeed015.mx\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "fileF1delayedPb", "=", 
   "\"\<a5si-strategyF-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq-\
Pbspeed015.mx\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "fileF2delayedPb", "=", 
   "\"\<a5si-strategyF-envcorr053-wtmu6798-ncost000001-Pbcost00005-speedeq-\
Pbspeed015.mx\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "fileF3delayedPb", "=", 
   "\"\<a5si-strategyF-envcorr089-wtmu6798-ncost000001-Pbcost00005-speedeq-\
Pbspeed015.mx\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filesdelayedPb", "=", 
   RowBox[{"{", 
    RowBox[{
    "fileDdelayedPb", ",", "fileE1delayedPb", ",", "fileE2delayedPb", ",", 
     "fileE3delayedPb", ",", "fileF1delayedPb", ",", "fileF2delayedPb", ",", 
     "fileF3delayedPb"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.819622671557063*^9, 3.819622823145677*^9}, 
   3.819622944104823*^9, {3.819652155637021*^9, 3.819652198439711*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"17a4af88-57cf-4d70-a981-fd7520ad4752"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot functions", "Chapter",
 CellChangeTimes->{
  3.815295201490445*^9},ExpressionUUID->"1e76fce8-151f-4c6c-9b50-\
0481beeee29a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"strategiesBCD", "[", 
    RowBox[{"file_", ",", "envcor_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"output", "=", 
       RowBox[{"Import", "[", "file", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"envscenset", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutb", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutRgerm", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutPb", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutstrategy", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"focalparameters", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutresult", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"speedeq", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ncost", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Pbcost", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "10", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"envcolor", "=", 
       RowBox[{"GrayLevel", "[", "0.7", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "mutb", "]"}], ">", "1"}], ",", 
        RowBox[{"varvalues", "=", "mutb"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "mutRgerm", "]"}], ">", "1"}], ",", 
        RowBox[{"varvalues", "=", "mutRgerm"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "mutPb", "]"}], ">", "1"}], ",", 
        RowBox[{"varvalues", "=", "mutPb"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xvalues", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ")"}], 
             "/", "5"}]}], "]"}], ",", 
          RowBox[{"Length", "[", "varvalues", "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xticks", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"xvalues", ",", 
          RowBox[{"varvalues", "[", 
           RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ymax", "=", 
       RowBox[{"Max", "[", 
        RowBox[{"mutresult", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ymin", "=", 
       RowBox[{"Min", "[", 
        RowBox[{"mutresult", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ydistance", "=", 
       RowBox[{"Abs", "[", 
        RowBox[{"ymax", "-", "ymin"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutinvasionselcoeffplot", "=", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"envcolor", ",", "Thick"}], "]"}]}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
                "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", 
                 RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                RowBox[{"ymax", "+", 
                 RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"focalparameters", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              "\"\<Selection coefficient (\\!\\(\\*SuperscriptBox[\\(s\\), \n\
\\(+\\)]\\))\>\""}], "}"}]}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
           RowBox[{"FrameTicks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"FrameTicksStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
           RowBox[{"AxesOrigin", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
           RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "StringTemplate", "[", 
                    "\"\<Subscript[\n        p, \[Epsilon]]=`1`\>\"", "]"}], 
                    "[", "envcor", "]"}], ",", "20", ",", 
                   RowBox[{"Background", "\[Rule]", "None"}], ",", "Bold"}], 
                  "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Round", "[", 
                    RowBox[{"0.5", 
                    RowBox[{"Length", "[", "varvalues", "]"}]}], "]"}], "+", 
                    "1"}], ",", 
                   RowBox[{"ymax", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "]"}], 
               ","}], "*)"}], 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Length", "[", "varvalues", "]"}], ",", "0"}], 
                 "}"}]}], "}"}], "]"}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"Mean", "[", 
            RowBox[{"mutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
                "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", 
                 RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                RowBox[{"ymax", "+", 
                 RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"GrayLevel", "[", "0", "]"}], ",", "Thick"}], "]"}]}]}],
           "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"invasionselcoeffplot", "=", 
       RowBox[{"Show", "[", 
        RowBox[{"mutinvasionselcoeffplot", ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", 
            RowBox[{"Opacity", "[", "0.2", "]"}], ",", 
            RowBox[{"Rectangle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "0.001"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Length", "[", "varvalues", "]"}], ",", "0.001"}], 
               "}"}]}], "]"}]}], "}"}], "]"}]}], "]"}]}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8152952095828257`*^9, 3.815295209590353*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"ba511135-0633-4a9d-91c6-797e6c50a588"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"strategiesBcloseup", "[", 
    RowBox[{"file_", ",", "envcor_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"output", "=", 
       RowBox[{"Import", "[", "file", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"envscenset", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutb", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutRgerm", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutPb", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutstrategy", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"focalparameters", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutresult", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"speedeq", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ncost", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Pbcost", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "10", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"Plot", " ", "closeup", " ", "of", " ", "low", " ", "b"}], 
       "*)"}], 
      RowBox[{"bindexmin", "=", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"bindexmax", "=", "11"}], ";", "\[IndentingNewLine]", 
      RowBox[{"envcolor", "=", 
       RowBox[{"GrayLevel", "[", "0.7", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "mutb", "]"}], ">", "1"}], ",", 
        RowBox[{"varvalues", "=", 
         RowBox[{"mutb", "[", 
          RowBox[{"[", 
           RowBox[{"bindexmin", ";;", "bindexmax"}], "]"}], "]"}]}]}], "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "mutRgerm", "]"}], ">", "1"}], ",", 
        RowBox[{"varvalues", "=", "mutRgerm"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "mutPb", "]"}], ">", "1"}], ",", 
        RowBox[{"varvalues", "=", "mutPb"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xvalues", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"bindexmin", ",", "bindexmax"}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xticks", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"xvalues", ",", 
          RowBox[{"varvalues", "[", 
           RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ymax", "=", 
       RowBox[{"Max", "[", 
        RowBox[{"mutresult", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"bindexmin", ";;", "bindexmax"}], ",", "6"}], "]"}], "]"}],
         "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ymin", "=", 
       RowBox[{"Min", "[", 
        RowBox[{"mutresult", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"bindexmin", ";;", "bindexmax"}], ",", "6"}], "]"}], "]"}],
         "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ydistance", "=", 
       RowBox[{"Abs", "[", 
        RowBox[{"ymax", "-", "ymin"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutinvasionselcoeffplotb", "=", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", 
              RowBox[{"bindexmin", ";;", "bindexmax"}], ",", "6"}], "]"}], 
            "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"envcolor", ",", "Thick"}], "]"}]}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", 
                    RowBox[{"bindexmin", ";;", "bindexmax"}], ",", "6"}], 
                   "]"}], "]"}], "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", 
                 RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                RowBox[{"ymax", "+", 
                 RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", "None"}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
           RowBox[{"FrameTicks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"FrameTicksStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
           RowBox[{"AxesOrigin", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
           RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "StringTemplate", "[", 
                    "\"\<Subscript[\n        p, \[Epsilon]]=`1`\>\"", "]"}], 
                    "[", "envcor", "]"}], ",", "20", ",", 
                   RowBox[{"Background", "\[Rule]", "None"}], ",", "Bold"}], 
                  "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Round", "[", 
                    RowBox[{"0.5", 
                    RowBox[{"Length", "[", "varvalues", "]"}]}], "]"}], "+", 
                    "1"}], ",", 
                   RowBox[{"ymax", "-", 
                    RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "]"}], 
               ","}], "*)"}], 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Length", "[", "varvalues", "]"}], ",", "0"}], 
                 "}"}]}], "}"}], "]"}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"Mean", "[", 
            RowBox[{"mutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", 
               RowBox[{"bindexmin", ";;", "bindexmax"}], ",", "6"}], "]"}], 
             "]"}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", 
                    RowBox[{"bindexmin", ";;", "bindexmax"}], ",", "6"}], 
                   "]"}], "]"}], "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", 
                 RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                RowBox[{"ymax", "+", 
                 RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"GrayLevel", "[", "0", "]"}], ",", "Thick"}], "]"}]}]}],
           "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutinvasionselcoeffplotbcloseup", "=", 
       RowBox[{"Show", "[", 
        RowBox[{"mutinvasionselcoeffplotb", ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", 
            RowBox[{"Opacity", "[", "0.2", "]"}], ",", 
            RowBox[{"Rectangle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "0.001"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Length", "[", "varvalues", "]"}], ",", "0.001"}], 
               "}"}]}], "]"}]}], "}"}], "]"}]}], "]"}]}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.815295216918376*^9, 3.8152952169251413`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"28999a70-8a23-470f-ae05-0268a4beec86"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Calculate", " ", "ymin", " ", "and", " ", "ymax", " ", "for", " ", "the",
      " ", "plots", " ", "of", " ", "strategies", " ", "D"}], ",", 
    RowBox[{"E", " ", "and", " ", 
     RowBox[{"F", "."}]}]}], "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"filesDEF", "=", 
     RowBox[{"{", 
      RowBox[{
      "fileD", ",", "fileE1", ",", "fileE2", ",", "fileE3", ",", "fileF1", 
       ",", "fileF2", ",", "fileF3"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"filesDEFslow", "=", 
     RowBox[{"{", 
      RowBox[{
      "fileDslow", ",", "fileE1slow", ",", "fileE2slow", ",", "fileE3slow", 
       ",", "fileF1slow", ",", "fileF2slow", ",", "fileF3slow"}], "}"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"filesDEFhighPbcost", "=", 
     RowBox[{"{", 
      RowBox[{
      "fileDhighPbcost", ",", "fileE1highPbcost", ",", "fileE3highPbcost", 
       ",", "fileF1highPbcost", ",", "fileF3highPbcost"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"yminfast", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ymaxfast", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"output", "=", 
         RowBox[{"Import", "[", "f", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"mutresult", "=", 
         RowBox[{"output", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"yminfast", "=", 
         RowBox[{"Min", "[", 
          RowBox[{"yminfast", ",", 
           RowBox[{"Min", "[", 
            RowBox[{"mutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ymaxfast", "=", 
         RowBox[{"Max", "[", 
          RowBox[{"ymaxfast", ",", 
           RowBox[{"Max", "[", 
            RowBox[{"mutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
          "]"}]}], ";"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "filesDEF"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"yminslow", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ymaxslow", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"output", "=", 
         RowBox[{"Import", "[", "f", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"mutresult", "=", 
         RowBox[{"output", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"yminslow", "=", 
         RowBox[{"Min", "[", 
          RowBox[{"yminslow", ",", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"ymaxslow", "=", 
         RowBox[{"Max", "[", 
          RowBox[{"ymaxslow", ",", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}]}], "]"}]}], 
        ";"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "filesDEFslow"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"yminhighPbcost", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ymaxhighPbcost", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"output", "=", 
         RowBox[{"Import", "[", "f", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"mutresult", "=", 
         RowBox[{"output", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"yminhighPbcost", "=", 
         RowBox[{"Min", "[", 
          RowBox[{"yminhighPbcost", ",", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"ymaxhighPbcost", "=", 
         RowBox[{"Max", "[", 
          RowBox[{"ymaxhighPbcost", ",", 
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}]}], "]"}]}], 
        ";"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "filesDEFhighPbcost"}], "}"}]}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8152952237653418`*^9, 3.815295223774026*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"a48e7f51-bb03-48d2-a267-680edb67e8c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"strategiesDEF", "[", 
    RowBox[{"Dfile_", ",", "EFfile_", ",", "envcor_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{"outputEF", "=", 
       RowBox[{"Import", "[", "EFfile", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"outputD", "=", 
       RowBox[{"Import", "[", "Dfile", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"envscenset", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutb", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutRgerm", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutPb", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutstrategy", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"focalparameters", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutresult", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"speedeq", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ncost", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Pbcost", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "10", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Denvscenset", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dmutb", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"DmutRgerm", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"DmutPb", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dmutstrategy", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dfocalparameters", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dmutresult", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dspeedeq", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dncost", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"DPbcost", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "10", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"outputfile", "=", 
       RowBox[{"StringDrop", "[", 
        RowBox[{"EFfile", ",", 
         RowBox[{"-", "3"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"envcolor", "=", 
       RowBox[{"GrayLevel", "[", "0.7", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"varvalues", "=", "mutPb"}], ";", "\[IndentingNewLine]", 
      RowBox[{"xvalues", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ")"}], 
             "/", "5"}]}], "]"}], ",", 
          RowBox[{"Length", "[", "varvalues", "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xticks", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"xvalues", ",", 
          RowBox[{"varvalues", "[", 
           RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"yvalues", "=", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"Min", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"mutresult", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
            "]"}], ",", 
           RowBox[{"Max", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"mutresult", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", 
               RowBox[{"Flatten", "[", 
                RowBox[{"mutresult", "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
               "]"}], "-", 
              RowBox[{"Min", "[", 
               RowBox[{"Flatten", "[", 
                RowBox[{"mutresult", "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
               "]"}]}], ")"}], "/", "6"}]}], "]"}]}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"speedeq", "\[Equal]", "1.0"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ymin", "=", "yminfast"}], ";", "\[IndentingNewLine]", 
          RowBox[{"ymax", "=", "ymaxfast"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ymin", "=", "yminslow"}], ";", 
          RowBox[{"ymax", "=", "ymaxslow"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Pbcost", "\[Equal]", "0.005"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ymin", "=", "yminhighPbcost"}], ";", 
          RowBox[{"ymax", "=", "ymaxhighPbcost"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"ymax", "=", 
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Max", "[", 
            RowBox[{"mutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"Max", "[", 
            RowBox[{"Dmutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ymin", "=", 
         RowBox[{"Min", "[", 
          RowBox[{
           RowBox[{"Min", "[", 
            RowBox[{"mutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"Min", "[", 
            RowBox[{"Dmutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
          "]"}]}], ";"}], "*)"}], 
      RowBox[{"ydistance", "=", 
       RowBox[{"Abs", "[", 
        RowBox[{"ymax", "-", "ymin"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutinvasionselcoeffplot", "=", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"envcolor", ",", "Thick"}], "]"}]}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
                "}"}], ",", 
              RowBox[{"(*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.07"}], ",", "0.1"}], "}"}], "*)"}], 
              RowBox[{"(*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.045"}], ",", "0.012"}], "}"}], "*)"}], 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", 
                 RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                RowBox[{"ymax", "+", 
                 RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"FrameTicks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"focalparameters", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              "\"\<Selection coefficient (\\!\\(\\*SuperscriptBox[\\(s\\), \n\
\\(+\\)]\\))\>\""}], "}"}]}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
           RowBox[{"FrameTicks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"FrameTicksStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
           RowBox[{"AxesOrigin", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
           RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Text", "[", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "StringTemplate", "[", 
                    "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \
\\(\[Epsilon]\\)]\\)=`1`\>\"", "]"}], "[", "envcor", "]"}], ",", "20", ",", 
                  RowBox[{"Background", "\[Rule]", "None"}], ",", "Black", 
                  ",", "Bold"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"0.1", " ", 
                    RowBox[{"Length", "[", "mutPb", "]"}]}], "+", "1"}], ",", 
                  
                  RowBox[{"ymin", "+", 
                   RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], 
               RowBox[{"(*", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Round", "[", 
                    RowBox[{"0.5", 
                    RowBox[{"Length", "[", "mutPb", "]"}]}], "]"}], "+", 
                   "1"}], ",", 
                  RowBox[{"ymax", "-", 
                   RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}], "*)"}], 
               "]"}], ",", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Length", "[", "mutPb", "]"}], ",", "0"}], "}"}]}],
                 "}"}], "]"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"Mean", "[", 
            RowBox[{"mutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
                "}"}], ",", 
              RowBox[{"(*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.07"}], ",", "0.1"}], "}"}], "*)"}], 
              RowBox[{"(*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.045"}], ",", "0.012"}], "}"}], "*)"}], 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", 
                 RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                RowBox[{"ymax", "+", 
                 RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"GrayLevel", "[", "0", "]"}], ",", "Thick"}], "]"}]}]}],
           "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutinvasionselcoeffplotPbB", "=", 
       RowBox[{"ListLinePlot", "[", 
        RowBox[{
         RowBox[{"Mean", "[", 
          RowBox[{"Dmutresult", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"Length", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"(*", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.07"}], ",", "0.1"}], "}"}], "*)"}], 
            RowBox[{"(*", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.045"}], ",", "0.012"}], "}"}], "*)"}], 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ymin", "-", 
               RowBox[{"0.05", "*", "ydistance"}]}], ",", 
              RowBox[{"ymax", "+", 
               RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], ",", 
         
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"Red", ",", "Thick", ",", 
            RowBox[{"Opacity", "[", "1.0", "]"}]}], 
           RowBox[{"(*", 
            RowBox[{"White", ",", 
             RowBox[{"Opacity", "[", "0.0", "]"}]}], "*)"}], "]"}]}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{"Filling", "\[Rule]", "0.09"}], ",", 
          RowBox[{"FillingStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Green", ",", 
             RowBox[{"Opacity", "[", "0.3", "]"}]}], "]"}]}]}], "*)"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{
       "mutinvasionselcoeffplot", ",", "mutinvasionselcoeffplotPbB", ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Blue", ",", 
           RowBox[{"Opacity", "[", "0.2", "]"}], ",", 
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "0.001"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "mutPb", "]"}], ",", "0.001"}], "}"}]}],
             "]"}]}], "}"}], "]"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815295231163726*^9, 3.815295231171646*^9}, 
   3.819623545082181*^9},ExpressionUUID->"c8856812-94b3-4392-9057-\
7082e2f6ef1e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ymindelayedPb", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymaxdelayedPb", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"output", "=", 
       RowBox[{"Import", "[", "f", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutresult", "=", 
       RowBox[{"output", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ymindelayedPb", "=", 
       RowBox[{"Min", "[", 
        RowBox[{"ymindelayedPb", ",", 
         RowBox[{"mutresult", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"ymaxdelayedPb", "=", 
       RowBox[{"Max", "[", 
        RowBox[{"ymaxdelayedPb", ",", 
         RowBox[{"mutresult", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}]}], "]"}]}], 
      ";"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"f", ",", "filesdelayedPb"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"strategiesDEFdelayedPb", "[", 
    RowBox[{"Dfile_", ",", "EFfile_", ",", "envcor_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"outputEF", "=", 
       RowBox[{"Import", "[", "EFfile", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"outputD", "=", 
       RowBox[{"Import", "[", "Dfile", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"envscenset", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutb", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutRgerm", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutPb", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutstrategy", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"focalparameters", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutresult", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"speedeq", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ncost", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Pbcost", "=", 
       RowBox[{"outputEF", "[", 
        RowBox[{"[", "10", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Denvscenset", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dmutb", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"DmutRgerm", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"DmutPb", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dmutstrategy", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dfocalparameters", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dmutresult", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dspeedeq", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Dncost", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"DPbcost", "=", 
       RowBox[{"outputD", "[", 
        RowBox[{"[", "10", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"outputfile", "=", 
       RowBox[{"StringDrop", "[", 
        RowBox[{"EFfile", ",", 
         RowBox[{"-", "3"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"envcolor", "=", 
       RowBox[{"GrayLevel", "[", "0.7", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"varvalues", "=", "mutPb"}], ";", "\[IndentingNewLine]", 
      RowBox[{"xvalues", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", 
            RowBox[{
             RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ")"}], 
             "/", "5"}]}], "]"}], ",", 
          RowBox[{"Length", "[", "varvalues", "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xticks", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"xvalues", ",", 
          RowBox[{"varvalues", "[", 
           RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"yvalues", "=", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"Min", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"mutresult", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
            "]"}], ",", 
           RowBox[{"Max", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"mutresult", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", 
               RowBox[{"Flatten", "[", 
                RowBox[{"mutresult", "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
               "]"}], "-", 
              RowBox[{"Min", "[", 
               RowBox[{"Flatten", "[", 
                RowBox[{"mutresult", "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
               "]"}]}], ")"}], "/", "6"}]}], "]"}]}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"ymax", "=", "ymaxdelayedPb"}], ";", "\[IndentingNewLine]", 
        RowBox[{"ymin", "=", "ymindelayedPb"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"ymax", "=", 
       RowBox[{"Max", "[", 
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{"mutresult", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"Max", "[", 
          RowBox[{"Dmutresult", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ymin", "=", 
       RowBox[{"Min", "[", 
        RowBox[{
         RowBox[{"Min", "[", 
          RowBox[{"mutresult", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"Min", "[", 
          RowBox[{"Dmutresult", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ydistance", "=", 
       RowBox[{"Abs", "[", 
        RowBox[{"ymax", "-", "ymin"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutinvasionselcoeffplot", "=", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"mutresult", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"envcolor", ",", "Thick"}], "]"}]}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
                "}"}], ",", 
              RowBox[{"(*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.07"}], ",", "0.1"}], "}"}], "*)"}], 
              RowBox[{"(*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.045"}], ",", "0.012"}], "}"}], "*)"}], 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", 
                 RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                RowBox[{"ymax", "+", 
                 RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"FrameTicks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"focalparameters", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              "\"\<Selection coefficient (\\!\\(\\*SuperscriptBox[\\(s\\), \n\
\\(+\\)]\\))\>\""}], "}"}]}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
           RowBox[{"FrameTicks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"FrameTicksStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
           RowBox[{"AxesOrigin", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
           RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Text", "[", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "StringTemplate", "[", 
                    "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \
\\(\[Epsilon]\\)]\\)=`1`\>\"", "]"}], "[", "envcor", "]"}], ",", "20", ",", 
                  RowBox[{"Background", "\[Rule]", "None"}], ",", "Black", 
                  ",", "Bold"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"0.1", " ", 
                    RowBox[{"Length", "[", "mutPb", "]"}]}], "+", "1"}], ",", 
                  
                  RowBox[{"ymin", "+", 
                   RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], 
               RowBox[{"(*", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Round", "[", 
                    RowBox[{"0.5", 
                    RowBox[{"Length", "[", "mutPb", "]"}]}], "]"}], "+", 
                   "1"}], ",", 
                  RowBox[{"ymax", "-", 
                   RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}], "*)"}], 
               "]"}], ",", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Length", "[", "mutPb", "]"}], ",", "0"}], "}"}]}],
                 "}"}], "]"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListLinePlot", "[", 
          RowBox[{
           RowBox[{"Mean", "[", 
            RowBox[{"mutresult", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
                "}"}], ",", 
              RowBox[{"(*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.07"}], ",", "0.1"}], "}"}], "*)"}], 
              RowBox[{"(*", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.045"}], ",", "0.012"}], "}"}], "*)"}], 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ymin", "-", 
                 RowBox[{"0.05", "*", "ydistance"}]}], ",", 
                RowBox[{"ymax", "+", 
                 RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"GrayLevel", "[", "0", "]"}], ",", "Thick"}], "]"}]}]}],
           "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"mutinvasionselcoeffplotPbB", "=", 
       RowBox[{"ListLinePlot", "[", 
        RowBox[{
         RowBox[{"Mean", "[", 
          RowBox[{"Dmutresult", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"Length", "[", 
               RowBox[{"mutresult", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"(*", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.07"}], ",", "0.1"}], "}"}], "*)"}], 
            RowBox[{"(*", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.045"}], ",", "0.012"}], "}"}], "*)"}], 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ymin", "-", 
               RowBox[{"0.05", "*", "ydistance"}]}], ",", 
              RowBox[{"ymax", "+", 
               RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], "}"}]}], ",", 
         
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"Red", ",", "Thick", ",", 
            RowBox[{"Opacity", "[", "1.0", "]"}]}], 
           RowBox[{"(*", 
            RowBox[{"White", ",", 
             RowBox[{"Opacity", "[", "0.0", "]"}]}], "*)"}], "]"}]}]}], 
        RowBox[{"(*", 
         RowBox[{",", 
          RowBox[{"Filling", "\[Rule]", "0.09"}], ",", 
          RowBox[{"FillingStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Green", ",", 
             RowBox[{"Opacity", "[", "0.3", "]"}]}], "]"}]}]}], "*)"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{
       "mutinvasionselcoeffplot", ",", "mutinvasionselcoeffplotPbB", ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Blue", ",", 
           RowBox[{"Opacity", "[", "0.2", "]"}], ",", 
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "0.001"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "mutPb", "]"}], ",", "0.001"}], "}"}]}],
             "]"}]}], "}"}], "]"}]}], "]"}]}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.815295231163726*^9, 3.815295231171646*^9}, 
   3.819623545082181*^9, {3.819651863445874*^9, 3.819651871280952*^9}, {
   3.819651911429832*^9, 3.819651974202765*^9}, {3.819652225462686*^9, 
   3.819652283591874*^9}, 3.819652465080937*^9, {3.8196529805549307`*^9, 
   3.819653007792461*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"764bd257-74af-4e99-b3c7-6eaf437f1634"],

Cell[BoxData[
 RowBox[{
  RowBox[{"strategiesCDEF", "[", 
   RowBox[{"file_", ",", "envcor_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"output", "=", 
      RowBox[{"Import", "[", "file", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"envscenset", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutb", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutRgerm", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutPb", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutstrategy", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"focalparameters", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutresult", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"speedeq", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ncost", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Pbcost", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "10", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"envscenario", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutresult", "=", 
      RowBox[{"{", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"mutresult", "[", 
          RowBox[{"[", 
           RowBox[{"envscenario", ",", "All", ",", "All"}], "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"And", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "\[LessEqual]", "0.15"}], "]"}], 
          "&"}]}], "]"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "mutb", "]"}], ">", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xpar", "=", "2"}], 
         RowBox[{"(*", "b", "*)"}], ";"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xpar", "=", "4"}], 
         RowBox[{"(*", "Pb", "*)"}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"zmax", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"mutresult", "[", 
        RowBox[{"[", 
         RowBox[{"envscenario", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"zmin", "=", 
      RowBox[{"Min", "[", 
       RowBox[{"mutresult", "[", 
        RowBox[{"[", 
         RowBox[{"envscenario", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"minpos", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"mutresult", "[", 
          RowBox[{"[", 
           RowBox[{"envscenario", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
         RowBox[{"Min", "[", 
          RowBox[{"mutresult", "[", 
           RowBox[{"[", 
            RowBox[{"envscenario", ",", "All", ",", "6"}], "]"}], "]"}], 
          "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mincoord", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"mutresult", "[", 
        RowBox[{"[", 
         RowBox[{"envscenario", ",", "minpos", ",", 
          RowBox[{"{", 
           RowBox[{"xpar", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"maxpos", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{
         RowBox[{"mutresult", "[", 
          RowBox[{"[", 
           RowBox[{"envscenario", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
         RowBox[{"Max", "[", 
          RowBox[{"mutresult", "[", 
           RowBox[{"[", 
            RowBox[{"envscenario", ",", "All", ",", "6"}], "]"}], "]"}], 
          "]"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"maxcoord", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"mutresult", "[", 
        RowBox[{"[", 
         RowBox[{"envscenario", ",", "maxpos", ",", 
          RowBox[{"{", 
           RowBox[{"xpar", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mutinvasionselcoeffplot", "=", 
      RowBox[{"ListContourPlot", "[", 
       RowBox[{
        RowBox[{"mutresult", "[", 
         RowBox[{"[", 
          RowBox[{"envscenario", ",", "All", ",", 
           RowBox[{"{", 
            RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], "]"}], ",", 
        
        RowBox[{"Contours", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"{", "Black", "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0.001", ",", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Dashed"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.001"}], ",", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Dashed"}], "}"}]}], "}"}], ",", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"#", ",", "None"}], "}"}], "&"}], "/@", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"Min", "@", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"envscenario", ",", "All", ",", 
                    RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                  "]"}]}], ",", 
                RowBox[{"Max", "@", 
                 RowBox[{"mutresult", "[", 
                  RowBox[{"[", 
                   RowBox[{"envscenario", ",", "All", ",", 
                    RowBox[{"{", 
                    RowBox[{"xpar", ",", "3", ",", "6"}], "}"}]}], "]"}], 
                  "]"}]}], ",", ".0005"}], "]"}]}], ")"}]}]}], "}"}]}], ",", 
        RowBox[{"ContourStyle", "\[Rule]", "None"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
        RowBox[{"ColorFunction", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}], "[", 
            RowBox[{"Rescale", "[", 
             RowBox[{"#", ",", 
              RowBox[{"{", 
               RowBox[{"zmin", ",", "zmax"}], "}"}]}], "]"}], "]"}], "&"}], 
          ")"}]}], ",", 
        RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameTicks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"focalparameters", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"focalparameters", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
        RowBox[{"FrameTicksStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"Placed", "[", 
          RowBox[{
           RowBox[{"BarLegend", "[", 
            RowBox[{"Automatic", ",", "50", ",", 
             RowBox[{"LegendMarkerSize", "\[Rule]", "250"}], ",", 
             RowBox[{
             "LegendLabel", "\[Rule]", 
              "\"\<\\!\\(\\*SuperscriptBox[\\(s\\), \\(+\\)]\\)\>\""}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"Directive", "[", 
               RowBox[{"Black", ",", "20"}], "]"}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"After", ",", "Top"}], "}"}]}], "]"}]}], ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"Black", ",", 
            RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
            RowBox[{"Point", "[", 
             RowBox[{"{", "maxcoord", "}"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"Text", "[", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "StringTemplate", "[", 
                   "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \
\\(\[Epsilon]\\)]\\)=`1`\>\"", "]"}], "[", "envcor", "]"}], ",", "20", ",", 
                 RowBox[{"Background", "\[Rule]", "None"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Max", "[", 
                   RowBox[{"mutresult", "[", 
                    RowBox[{"[", 
                    RowBox[{"envscenario", ",", "All", ",", "xpar"}], "]"}], 
                    "]"}], "]"}], "/", "2"}], ",", "0.14"}], "}"}]}], "]"}], 
             "}"}]}], "}"}], "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{",", 
            RowBox[{"{", 
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{"\"\<*\>\"", ",", "mincoord"}], "]"}], ",", "40"}], 
              "]"}], "}"}]}], "*)"}], "}"}]}]}], "]"}]}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.815295238354842*^9, 3.8152952383635*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"1b5813f0-7635-49de-84c6-863440d0a0d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"strategiesCDEFforbestrgerm", "[", 
   RowBox[{"file_", ",", "bestrgerm_", ",", "envcor_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"output", "=", 
      RowBox[{"Import", "[", "file", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"envscenset", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutb", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutRgerm", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutPb", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutstrategy", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"focalparameters", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutresult", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"speedeq", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ncost", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Pbcost", "=", 
      RowBox[{"output", "[", 
       RowBox[{"[", "10", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"envscenario", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutresult", "=", 
      RowBox[{"{", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"mutresult", "[", 
          RowBox[{"[", 
           RowBox[{"envscenario", ",", "All", ",", "All"}], "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"And", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "bestrgerm"}], "]"}],
           "&"}]}], "]"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "mutb", "]"}], ">", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xpar", "=", "2"}], 
         RowBox[{"(*", "b", "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"varvalues", "=", "mutb"}], ";"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xpar", "=", "4"}], 
         RowBox[{"(*", "Pb", "*)"}], ";", "\[IndentingNewLine]", 
         RowBox[{"varvalues", "=", "mutPb"}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xvalues", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ")"}], 
            "/", "5"}]}], "]"}], ",", 
         RowBox[{"Length", "[", "varvalues", "]"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xticks", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"xvalues", ",", 
         RowBox[{"varvalues", "[", 
          RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ymin", "=", 
      RowBox[{"Min", "[", 
       RowBox[{"mutresult", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ymax", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"mutresult", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ydistance", "=", 
      RowBox[{"Abs", "[", 
       RowBox[{"ymax", "-", "ymin"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"plotforbestrgerm", "=", 
      RowBox[{"ListLinePlot", "[", 
       RowBox[{
        RowBox[{"mutresult", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Red", ",", "Thick"}], "]"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ymin", "-", 
            RowBox[{"0.05", "*", "ydistance"}]}], ",", 
           RowBox[{"ymax", "+", 
            RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}], ",", 
        RowBox[{"FrameTicks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"focalparameters", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           "\"\<Selection coefficient (\\!\\(\\*SuperscriptBox[\\(s\\), \n\
\\(+\\)]\\))\>\""}], "}"}]}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
        RowBox[{"FrameTicks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameTicksStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "StringTemplate", "[", 
                 "\"\<\\!\\(\\*SubscriptBox[\\(p\\), \\(\[Epsilon]\\)]\\)=`1`\
\>\"", "]"}], "[", "envcor", "]"}], ",", "20", ",", 
               RowBox[{"Background", "\[Rule]", "None"}], ",", "Black", ",", 
               "Bold"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"0.5", "*", 
                RowBox[{"Length", "[", "varvalues", "]"}]}], ",", "ymax"}], 
              "}"}]}], 
            RowBox[{"(*", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"Round", "[", 
                 RowBox[{"0.5", 
                  RowBox[{"Length", "[", "mutPb", "]"}]}], "]"}], "+", "1"}], 
               ",", 
               RowBox[{"ymax", "-", 
                RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}], "*)"}], "]"}], 
           ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Length", "[", "varvalues", "]"}], ",", "0"}], 
               "}"}]}], "}"}], "]"}]}], "}"}]}]}], "]"}]}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.815295245700469*^9, 3.815295245707987*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"27a62263-84aa-4b42-940e-0a15a4922535"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strategies B, C, D", "Chapter",
 CellChangeTimes->{
  3.815295279720134*^9},ExpressionUUID->"83982e5b-eb92-4c15-8baf-\
08044082ed6f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotBC", "=", 
   RowBox[{"Grid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesBCD", "[", 
        RowBox[{"fileB", ",", "envcorB"}], "]"}], ",", 
       RowBox[{"strategiesBCD", "[", 
        RowBox[{"fileC", ",", "envcorC"}], "]"}]}], "}"}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.815295292549838*^9, 
  3.815295292557152*^9}},ExpressionUUID->"115d77d3-1ed8-4d3e-a37e-\
0679beb1f17d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyBC-envcorr011-wtmu6798-ncost000001-Pbcost00005-speedeq10-\
mutinvasionselcoeffplot.pdf\>\"", ",", "plotBC", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815295297179038*^9, 
  3.815295297186626*^9}},ExpressionUUID->"67eae316-a233-4bd9-ac37-\
db373709f479"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotD", "=", 
   RowBox[{"strategiesBCD", "[", 
    RowBox[{"fileD", ",", "envcorD"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815295301974537*^9, 
  3.815295301981776*^9}},ExpressionUUID->"6b32f72f-931d-4d97-a277-\
05d9be34e10d"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
    "\"\<a5si-strategyD-envcorr011-wtmu6798-\n\
ncost000001-Pbcost00005-speedeq10-mutinvasionselcoeffplot.pdf\>\"", ",", 
     "plotD", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.815295307848077*^9, 
  3.8152953078553963`*^9}},ExpressionUUID->"a7e9eeb8-7a9d-4291-b3f9-\
12574b81b823"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotBCslow", "=", 
   RowBox[{"Grid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesBCD", "[", 
        RowBox[{"fileBslow", ",", "envcorB"}], "]"}], ",", 
       RowBox[{"strategiesBCD", "[", 
        RowBox[{"fileCslow", ",", "envcorC"}], "]"}]}], "}"}], "}"}], "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.815295312823832*^9, 
  3.8152953128307*^9}},ExpressionUUID->"6aaa82f1-d7ff-4080-96cb-30c659e1d932"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyBC-envcorr011-wtmu6798-ncost000001-Pbcost00005-\n\
speedeq075-mutinvasionselcoeffplot.pdf\>\"", ",", "plotBCslow", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815295317638817*^9, 
  3.8152953176455727`*^9}},ExpressionUUID->"520a9d16-72cb-4286-a266-\
0e728bb1e2a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotDslow", "=", 
   RowBox[{"strategiesBCD", "[", 
    RowBox[{"fileDslow", ",", "envcorD"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815295322783993*^9, 
  3.81529532279178*^9}},ExpressionUUID->"c5caa7dc-d4b4-4fd8-b294-\
cded1f63342e"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
    "\"\<a5si-strategyD-envcorr011-wtmu6798-\n\
ncost000001-Pbcost00005-speedeq075-mutinvasionselcoeffplot.pdf\>\"", ",", 
     "plotDslow", ",", 
     RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.815295328646873*^9, 
  3.815295328654278*^9}},ExpressionUUID->"12a4d9fe-a43e-4aa0-985c-\
471c4b53cef1"],

Cell[BoxData[
 RowBox[{"plotBCfastslow", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "plotBC", "}"}], ",", 
     RowBox[{"{", "plotBCslow", "}"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815295333939865*^9, 
  3.815295333946878*^9}},ExpressionUUID->"0c7c78d6-044d-4387-9d44-\
ed80bea88c7a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyBC-envcorr011-wtmu6798-ncost000001-Pbcost00005-\n\
speedeq10075-mutinvasionselcoeffplot.pdf\>\"", ",", "plotBCfastslow", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815295339763468*^9, 
  3.8152953397715263`*^9}},ExpressionUUID->"0f4e2235-60ff-42fc-bf93-\
a2d676fd9e18"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strategies D, E, F", "Chapter",
 CellChangeTimes->{{3.815295347646406*^9, 
  3.815295350909988*^9}},ExpressionUUID->"cc95a355-95ea-44e4-a65a-\
51928295642e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Best", " ", "Pb", " ", "value"}], "*)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"strategyDfile", "=", 
     RowBox[{"Import", "[", "fileD", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"strategyDmutresult", "=", 
     RowBox[{"strategyDfile", "[", 
      RowBox[{"[", "7", "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"bestPbvaluepos", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Position", "[", 
       RowBox[{
        RowBox[{"strategyDmutresult", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
        RowBox[{"Max", "[", 
         RowBox[{"strategyDmutresult", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], "]"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{"bestPbvalue", "=", 
    RowBox[{"Max", "[", 
     RowBox[{"strategyDmutresult", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "bestPbvaluepos", ",", "4"}], "]"}], "]"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.81529535783773*^9, 
  3.815295357843639*^9}},ExpressionUUID->"cc9f7dfe-dbd9-4027-a5e5-\
003d80d0703b"],

Cell[BoxData[
 RowBox[{"plotDEF", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileD", ",", "fileE1", ",", "envcorE1"}], "]"}], ",", 
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileD", ",", "fileF1", ",", "envcorF1"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileD", ",", "fileE2", ",", "envcorE2"}], "]"}], ",", 
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileD", ",", "fileF2", ",", "envcorF2"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileD", ",", "fileE3", ",", "envcorE3"}], "]"}], ",", 
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileD", ",", "fileF3", ",", "envcorF3"}], "]"}]}], "}"}]}], 
    "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8152953633015223`*^9, 
  3.815295363309602*^9}},ExpressionUUID->"7ac868c8-cc0c-4c90-809e-\
e3b82615d045"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyDEF-envcorr011053089-wtmu6798-ncost000001-\n\
Pbcost00005-speedeq10-mutinvasionselcoeffplot.pdf\>\"", ",", "plotDEF", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815295370071198*^9, 
  3.815295370080035*^9}},ExpressionUUID->"0d9a918a-b150-49f3-a01b-\
d6a083d13ea9"],

Cell[BoxData[
 RowBox[{"plotDEFslow", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDslow", ",", "fileE1slow", ",", "envcorE1"}], "]"}], ",", 
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDslow", ",", "fileF1slow", ",", "envcorF1"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDslow", ",", "fileE2slow", ",", "envcorE2"}], "]"}], ",", 
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDslow", ",", "fileF2slow", ",", "envcorF2"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDslow", ",", "fileE3slow", ",", "envcorE3"}], "]"}], ",", 
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDslow", ",", "fileF3slow", ",", "envcorF3"}], "]"}]}], 
      "}"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815295376038837*^9, 
  3.815295376046176*^9}},ExpressionUUID->"5f10bbd0-5785-464c-9905-\
34a375a7ec81"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyDEF-envcorr011053089-wtmu6798-ncost000001-\n\
Pbcost00005-speedeq075-mutinvasionselcoeffplot.pdf\>\"", ",", "plotDEFslow", 
    ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815295382752962*^9, 
  3.815295382759865*^9}},ExpressionUUID->"8e241715-4299-4768-b1ee-\
46609ea27d59"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strategies D, E, F (High Pb cost)", "Chapter",
 CellChangeTimes->{
  3.815295393218938*^9},ExpressionUUID->"6b8d7146-4317-4fb0-b442-\
451bda3ecbea"],

Cell[BoxData[
 RowBox[{"plotDEFhighPbcost", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDhighPbcost", ",", "fileE1highPbcost", ",", "envcorE1"}],
         "]"}], ",", 
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDhighPbcost", ",", "fileF1highPbcost", ",", "envcorF1"}],
         "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDhighPbcost", ",", "fileE3highPbcost", ",", "envcorE3"}],
         "]"}], ",", 
       RowBox[{"strategiesDEF", "[", 
        RowBox[{"fileDhighPbcost", ",", "fileF3highPbcost", ",", "envcorF3"}],
         "]"}]}], "}"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8152954001205673`*^9, 
  3.815295400129189*^9}},ExpressionUUID->"815ba92c-b275-4dc7-b1f9-\
0877ba28856a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyDEF-envcorr011089-wtmu6798-ncost000001-Pbcost0005-\n\
speedeq10-mutinvasionselcoeffplot.pdf\>\"", ",", "plotDEFhighPbcost", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815295406424489*^9, 
  3.815295406432261*^9}},ExpressionUUID->"e1bc969e-690c-430d-b0df-\
f8dfb95e0274"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strategies D, E, F (Delayed Pb)", "Chapter",
 CellChangeTimes->{
  3.815295393218938*^9, {3.8196229130769863`*^9, 
   3.8196229159396143`*^9}},ExpressionUUID->"664a6c08-8dfc-439e-8575-\
02b94ad2a618"],

Cell[BoxData[
 RowBox[{"plotDEFdelayedPb", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEFdelayedPb", "[", 
        RowBox[{"fileDdelayedPb", ",", "fileE1delayedPb", ",", "envcorE1"}], 
        "]"}], ",", 
       RowBox[{"strategiesDEFdelayedPb", "[", 
        RowBox[{"fileDdelayedPb", ",", "fileF1delayedPb", ",", "envcorF1"}], 
        "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEFdelayedPb", "[", 
        RowBox[{"fileDdelayedPb", ",", "fileE2delayedPb", ",", "envcorE2"}], 
        "]"}], ",", 
       RowBox[{"strategiesDEFdelayedPb", "[", 
        RowBox[{"fileDdelayedPb", ",", "fileF2delayedPb", ",", "envcorF2"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesDEFdelayedPb", "[", 
        RowBox[{"fileDdelayedPb", ",", "fileE3delayedPb", ",", "envcorE3"}], 
        "]"}], ",", 
       RowBox[{"strategiesDEFdelayedPb", "[", 
        RowBox[{"fileDdelayedPb", ",", "fileF3delayedPb", ",", "envcorF3"}], 
        "]"}]}], "}"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8152954001205673`*^9, 3.815295400129189*^9}, {
  3.8196229248703537`*^9, 3.8196229277137423`*^9}, {3.819622962978799*^9, 
  3.819622979284503*^9}, {3.819623129022909*^9, 3.819623182470385*^9}, {
  3.819623212747315*^9, 3.819623239747408*^9}, {3.8196527271628*^9, 
  3.819652751695467*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"243d278d-46bc-4b17-b9a1-1108d992d5c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyDEFdelayedPb-envcorr011089-wtmu6798-ncost000001-\
Pbcost00005-\nspeedeq10-mutinvasionselcoeffplot.pdf\>\"", ",", 
    "plotDEFdelayedPb", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815295406424489*^9, 3.815295406432261*^9}, {
   3.819652352311206*^9, 3.819652355842413*^9}, 3.819653066888151*^9, 
   3.821301884299698*^9},ExpressionUUID->"1d9a1e07-d3d8-4384-afbd-\
25e22451eb1c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strategy B+C", "Chapter",
 CellChangeTimes->{
  3.815295416156242*^9},ExpressionUUID->"0e1f5b32-a909-4079-a0a4-\
311cd64dc35b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"outputBC", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Import", "[", "fileBC", "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"bestcase", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Select", "[", 
     RowBox[{"outputBC", ",", 
      RowBox[{
       RowBox[{"And", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "6", "]"}], "]"}], "\[Equal]", 
         RowBox[{"Max", "[", 
          RowBox[{"outputBC", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "6"}], "]"}], "]"}], "]"}]}], "]"}], "&"}]}], 
     "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8152954220966043`*^9, 
  3.815295422103325*^9}},ExpressionUUID->"c306ad07-eb8b-44a6-9201-\
f659f4fe35b8"],

Cell[BoxData[{
 RowBox[{"bestb", "=", 
  RowBox[{"bestcase", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\n", 
 RowBox[{"bestrgerm", "=", 
  RowBox[{"bestcase", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.815295427100129*^9, 
  3.815295427107377*^9}},ExpressionUUID->"d18b9b7a-8740-4bb4-836c-\
1623077cda91"],

Cell[BoxData[
 RowBox[{"plotBplusC", "=", 
  RowBox[{"strategiesCDEF", "[", 
   RowBox[{"fileBC", ",", "envcorBC"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815295432477434*^9, 
  3.815295432484144*^9}},ExpressionUUID->"887944f6-ad45-43ba-9631-\
4a9459ca8052"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyBplusC-envcorr089-wtmu6798-ncost000001-\n\
Pbcost00005-speedeq10-mutinvasionselcoeffplot.png\>\"", ",", "plotBplusC", 
    ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8152954385008574`*^9, 
  3.81529543850804*^9}},ExpressionUUID->"54d298e8-e961-429d-9bb9-\
2ce52b3998b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strategy B+C: fitness of optimal Rgerm as a function of b", "Chapter",
 CellChangeTimes->{
  3.8152954472418833`*^9},ExpressionUUID->"96436361-cfbd-44a4-841a-\
2df486deadb8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BCdata", "=", 
    RowBox[{"Import", "[", "fileBC", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"envscenset", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mutb", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mutRgerm", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mutPb", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "4", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mutstrategy", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "5", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"focalparameters", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "6", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mutresult", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "7", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"speedeq", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "8", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ncost", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "9", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Pbcost", "=", 
   RowBox[{"BCdata", "[", 
    RowBox[{"[", "10", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"envscenario", "=", "1"}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mutresult", "=", 
    RowBox[{"{", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"mutresult", "[", 
        RowBox[{"[", 
         RowBox[{"envscenario", ",", "All", ",", "All"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"And", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "bestrgerm"}], "]"}], 
        "&"}]}], "]"}], "}"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "mutb", "]"}], ">", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xpar", "=", "2"}], 
       RowBox[{"(*", "b", "*)"}], ";"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xpar", "=", "4"}], 
       RowBox[{"(*", "Pb", "*)"}], ";"}], "}"}]}], "]"}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"varvalues", "=", "mutb"}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvalues", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ")"}], "/", 
         "5"}]}], "]"}], ",", 
      RowBox[{"Length", "[", "varvalues", "]"}]}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"xticks", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"xvalues", ",", 
       RowBox[{"varvalues", "[", 
        RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BCplotforbestrgerm", "=", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"mutresult", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Red", ",", "Thick"}], "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Min", "[", 
          RowBox[{"mutresult", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], "-", 
         "0.0005"}], ",", "Automatic"}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"focalparameters", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        "\"\<Selection coefficient (\\!\\(\\*SuperscriptBox[\\(s\\), \n\
\\(+\\)]\\))\>\""}], "}"}]}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", 
              "\"\<\\!\\(\\*SubscriptBox[\\(r\\), \\(germ\\)]\\)=`1`\>\"", 
              "]"}], "[", "bestrgerm", "]"}], ",", "20", ",", 
            RowBox[{"Background", "\[Rule]", "None"}], ",", "Black", ",", 
            "Bold"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0.5", " ", 
             RowBox[{"Length", "[", "mutb", "]"}]}], ",", 
            RowBox[{"Max", "[", 
             RowBox[{"mutresult", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}]}], 
           "}"}]}], 
         RowBox[{"(*", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Round", "[", 
              RowBox[{"0.5", 
               RowBox[{"Length", "[", "mutPb", "]"}]}], "]"}], "+", "1"}], 
            ",", 
            RowBox[{"ymax", "-", 
             RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}], "*)"}], "]"}], 
        ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Length", "[", "mutPb", "]"}], ",", "0"}], "}"}]}], 
          "}"}], "]"}]}], "}"}]}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8152954549935217`*^9, 
  3.815295455001053*^9}},ExpressionUUID->"9ac04952-fe80-402f-a137-\
b774bf0d4154"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyBplusC-envcorr089-wtmu6798-ncost000001-\n\
Pbcost00005-speedeq10-mutinvasionselcoeffplot-BCplotforbestrgerm.png\>\"", 
    ",", "BCplotforbestrgerm", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815295462456524*^9, 
  3.815295462465328*^9}},ExpressionUUID->"0e9bd831-8cc0-4f1b-9ffb-\
e516be037ca0"],

Cell[BoxData[
 RowBox[{"BCplotandbestrgerm", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"plotBplusC", ",", "BCplotforbestrgerm"}], "}"}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.815295467725786*^9, 
  3.815295467732939*^9}},ExpressionUUID->"715ace16-82c2-4afc-9684-\
359e73f0aeb4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyBplusC-envcorr089-wtmu6798-ncost000001-\n\
Pbcost00005-speedeq10-mutinvasionselcoeffplot-BCplotandbestrgerm.png\>\"", 
    ",", "BCplotandbestrgerm", ",", 
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8152954738847446`*^9, 
  3.8152954738926497`*^9}},ExpressionUUID->"ccf79b4d-5f83-4ab2-a9d7-\
4246c7ec21a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotBforspecificC", "[", 
   RowBox[{"file_", ",", "rgermvalue_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"BCdata", "=", 
      RowBox[{"Import", "[", "file", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"envscenset", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutb", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutRgerm", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutPb", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutstrategy", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "5", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"focalparameters", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutresult", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"speedeq", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "8", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ncost", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Pbcost", "=", 
      RowBox[{"BCdata", "[", 
       RowBox[{"[", "10", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"envscenario", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"mutresult", "=", 
      RowBox[{"{", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"mutresult", "[", 
          RowBox[{"[", 
           RowBox[{"envscenario", ",", "All", ",", "All"}], "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"And", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "rgermvalue"}], 
           "]"}], "&"}]}], "]"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "mutb", "]"}], ">", "1"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xpar", "=", "2"}], 
         RowBox[{"(*", "b", "*)"}], ";"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xpar", "=", "4"}], 
         RowBox[{"(*", "Pb", "*)"}], ";"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"varvalues", "=", "mutb"}], ";", "\[IndentingNewLine]", 
     RowBox[{"xvalues", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Length", "[", "varvalues", "]"}], "-", "1"}], ")"}], 
            "/", "5"}]}], "]"}], ",", 
         RowBox[{"Length", "[", "varvalues", "]"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xticks", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"xvalues", ",", 
         RowBox[{"varvalues", "[", 
          RowBox[{"[", "xvalues", "]"}], "]"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"BCplotforbestrgerm", "=", 
      RowBox[{"ListLinePlot", "[", 
       RowBox[{
        RowBox[{"mutresult", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Red", ",", "Thick"}], "]"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Min", "[", 
              RowBox[{"mutresult", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], "]"}], 
             "-", "0.0005"}], ",", "Automatic"}], "}"}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}], ",", 
        RowBox[{"FrameTicks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"xticks", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"focalparameters", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           "\"\<Selection coefficient (\\!\\(\\*SuperscriptBox[\\(s\\), \n\
\\(+\\)]\\))\>\""}], "}"}]}], ",", 
        RowBox[{"FrameStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "Thick", ",", "20"}], "]"}]}], ",", 
        RowBox[{"FrameTicks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "None"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"FrameTicksStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", "20"}], "]"}]}], ",", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Large"}], ",", 
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "StringTemplate", "[", 
                 "\"\<\\!\\(\\*SubscriptBox[\\(r\\), \\(germ\\)]\\)=`1`\>\"", 
                 "]"}], "[", "rgermvalue", "]"}], ",", "20", ",", 
               RowBox[{"Background", "\[Rule]", "None"}], ",", "Black", ",", 
               "Bold"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"0.5", " ", 
                RowBox[{"Length", "[", "mutb", "]"}]}], ",", 
               RowBox[{"Max", "[", 
                RowBox[{"mutresult", "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "All", ",", "6"}], "]"}], "]"}], 
                "]"}]}], "}"}]}], 
            RowBox[{"(*", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"Round", "[", 
                 RowBox[{"0.5", 
                  RowBox[{"Length", "[", "mutPb", "]"}]}], "]"}], "+", "1"}], 
               ",", 
               RowBox[{"ymax", "-", 
                RowBox[{"0.05", "*", "ydistance"}]}]}], "}"}], "*)"}], "]"}], 
           ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Length", "[", "mutPb", "]"}], ",", "0"}], "}"}]}], 
             "}"}], "]"}]}], "}"}]}]}], "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.815295483226623*^9, 
  3.8152954832332993`*^9}},ExpressionUUID->"9dd807c3-0723-4be6-a461-\
45d638434d41"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plotBforspecificC", "[", 
    RowBox[{"fileBC", ",", "bestrgerm"}], "]"}], ",", 
   RowBox[{"plotBforspecificC", "[", 
    RowBox[{"fileBC", ",", "0.01"}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Blue", ",", 
       RowBox[{"Opacity", "[", "0.2", "]"}], ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "0.001"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Length", "[", "mutPb", "]"}], ",", "0.001"}], "}"}]}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "0.3"}], "}"}]}], "}"}]}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.815295490439168*^9, 
  3.815295490447165*^9}},ExpressionUUID->"c1f09687-64a7-483f-91d6-\
45cc7f559f77"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strategies CD-CF", "Chapter",
 CellChangeTimes->{
  3.815295500421075*^9},ExpressionUUID->"45da33ec-2154-4675-87c9-\
9109f8d03890"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"outputCD1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Import", "[", "fileCD1", "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"bestCD1", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"outputCD1", ",", 
       RowBox[{
        RowBox[{"And", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "6", "]"}], "]"}], "\[Equal]", 
          RowBox[{"Max", "[", 
           RowBox[{"outputCD1", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "6"}], "]"}], "]"}], "]"}]}], "]"}], "&"}]}],
       "]"}], "]"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outputCD3", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Import", "[", "fileCD3", "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"bestCD3", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"outputCD3", ",", 
       RowBox[{
        RowBox[{"And", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "6", "]"}], "]"}], "\[Equal]", 
          RowBox[{"Max", "[", 
           RowBox[{"outputCD3", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "6"}], "]"}], "]"}], "]"}]}], "]"}], "&"}]}],
       "]"}], "]"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outputCE1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Import", "[", "fileCE1", "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"bestCE1", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"outputCE1", ",", 
       RowBox[{
        RowBox[{"And", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "6", "]"}], "]"}], "\[Equal]", 
          RowBox[{"Max", "[", 
           RowBox[{"outputCE1", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "6"}], "]"}], "]"}], "]"}]}], "]"}], "&"}]}],
       "]"}], "]"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outputCE3", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Import", "[", "fileCE3", "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"bestCE3", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"outputCE3", ",", 
       RowBox[{
        RowBox[{"And", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "6", "]"}], "]"}], "\[Equal]", 
          RowBox[{"Max", "[", 
           RowBox[{"outputCE3", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "6"}], "]"}], "]"}], "]"}]}], "]"}], "&"}]}],
       "]"}], "]"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outputCF1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Import", "[", "fileCF1", "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"bestCF1", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"outputCF1", ",", 
       RowBox[{
        RowBox[{"And", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "6", "]"}], "]"}], "\[Equal]", 
          RowBox[{"Max", "[", 
           RowBox[{"outputCF1", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "6"}], "]"}], "]"}], "]"}]}], "]"}], "&"}]}],
       "]"}], "]"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outputCF3", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Import", "[", "fileCF3", "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", "1"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"bestCF3", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Select", "[", 
     RowBox[{"outputCF3", ",", 
      RowBox[{
       RowBox[{"And", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "6", "]"}], "]"}], "\[Equal]", 
         RowBox[{"Max", "[", 
          RowBox[{"outputCF3", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "6"}], "]"}], "]"}], "]"}]}], "]"}], "&"}]}], 
     "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8152955093690042`*^9, 
  3.8152955093761177`*^9}},ExpressionUUID->"e73f714c-aefa-46ba-aa23-\
6ed79666dec8"],

Cell[BoxData[
 RowBox[{"plotCDEF", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesCDEF", "[", 
        RowBox[{"fileCD1", ",", "envcorCD1"}], "]"}], ",", 
       RowBox[{"strategiesCDEF", "[", 
        RowBox[{"fileCD3", ",", "envcorCD3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesCDEF", "[", 
        RowBox[{"fileCE1", ",", "envcorCE1"}], "]"}], ",", 
       RowBox[{"strategiesCDEF", "[", 
        RowBox[{"fileCE3", ",", "envcorCE3"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesCDEF", "[", 
        RowBox[{"fileCF1", ",", "envcorCF1"}], "]"}], ",", 
       RowBox[{"strategiesCDEF", "[", 
        RowBox[{"fileCF3", ",", "envcorCF3"}], "]"}]}], "}"}]}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.815295514975109*^9, 
  3.815295514984084*^9}},ExpressionUUID->"1089c078-a9d5-4b62-a7aa-\
6b2d1e70afcb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\<a5si-strategyCDEF-envcorr011089-wtmu6798-ncost000001-\n\
Pbcost00005-speedeq10-mutinvasionselcoeffplot.png\>\"", ",", "plotCDEF", ",", 
    
    RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.815295521757038*^9, 
  3.815295521764187*^9}},ExpressionUUID->"87e345a4-cf1c-4452-807a-\
d668ed5ad1f7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Strategies CD-CF: fitness of optimal Rgerm as a function of Pb\
\>", "Chapter",
 CellChangeTimes->{
  3.815295529346792*^9},ExpressionUUID->"115cf903-d97a-4066-a468-\
8f5de6ec3aa4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bestrgerm", "=", "0.1"}], ";"}], "\n", 
 RowBox[{"plotCDEF", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesCDEFforbestrgerm", "[", 
        RowBox[{"fileCD1", ",", "bestrgerm", ",", "envcorCD1"}], "]"}], ",", 
       RowBox[{"strategiesCDEFforbestrgerm", "[", 
        RowBox[{"fileCD3", ",", "bestrgerm", ",", "envcorCD3"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesCDEFforbestrgerm", "[", 
        RowBox[{"fileCE1", ",", "bestrgerm", ",", "envcorCE1"}], "]"}], ",", 
       RowBox[{"strategiesCDEFforbestrgerm", "[", 
        RowBox[{"fileCE3", ",", "bestrgerm", ",", "envcorCE3"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"strategiesCDEFforbestrgerm", "[", 
        RowBox[{"fileCF1", ",", "bestrgerm", ",", "envcorCF1"}], "]"}], ",", 
       RowBox[{"strategiesCDEFforbestrgerm", "[", 
        RowBox[{"fileCF3", ",", "bestrgerm", ",", "envcorCF3"}], "]"}]}], 
      "}"}]}], "}"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.815295536687036*^9, 
  3.815295536694542*^9}},ExpressionUUID->"b774adc5-232d-4135-9ced-\
df7c10ceb5e5"]
}, Open  ]]
}, Open  ]],

Cell["Test zone", "Title",
 CellChangeTimes->{
  3.8152955461142883`*^9},ExpressionUUID->"68e5adfa-5d5a-439f-a4e7-\
e79642178b1a"]
},
WindowSize->{1440, 782},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"2a555875-8bc7-49bf-9624-35785e743d67"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 300, 5, 171, "Title",ExpressionUUID->"d8e03421-3017-45a7-90fe-b27ce3fbc027"],
Cell[883, 29, 199, 3, 69, "Chapter",ExpressionUUID->"e37f05dc-2e5a-4625-b1f0-72d2a7b06448"],
Cell[1085, 34, 181, 3, 58, "Chapter",ExpressionUUID->"03223c65-756b-40cf-9f00-b49764c3d47b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1303, 42, 151, 3, 98, "Title",ExpressionUUID->"16c6eee6-4d95-4506-b421-193679f16308"],
Cell[1457, 47, 221, 3, 30, "Input",ExpressionUUID->"008c8c13-1262-49d7-9962-34b0e0f33c62"],
Cell[1681, 52, 303, 5, 30, "Input",ExpressionUUID->"ea031699-dc47-469f-833a-4171ab6f7f0e"],
Cell[1987, 59, 265, 4, 30, "Input",ExpressionUUID->"733a8a16-e533-4ed7-bac7-54fd67372afd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2289, 68, 152, 3, 98, "Title",ExpressionUUID->"4e9b5054-64c4-47ee-bf76-cba21f66835c"],
Cell[2444, 73, 943, 26, 199, "Input",ExpressionUUID->"173bbc86-127f-4b69-aa4d-7696a9016297"],
Cell[3390, 101, 2691, 79, 178, "Input",ExpressionUUID->"9a399f38-1e31-4619-80f1-31a6153ebc87"],
Cell[6084, 182, 1792, 49, 136, "Input",ExpressionUUID->"8dc428ed-3c81-479e-b2ca-5cfcede7fa22"],
Cell[7879, 233, 304, 6, 30, "Input",ExpressionUUID->"03ab6761-a84e-4f32-b5ea-4caccb390756"],
Cell[8186, 241, 636, 16, 30, "Input",ExpressionUUID->"cb8f25a9-4b2b-4299-8f2a-90350a671bc2"],
Cell[8825, 259, 7151, 187, 409, "Input",ExpressionUUID->"b3b9ffa0-462c-4ede-bac0-eb96b2c63cd5"],
Cell[15979, 448, 410, 8, 30, "Input",ExpressionUUID->"e07d1e28-8dda-444e-a360-c97f34c9c0a3"],
Cell[16392, 458, 5684, 155, 451, "Input",ExpressionUUID->"32a3642b-876f-40a0-bad2-86f38a838036"],
Cell[22079, 615, 3118, 79, 220, "Input",ExpressionUUID->"d42ff67a-92e2-4f40-9439-612d08068b98"],
Cell[25200, 696, 3235, 82, 199, "Input",ExpressionUUID->"ccb78194-b03f-4c52-bab4-cc68e6057341"],
Cell[28438, 780, 352, 7, 30, "Input",ExpressionUUID->"4d8d51aa-ae56-4503-bab1-6d05bd5a1727"],
Cell[28793, 789, 3163, 82, 199, "Input",ExpressionUUID->"f67ee56a-1e1a-48cc-b424-3bc9c2af0278"],
Cell[31959, 873, 344, 6, 30, "Input",ExpressionUUID->"f532c1d6-b0f8-420d-a1b2-72f0c6ea48de"],
Cell[32306, 881, 492, 12, 73, "Input",ExpressionUUID->"be314ea1-9fee-4596-bf34-920ce02ec6f5"],
Cell[32801, 895, 24287, 568, 1669, "Input",ExpressionUUID->"d4ecdb80-5632-4114-9cc3-5b9f9c176442"],
Cell[57091, 1465, 994, 23, 94, "Input",ExpressionUUID->"56d74aea-63f8-4960-91fd-d1bf314f9b2d"],
Cell[58088, 1490, 179, 2, 30, "Input",ExpressionUUID->"cf3bbcc0-1420-4094-b5b4-a6ccc3336179"],
Cell[58270, 1494, 27371, 642, 1669, "Input",ExpressionUUID->"3153d8d4-8e6b-40b4-9d94-d929eaa8233b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85678, 2141, 155, 3, 98, "Title",ExpressionUUID->"68e888f4-3e1d-4b0d-9d05-d7f3c9545f70"],
Cell[85836, 2146, 694, 16, 219, "Text",ExpressionUUID->"72f115f0-1b15-4db6-ad76-8bf1269bcf08"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86567, 2167, 192, 3, 98, "Title",ExpressionUUID->"ca85f9b0-5118-40f5-9b50-4f276d892300"],
Cell[86762, 2172, 221, 6, 35, "Text",ExpressionUUID->"2db96c8b-2f52-4d70-9e1a-28f21950f754"],
Cell[86986, 2180, 1950, 51, 73, "Input",ExpressionUUID->"1317de87-7b03-4b6f-b0ed-7b53c17dc59f"],
Cell[88939, 2233, 427, 9, 30, "Input",ExpressionUUID->"9b05c6fe-b483-47a2-b1e2-c6993c961892"],
Cell[89369, 2244, 1368, 37, 52, "Input",ExpressionUUID->"6b826bea-46fd-4893-a19c-ded0a50c2617"],
Cell[90740, 2283, 430, 9, 30, "Input",ExpressionUUID->"0116a5d7-b8b3-4e6d-9cc6-fcec0c364e9a"],
Cell[91173, 2294, 1336, 38, 98, "Input",ExpressionUUID->"1659b6ce-494b-418a-b1fe-e25a386c5596"],
Cell[92512, 2334, 340, 7, 30, "Input",ExpressionUUID->"634e6ed9-47c8-4ca8-8296-a89e5da88360"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92889, 2346, 144, 3, 98, "Title",ExpressionUUID->"928c9b19-1426-46d2-b7ce-0b812b7991df"],
Cell[93036, 2351, 300, 7, 35, "Text",ExpressionUUID->"87009074-4e7d-4216-9e3b-a20a32363f6b"],
Cell[93339, 2360, 1687, 48, 262, "Input",ExpressionUUID->"7641103b-d9a5-43ee-a407-34bfc43b1585"],
Cell[95029, 2410, 3641, 84, 178, "Input",ExpressionUUID->"f868b017-da3e-4abe-91b3-36114ef753f0"],
Cell[98673, 2496, 368, 8, 30, "Input",ExpressionUUID->"f035ca3f-ccc5-4cf5-b601-1bc1bdf1a1d2"],
Cell[99044, 2506, 371, 8, 30, "Input",ExpressionUUID->"88f809fd-a887-4791-9fcc-8af47bfbdcb1"],
Cell[99418, 2516, 632, 17, 52, "Input",ExpressionUUID->"3ccccca5-fdf5-41d3-8779-a1f3725abfb8"],
Cell[100053, 2535, 537, 14, 30, "Input",ExpressionUUID->"36fe7c4a-777c-4eb1-aef6-f443614fa184"],
Cell[100593, 2551, 679, 16, 30, "Input",ExpressionUUID->"9f69ecf6-b26c-40b8-8cf0-283561541af6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101309, 2572, 198, 3, 98, "Title",ExpressionUUID->"ab5262e3-a773-4e5f-a0b7-028a76897a65"],
Cell[101510, 2577, 2743, 66, 157, "Input",ExpressionUUID->"df02e9b7-5817-47d4-86eb-d66bfdc4e66d"],
Cell[104256, 2645, 642, 18, 52, "Input",ExpressionUUID->"cf1ad59d-80f0-479a-b0a7-f7489be90eb8"],
Cell[104901, 2665, 546, 15, 30, "Input",ExpressionUUID->"10da78a6-543a-4bc8-87c4-8faf2011da87"],
Cell[105450, 2682, 687, 17, 30, "Input",ExpressionUUID->"efcc5c6c-1ece-4518-9834-0268c53fd1e7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106174, 2704, 173, 3, 98, "Title",ExpressionUUID->"408a7951-1f72-48b8-a823-9a83be54d04d"],
Cell[106350, 2709, 2742, 66, 157, "Input",ExpressionUUID->"40707f0f-5142-4b87-8a8d-a0d570b18222"],
Cell[109095, 2777, 638, 18, 52, "Input",ExpressionUUID->"b8e11398-ce7a-4337-8cd3-c8d66094e36c"],
Cell[109736, 2797, 544, 15, 30, "Input",ExpressionUUID->"eb902c93-d4d2-4faf-91e7-fc8e846e8f8e"],
Cell[110283, 2814, 687, 17, 30, "Input",ExpressionUUID->"1567343c-3c66-463f-ba5b-47a6551cf2b3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111007, 2836, 158, 3, 98, "Title",ExpressionUUID->"75149c7d-6d81-4b54-bc23-529e6f7d1c48"],
Cell[111168, 2841, 226, 5, 30, "Input",ExpressionUUID->"c97a08f1-42b8-478a-a2b4-402ff5a1233b"],
Cell[111397, 2848, 3677, 84, 304, "Input",ExpressionUUID->"fcb1d292-5246-44cf-811c-710652506640"],
Cell[115077, 2934, 678, 18, 52, "Input",ExpressionUUID->"615fb6ca-fa85-4761-a965-1d88c99e4654"],
Cell[115758, 2954, 574, 15, 30, "Input",ExpressionUUID->"2bd9d94c-673a-41d0-b4da-5e38d1dd8ff2"],
Cell[116335, 2971, 1079, 26, 73, "Input",ExpressionUUID->"66216dc7-3e5e-45be-bbb5-a905cd17204b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117451, 3002, 194, 3, 98, "Title",ExpressionUUID->"62163b02-2dcd-4a93-bfb7-4116de640474"],
Cell[117648, 3007, 760, 19, 52, "Input",ExpressionUUID->"57e4d12a-177e-45f6-87fa-6a92db5ce80e"],
Cell[118411, 3028, 1150, 29, 94, "Input",ExpressionUUID->"fb3d02ea-a1b3-40d7-944a-32b8bc053581"],
Cell[119564, 3059, 871, 23, 52, "Input",ExpressionUUID->"3e339c7e-f6ea-44cb-bc89-ea1c94a769b1"],
Cell[120438, 3084, 1217, 32, 94, "Input",ExpressionUUID->"f505d355-0433-48ac-aade-10f431a1caf8"],
Cell[121658, 3118, 1030, 25, 115, "Input",ExpressionUUID->"d53d0758-3897-42bf-afde-8f184399e727"],
Cell[122691, 3145, 1034, 25, 115, "Input",ExpressionUUID->"4292b21c-9835-4cc5-97a2-1ca27fc762f8"],
Cell[123728, 3172, 1085, 25, 115, "Input",ExpressionUUID->"9d1476c7-ad01-4a6d-a38d-3b46e665a1cb"],
Cell[124816, 3199, 1084, 25, 115, "Input",ExpressionUUID->"bf07d010-2d58-4bf6-a1f1-be6a1183046b"],
Cell[125903, 3226, 13816, 334, 556, "Input",ExpressionUUID->"4916e13b-55ec-453d-855e-d92c18794ddb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139756, 3565, 167, 3, 98, "Title",ExpressionUUID->"98c9793e-4504-421d-a3fc-55965cfee2d1"],
Cell[139926, 3570, 2108, 56, 157, "Input",ExpressionUUID->"81028b68-0b48-45cd-b15d-b0513555c3ef"],
Cell[142037, 3628, 12362, 317, 346, "Input",ExpressionUUID->"488642f5-0e13-4af9-b145-50fbe23ff229"],
Cell[154402, 3947, 4957, 127, 199, "Input",ExpressionUUID->"0085c0ce-75a4-400b-8852-dc8cc83134d0"],
Cell[159362, 4076, 350, 7, 85, "Input",ExpressionUUID->"a1d4ffa9-3a52-4f73-b70d-81f9ff063b17"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159749, 4088, 201, 3, 98, "Title",ExpressionUUID->"42ee50a8-3e7b-4eb1-8a8c-b37d478076eb"],
Cell[159953, 4093, 303, 8, 30, "Input",ExpressionUUID->"f5aa6522-636d-4781-a8f1-6f2c3fa94368"],
Cell[160259, 4103, 696, 19, 30, "Input",ExpressionUUID->"92b4834e-2999-4774-a5ba-d232ef596fc3"],
Cell[160958, 4124, 2032, 50, 115, "Input",ExpressionUUID->"b854227b-ccd4-435b-90c9-2d5fe5befbde"],
Cell[162993, 4176, 364, 8, 30, "Input",ExpressionUUID->"f68e21c7-34b2-4b3a-a6f4-ecde1eddcbe5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163394, 4189, 220, 4, 98, "Title",ExpressionUUID->"b22f87d7-0237-4c44-a4ab-0490430799fa"],
Cell[163617, 4195, 1667, 45, 157, "Input",ExpressionUUID->"055602f0-220a-4963-b422-57e7471e5681"],
Cell[165287, 4242, 2572, 67, 157, "Input",ExpressionUUID->"a979a5cf-0f48-4fa3-b879-68c898a06201"],
Cell[167862, 4311, 288, 7, 30, "Input",ExpressionUUID->"17ddd05c-779f-4be0-a4a8-b88a5a69634d"],
Cell[168153, 4320, 385, 10, 30, "Input",ExpressionUUID->"3cb58b30-eaf5-4fde-abe5-eec645983962"],
Cell[168541, 4332, 394, 11, 30, "Input",ExpressionUUID->"b320b8c9-667d-47ab-a1de-394951d10086"],
Cell[168938, 4345, 215, 4, 30, "Input",ExpressionUUID->"42f438b7-d988-4c23-b580-1d22bd4b7c0f"],
Cell[CellGroupData[{
Cell[169178, 4353, 138, 3, 69, "Chapter",ExpressionUUID->"0168e2ef-a573-4bc1-b139-ed55eaf81735"],
Cell[169319, 4358, 392, 11, 30, "Input",ExpressionUUID->"474cf568-d7db-4447-a779-d2d92850918b"],
Cell[169714, 4371, 383, 11, 30, "Input",ExpressionUUID->"34a2df77-4079-4d2f-8b9c-9a3d695bb391"],
Cell[170100, 4384, 2013, 47, 94, "Input",ExpressionUUID->"6ec20ff3-46b6-4af0-8a89-662cd26fa177"],
Cell[172116, 4433, 335, 7, 30, "Input",ExpressionUUID->"59337bd6-1d16-41ee-a604-3126b1fa2d31"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[172500, 4446, 126, 3, 98, "Title",ExpressionUUID->"e0ab9a17-d3a8-4031-a328-043d82f6d251"],
Cell[172629, 4451, 751, 23, 136, "Input",ExpressionUUID->"d16336b2-a554-4706-bd49-b89848bb006a"],
Cell[CellGroupData[{
Cell[173405, 4478, 161, 3, 69, "Chapter",ExpressionUUID->"9c7653b2-e85a-4296-acb8-a912def0f393"],
Cell[173569, 4483, 398, 11, 94, "Input",ExpressionUUID->"75710748-e3b0-4248-bdb4-90f5d73cefdd"],
Cell[173970, 4496, 4011, 111, 199, "Input",ExpressionUUID->"29634695-ab27-4552-a4d5-39918fe1013f"],
Cell[177984, 4609, 430, 10, 30, "Input",ExpressionUUID->"7e76f2be-4444-4054-ae25-82889febdf51"],
Cell[178417, 4621, 3931, 106, 199, "Input",ExpressionUUID->"3faaa7d6-2d7c-4f8d-85a1-0a52d2a44a58"],
Cell[182351, 4729, 391, 11, 30, "Input",ExpressionUUID->"c7820f11-8210-4195-a352-399292d203c4"],
Cell[182745, 4742, 454, 11, 30, "Input",ExpressionUUID->"30f7e3fd-75b5-4147-a56f-a57bb41502c1"],
Cell[183202, 4755, 443, 12, 30, "Input",ExpressionUUID->"3ba2e602-700d-4644-8612-30b197357dc0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[183682, 4772, 166, 3, 53, "Subtitle",ExpressionUUID->"905b7400-55d0-4707-a3b6-5051873baaba"],
Cell[183851, 4777, 959, 29, 73, "Input",ExpressionUUID->"83e30b70-9ce2-4f2b-ae86-c103a0fe337d"],
Cell[184813, 4808, 658, 19, 52, "Input",ExpressionUUID->"37d72dc6-1d7f-4bf5-9584-2c4c5e29ace5"],
Cell[185474, 4829, 657, 19, 52, "Input",ExpressionUUID->"1db4f1a8-0626-4c63-9a82-26cccd9ec342"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[186180, 4854, 170, 3, 98, "Title",ExpressionUUID->"3c620945-33a4-47c2-9f6d-b8cb1fa66033"],
Cell[186353, 4859, 327, 7, 35, "Text",ExpressionUUID->"5c59f8dd-c51d-4da6-b185-7627b44ba638"],
Cell[186683, 4868, 581, 17, 52, "Input",ExpressionUUID->"2e608b88-2c7e-458c-afa3-bc8dc9ba5b9b"],
Cell[187267, 4887, 3749, 87, 178, "Input",ExpressionUUID->"e7c955a5-1a07-4082-8e8e-32a0afa57706"],
Cell[191019, 4976, 298, 7, 30, "Input",ExpressionUUID->"d2399b0d-2804-4c4d-83f9-5552f6c5d88e"],
Cell[191320, 4985, 293, 7, 30, "Input",ExpressionUUID->"ba3a65c4-e8b8-4702-ba01-da1e4a21ccca"],
Cell[191616, 4994, 270, 7, 30, "Input",ExpressionUUID->"feb900c0-c63d-4afe-988a-f62a46e3321a"],
Cell[191889, 5003, 635, 18, 52, "Input",ExpressionUUID->"69d86e0b-c659-468e-b651-18f70cada97a"],
Cell[192527, 5023, 959, 28, 73, "Input",ExpressionUUID->"436d7070-b425-486b-9f3e-1df16548e630"],
Cell[CellGroupData[{
Cell[193511, 5055, 152, 3, 69, "Chapter",ExpressionUUID->"8369367e-dd95-4862-99ea-bda5f1cf7a21"],
Cell[193666, 5060, 268, 7, 30, "Input",ExpressionUUID->"afcadfe0-c672-4c96-b3c0-cb4bbd519e31"],
Cell[193937, 5069, 423, 11, 30, "Input",ExpressionUUID->"922a5fa1-0d17-4ff1-b73c-bd960312ee13"],
Cell[194363, 5082, 670, 19, 52, "Input",ExpressionUUID->"37c0db43-1924-484e-9c6f-b89a125ae731"],
Cell[195036, 5103, 2803, 69, 115, "Input",ExpressionUUID->"ae6adea0-9107-40cc-8f75-0ecddb1ed339"],
Cell[197842, 5174, 355, 9, 30, "Input",ExpressionUUID->"8bc6332e-3ef2-4225-8439-0b4073050e77"],
Cell[198200, 5185, 2873, 71, 115, "Input",ExpressionUUID->"210a31e7-0210-46db-b7c1-4ba992de89f8"],
Cell[201076, 5258, 356, 9, 30, "Input",ExpressionUUID->"c0b75888-d94a-4572-b4c5-2c6a6f6dfbf1"],
Cell[201435, 5269, 400, 10, 30, "Input",ExpressionUUID->"c51c2ba6-17fa-49ed-ba91-4a21cd38f4e5"],
Cell[201838, 5281, 340, 7, 30, "Input",ExpressionUUID->"258a5fba-32a9-4e94-9bea-810be7c2e553"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[202227, 5294, 226, 4, 98, "Title",ExpressionUUID->"d8ae2f76-4bc6-4f2d-a942-7d2219105128"],
Cell[CellGroupData[{
Cell[202478, 5302, 236, 6, 69, "Chapter",ExpressionUUID->"749779b9-0dca-43a4-a4de-de0e8b90cf26"],
Cell[202717, 5310, 655, 17, 52, "Input",ExpressionUUID->"da8dd828-8789-4abf-bc28-35362b69209a"],
Cell[203375, 5329, 1817, 51, 136, "Input",ExpressionUUID->"21f66dbe-96d4-4b58-8c90-c909b83e131f"],
Cell[205195, 5382, 359, 8, 52, "Input",ExpressionUUID->"7e6a7f3a-314a-49a4-92b9-84ba75b51f0f"],
Cell[205557, 5392, 400, 8, 52, "Input",ExpressionUUID->"895b5ce5-8883-46a9-8d45-d53ba8b67272"],
Cell[205960, 5402, 523, 12, 52, "Input",ExpressionUUID->"e7fbe239-a72f-4e8d-a5d5-873deec628fd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[206520, 5419, 180, 3, 53, "Subtitle",ExpressionUUID->"23a34493-a5d0-48a8-a854-2f24871d5fe3"],
Cell[206703, 5424, 2873, 79, 136, "Input",ExpressionUUID->"f0df8be8-7647-46ae-b640-5d01f54340bb"],
Cell[209579, 5505, 2872, 79, 136, "Input",ExpressionUUID->"1da414c8-fc46-4b68-9f6e-d04ff2e49635"],
Cell[212454, 5586, 2874, 79, 136, "Input",ExpressionUUID->"2842d8ed-061c-484c-8d7d-32807bbe78b2"],
Cell[215331, 5667, 430, 10, 30, "Input",ExpressionUUID->"516eb51a-fceb-4a91-a9db-7e6cd64dcc1f"],
Cell[215764, 5679, 359, 8, 30, "Input",ExpressionUUID->"e089258f-a0e8-4a03-8d57-22074a103a2f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[216160, 5692, 161, 3, 69, "Chapter",ExpressionUUID->"36272765-5762-4ec4-8f8e-b37df2abc2e0"],
Cell[216324, 5697, 3446, 91, 262, "Input",ExpressionUUID->"8b246acb-2233-4597-a127-953b74b4325b"],
Cell[219773, 5790, 4657, 122, 241, "Input",ExpressionUUID->"98018fac-1b75-4eb0-9570-12a4f72c2750"],
Cell[224433, 5914, 360, 8, 30, "Input",ExpressionUUID->"0c0c4c7d-8201-4ad2-819f-801e647a424c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[224842, 5928, 273, 5, 98, "Title",ExpressionUUID->"3e4a9a7d-6f20-4a24-a9c6-c803d0724744"],
Cell[CellGroupData[{
Cell[225140, 5937, 133, 2, 69, "Chapter",ExpressionUUID->"8462b220-6e1d-4fcc-b968-b57e312e1f00"],
Cell[225276, 5941, 152, 3, 53, "Subtitle",ExpressionUUID->"f5531294-9e29-45c7-b431-6af5ac692639"],
Cell[225431, 5946, 2590, 77, 241, "Input",ExpressionUUID->"69721b26-837e-4ecb-8829-d198a6873093"],
Cell[228024, 6025, 1184, 32, 115, "Input",ExpressionUUID->"854198ec-9327-417e-8be3-0bba4abe2403"],
Cell[229211, 6059, 265, 5, 30, "Input",ExpressionUUID->"e76b4797-6e25-4694-b07e-921b7e131856"],
Cell[229479, 6066, 768, 21, 52, "Input",ExpressionUUID->"7d74b617-4429-4e39-b74a-4d3f1ce84ce1"],
Cell[230250, 6089, 447, 11, 30, "Input",ExpressionUUID->"ad7641e2-d20e-44af-81af-05b941c03ae1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230734, 6105, 132, 3, 69, "Chapter",ExpressionUUID->"7d44e0a1-d367-41f0-9d7e-b92342b4d61f"],
Cell[230869, 6110, 2132, 56, 346, "Input",ExpressionUUID->"94964efa-c683-43a3-996b-787bd416f201"],
Cell[233004, 6168, 49025, 1155, 3244, "Input",ExpressionUUID->"f2dd58e1-8195-42ed-ac6a-c8f7182a65e8"],
Cell[282032, 7325, 181, 3, 30, "Input",ExpressionUUID->"526e6a78-b301-417d-9df8-b51d88a78b89"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[282262, 7334, 214, 7, 98, "Title",ExpressionUUID->"54fec5a7-c29f-4070-bf87-8eff0558c093"],
Cell[CellGroupData[{
Cell[282501, 7345, 133, 2, 69, "Chapter",ExpressionUUID->"4246f477-6009-407c-af1c-fe1ea9b169ea"],
Cell[282637, 7349, 152, 3, 53, "Subtitle",ExpressionUUID->"271fa2f5-1ee3-4fc1-9e3b-ad6618d94832"],
Cell[282792, 7354, 2293, 72, 220, "Input",ExpressionUUID->"29607578-782c-41ba-95f6-25e013b068e5"],
Cell[285088, 7428, 985, 29, 73, "Input",ExpressionUUID->"0ecac2b2-8b7d-4cbf-945c-26cc633e0c33"],
Cell[286076, 7459, 246, 6, 30, "Input",ExpressionUUID->"fb93785b-2e00-4bb6-ba5a-e8f77a98de90"],
Cell[286325, 7467, 774, 22, 52, "Input",ExpressionUUID->"64694189-8f8f-4240-a450-ac64db5402d8"],
Cell[287102, 7491, 377, 11, 30, "Input",ExpressionUUID->"fb9392ac-1351-4215-b380-02541f758d1c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287516, 7507, 132, 3, 69, "Chapter",ExpressionUUID->"04a9b5ac-a853-4b3e-b46c-310ca2a44c02"],
Cell[287651, 7512, 2331, 65, 367, "Input",ExpressionUUID->"ca43076d-703d-44d4-a80e-5ac6fc96155d"],
Cell[289985, 7579, 33765, 790, 1795, "Input",ExpressionUUID->"94ba51ef-c6eb-43b4-bdbe-54c60ef38c00"],
Cell[323753, 8371, 158, 3, 30, "Input",ExpressionUUID->"4ddaa580-d692-446c-b2ca-7161bb52b5ce"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[323960, 8380, 316, 5, 98, "Title",ExpressionUUID->"1a810bc8-71e7-48c2-9031-1942ae8b0a2b"],
Cell[CellGroupData[{
Cell[324301, 8389, 133, 2, 69, "Chapter",ExpressionUUID->"eedec05c-a776-4774-84b0-4217e2e9d65f"],
Cell[324437, 8393, 152, 3, 53, "Subtitle",ExpressionUUID->"608ff216-65f6-4f24-afbd-e45d3f2966a2"],
Cell[324592, 8398, 2528, 77, 262, "Input",ExpressionUUID->"d44e4732-6cf4-4498-96c1-1b1427dfc804"],
Cell[327123, 8477, 1180, 32, 115, "Input",ExpressionUUID->"fc21cb7d-c095-4eae-aadc-4b2ac1b9957f"],
Cell[328306, 8511, 269, 6, 30, "Input",ExpressionUUID->"37e9ec0b-ada3-45a4-9157-ec3bb73bb996"],
Cell[328578, 8519, 772, 22, 52, "Input",ExpressionUUID->"ce4bb28e-5831-4b1e-beb9-429dd7dfcd73"],
Cell[329353, 8543, 773, 22, 52, "Input",ExpressionUUID->"2ccae347-261d-4042-aa92-91247995fa84"]
}, Open  ]],
Cell[CellGroupData[{
Cell[330163, 8570, 132, 3, 69, "Chapter",ExpressionUUID->"98fef14b-371e-431e-b915-1b6b6d2dd1d4"],
Cell[330298, 8575, 1942, 55, 346, "Input",ExpressionUUID->"345506ae-eb2d-4725-9e18-35317b2af77f"],
Cell[332243, 8632, 49480, 1164, 3118, "Input",ExpressionUUID->"9de2b292-2a74-4b1c-ad0c-4b2e671dd021"],
Cell[381726, 9798, 181, 3, 30, "Input",ExpressionUUID->"5e23eabd-e93c-4d15-af5c-e2860a73411d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[381956, 9807, 150, 3, 98, "Title",ExpressionUUID->"26a16030-ae08-4131-9a63-5fb6ac9a3ed0"],
Cell[382109, 9812, 220, 3, 30, "Input",ExpressionUUID->"40fd1e18-1729-49b9-868d-711af23e2bb1"],
Cell[382332, 9817, 276, 5, 30, "Input",ExpressionUUID->"8f24a24c-494a-4dfd-8a80-87902931666f"],
Cell[CellGroupData[{
Cell[382633, 9826, 133, 3, 69, "Chapter",ExpressionUUID->"e1394684-4f75-4eec-9fed-cca3874056e0"],
Cell[382769, 9831, 592, 16, 94, "Input",ExpressionUUID->"95ac5582-e244-4521-aaee-f5939d2a7696"],
Cell[383364, 9849, 594, 16, 94, "Input",ExpressionUUID->"98f614e0-4201-4759-8984-1d53e89fea93"],
Cell[383961, 9867, 592, 16, 94, "Input",ExpressionUUID->"a3010059-1eb9-4d4b-8c0a-f809cd3f7164"],
Cell[384556, 9885, 1303, 40, 220, "Input",ExpressionUUID->"92d1a042-4ef7-4675-9633-e3ff20a2918b"],
Cell[385862, 9927, 1301, 40, 220, "Input",ExpressionUUID->"9b1b5fed-06a3-44ed-9388-ac62a904f25e"],
Cell[387166, 9969, 922, 27, 115, "Input",ExpressionUUID->"c69b539c-5add-4723-99d5-eafabc6c922a"],
Cell[388091, 9998, 601, 18, 73, "Input",ExpressionUUID->"50d85788-0a00-433a-8189-57f7866da318"],
Cell[388695, 10018, 1453, 44, 262, "Input",ExpressionUUID->"af644773-4945-48bb-9f76-9226d12e1a71"],
Cell[390151, 10064, 1761, 46, 178, "Input",ExpressionUUID->"17a4af88-57cf-4d70-a981-fd7520ad4752"]
}, Open  ]],
Cell[CellGroupData[{
Cell[391949, 10115, 135, 3, 69, "Chapter",ExpressionUUID->"1e76fce8-151f-4c6c-9b50-0481beeee29a"],
Cell[392087, 10120, 9488, 233, 619, "Input",ExpressionUUID->"ba511135-0633-4a9d-91c6-797e6c50a588"],
Cell[401578, 10355, 9598, 233, 640, "Input",ExpressionUUID->"28999a70-8a23-470f-ae05-0268a4beec86"],
Cell[411179, 10590, 4671, 126, 514, "Input",ExpressionUUID->"a48e7f51-bb03-48d2-a267-680edb67e8c6"],
Cell[415853, 10718, 16194, 397, 1025, "Input",ExpressionUUID->"c8856812-94b3-4392-9057-7082e2f6ef1e"],
Cell[432050, 11117, 16977, 415, 1172, "Input",ExpressionUUID->"764bd257-74af-4e99-b3c7-6eaf437f1634"],
Cell[449030, 11534, 10155, 251, 682, "Input",ExpressionUUID->"1b5813f0-7635-49de-84c6-863440d0a0d7"],
Cell[459188, 11787, 7821, 197, 577, "Input",ExpressionUUID->"27a62263-84aa-4b42-940e-0a15a4922535"]
}, Open  ]],
Cell[CellGroupData[{
Cell[467046, 11989, 139, 3, 69, "Chapter",ExpressionUUID->"83982e5b-eb92-4c15-8baf-08044082ed6f"],
Cell[467188, 11994, 479, 14, 30, "Input",ExpressionUUID->"115d77d3-1ed8-4d3e-a37e-0679beb1f17d"],
Cell[467670, 12010, 399, 9, 30, "Input",ExpressionUUID->"67eae316-a233-4bd9-ac37-db373709f479"],
Cell[468072, 12021, 273, 7, 30, "Input",ExpressionUUID->"6b32f72f-931d-4d97-a277-05d9be34e10d"],
Cell[468348, 12030, 439, 12, 52, "Input",ExpressionUUID->"a7e9eeb8-7a9d-4291-b3f9-12574b81b823"],
Cell[468790, 12044, 487, 13, 30, "Input",ExpressionUUID->"6aaa82f1-d7ff-4080-96cb-30c659e1d932"],
Cell[469280, 12059, 408, 9, 52, "Input",ExpressionUUID->"520a9d16-72cb-4286-a266-0e728bb1e2a5"],
Cell[469691, 12070, 280, 7, 30, "Input",ExpressionUUID->"c5caa7dc-d4b4-4fd8-b294-cded1f63342e"],
Cell[469974, 12079, 442, 12, 52, "Input",ExpressionUUID->"12a4d9fe-a43e-4aa0-985c-471c4b53cef1"],
Cell[470419, 12093, 334, 9, 30, "Input",ExpressionUUID->"0c7c78d6-044d-4387-9d44-ed80bea88c7a"],
Cell[470756, 12104, 414, 9, 52, "Input",ExpressionUUID->"0f4e2235-60ff-42fc-bf93-a2d676fd9e18"]
}, Open  ]],
Cell[CellGroupData[{
Cell[471207, 12118, 163, 3, 69, "Chapter",ExpressionUUID->"cc95a355-95ea-44e4-a65a-51928295642e"],
Cell[471373, 12123, 1162, 33, 94, "Input",ExpressionUUID->"cc9f7dfe-dbd9-4027-a5e5-003d80d0703b"],
Cell[472538, 12158, 1049, 28, 73, "Input",ExpressionUUID->"7ac868c8-cc0c-4c90-809e-e3b82615d045"],
Cell[473590, 12188, 409, 9, 52, "Input",ExpressionUUID->"0d9a918a-b150-49f3-a01b-d6a083d13ea9"],
Cell[474002, 12199, 1103, 28, 73, "Input",ExpressionUUID->"5f10bbd0-5785-464c-9905-34a375a7ec81"],
Cell[475108, 12229, 419, 10, 52, "Input",ExpressionUUID->"8e241715-4299-4768-b1ee-46609ea27d59"]
}, Open  ]],
Cell[CellGroupData[{
Cell[475564, 12244, 154, 3, 69, "Chapter",ExpressionUUID->"6b8d7146-4317-4fb0-b442-451bda3ecbea"],
Cell[475721, 12249, 895, 23, 73, "Input",ExpressionUUID->"815ba92c-b275-4dc7-b1f9-0877ba28856a"],
Cell[476619, 12274, 415, 9, 52, "Input",ExpressionUUID->"e1bc969e-690c-430d-b0df-f8dfb95e0274"]
}, Open  ]],
Cell[CellGroupData[{
Cell[477071, 12288, 206, 4, 69, "Chapter",ExpressionUUID->"664a6c08-8dfc-439e-8575-02b94ad2a618"],
Cell[477280, 12294, 1547, 35, 73, "Input",ExpressionUUID->"243d278d-46bc-4b17-b9a1-1108d992d5c6"],
Cell[478830, 12331, 524, 11, 52, "Input",ExpressionUUID->"1d9a1e07-d3d8-4384-afbd-25e22451eb1c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[479391, 12347, 133, 3, 69, "Chapter",ExpressionUUID->"0e1f5b32-a909-4079-a0a4-311cd64dc35b"],
Cell[479527, 12352, 837, 25, 52, "Input",ExpressionUUID->"c306ad07-eb8b-44a6-9201-f659f4fe35b8"],
Cell[480367, 12379, 340, 9, 52, "Input",ExpressionUUID->"d18b9b7a-8740-4bb4-836c-1623077cda91"],
Cell[480710, 12390, 261, 6, 30, "Input",ExpressionUUID->"887944f6-ad45-43ba-9631-4a9459ca8052"],
Cell[480974, 12398, 415, 10, 52, "Input",ExpressionUUID->"54d298e8-e961-429d-9bb9-2ce52b3998b5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[481426, 12413, 180, 3, 69, "Chapter",ExpressionUUID->"96436361-cfbd-44a4-841a-2df486deadb8"],
Cell[481609, 12418, 6853, 205, 619, "Input",ExpressionUUID->"9ac04952-fe80-402f-a137-b774bf0d4154"],
Cell[488465, 12625, 441, 10, 52, "Input",ExpressionUUID->"0e9bd831-8cc0-4f1b-9ffb-e516be037ca0"],
Cell[488909, 12637, 328, 9, 30, "Input",ExpressionUUID->"715ace16-82c2-4afc-9684-359e73f0aeb4"],
Cell[489240, 12648, 445, 10, 52, "Input",ExpressionUUID->"ccf79b4d-5f83-4ab2-a9d7-4246c7ec21a6"],
Cell[489688, 12660, 7430, 188, 514, "Input",ExpressionUUID->"9dd807c3-0723-4be6-a461-45d638434d41"],
Cell[497121, 12850, 1022, 30, 52, "Input",ExpressionUUID->"c1f09687-64a7-483f-91d6-45cc7f559f77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[498180, 12885, 137, 3, 69, "Chapter",ExpressionUUID->"45da33ec-2154-4675-87c9-9109f8d03890"],
Cell[498320, 12890, 4562, 140, 367, "Input",ExpressionUUID->"e73f714c-aefa-46ba-aa23-6ed79666dec8"],
Cell[502885, 13032, 969, 26, 52, "Input",ExpressionUUID->"1089c078-a9d5-4b62-a7aa-6b2d1e70afcb"],
Cell[503857, 13060, 413, 10, 52, "Input",ExpressionUUID->"87e345a4-cf1c-4452-807a-d668ed5ad1f7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[504307, 13075, 191, 5, 69, "Chapter",ExpressionUUID->"115cf903-d97a-4066-a468-8f5de6ec3aa4"],
Cell[504501, 13082, 1229, 30, 94, "Input",ExpressionUUID->"b774adc5-232d-4135-9ced-df7c10ceb5e5"]
}, Open  ]]
}, Open  ]],
Cell[505757, 13116, 130, 3, 98, "Title",ExpressionUUID->"68e5adfa-5d5a-439f-a4e7-e79642178b1a"]
}
]
*)

